@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -52,6 +53,7 @@
 #include "manual.h"
 #include "filtering.h"
 #include "prefs_actions.h"
+#include "hooks.h"
 
 enum {
 	ACCOUNT_IS_DEFAULT,
@@ -107,11 +109,9 @@ static gint account_delete_event	(GtkWidget	*widget,
 					 gpointer	 data);
 static void account_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation);
-#ifndef MAEMO
 static gboolean account_key_pressed	(GtkWidget	*widget,
 					 GdkEventKey	*event,
 					 gpointer	 data);
-#endif
 static gboolean account_search_func_cb (GtkTreeModel *model, gint column, 
 						const gchar *key, GtkTreeIter *iter, 
 						gpointer search_data);
@@ -373,6 +373,15 @@ GList *account_get_list(void)
 	return account_list;
 }
 
+void account_edit_focus(void)
+{
+	manage_window_set_transient(GTK_WINDOW(edit_account.window));
+	gtk_widget_grab_focus(edit_account.close_btn);
+	gtk_widget_show(edit_account.window);
+	gtk_window_set_modal(GTK_WINDOW(edit_account.window), TRUE);
+	manage_window_focus_in(edit_account.window, NULL, NULL);
+}
+
 void account_edit_open(gpointer a, gpointer b)
 {
 	inc_lock();
@@ -394,11 +403,7 @@ void account_edit_open(gpointer a, gpointer b)
 
 	account_list_view_set();
 
-	manage_window_set_transient(GTK_WINDOW(edit_account.window));
-	gtk_widget_grab_focus(edit_account.close_btn);
-	gtk_widget_show(edit_account.window);
-	gtk_window_set_modal(GTK_WINDOW(edit_account.window), TRUE);
-	manage_window_focus_in(edit_account.window, NULL, NULL);
+	account_edit_focus();
 }
 
 void account_add(void)
@@ -409,6 +414,8 @@ void account_add(void)
 
 	if (!ac_prefs) return;
 
+	account_edit_focus();
+
 	account_list = g_list_append(account_list, ac_prefs);
 
 	if (ac_prefs->is_default)
@@ -454,6 +461,8 @@ void account_open(PrefsAccount *ac_prefs)
 
 	prefs_account_open(ac_prefs, &account_dirty);
 
+	account_edit_focus();
+
 	if (account_dirty) {
 		if (!prev_default && ac_prefs->is_default)
 			account_set_as_default(ac_prefs);
@@ -651,7 +660,6 @@ void account_destroy(PrefsAccount *ac_prefs)
 
 	folder_unref_account_all(ac_prefs);
 
-	prefs_account_free(ac_prefs);
 	account_list = g_list_remove(account_list, ac_prefs);
 
 	if (cur_account == ac_prefs) cur_account = NULL;
@@ -709,12 +717,8 @@ static void account_edit_create(void)
 	gtk_window_set_title (GTK_WINDOW (window), _("Edit accounts"));
 	g_signal_connect (G_OBJECT (window), "delete_event",
 			  G_CALLBACK (account_delete_event), NULL);
-#ifdef MAEMO
-	maemo_connect_key_press_to_mainwindow(GTK_WINDOW(window));
-#else
 	g_signal_connect (G_OBJECT (window), "key_press_event",
 			  G_CALLBACK (account_key_pressed), NULL);
-#endif			  
 	MANAGE_WINDOW_SIGNALS_CONNECT (window);
 	gtk_widget_realize(window);
 
@@ -839,9 +843,6 @@ static void account_edit_create(void)
 	edit_account.window    = window;
 	edit_account.list_view = list_view;
 	edit_account.close_btn = close_btn;
-#ifdef MAEMO
-	maemo_window_full_screen_if_needed(GTK_WINDOW(edit_account.window));
-#endif
 }
 
 static void account_edit_prefs(GtkWidget *widget, gpointer data)
@@ -1234,7 +1235,7 @@ static gint account_delete_event(GtkWidget *widget, GdkEventAny *event,
 	account_edit_close(NULL, NULL);
 	return TRUE;
 }
-#ifndef MAEMO
+
 static gboolean account_key_pressed(GtkWidget *widget, GdkEventKey *event,
 				    gpointer data)
 {
@@ -1242,7 +1243,6 @@ static gboolean account_key_pressed(GtkWidget *widget, GdkEventKey *event,
 		account_edit_close(NULL, NULL);
 	return FALSE;
 }
-#endif
 
 static gboolean account_search_func_cb (GtkTreeModel *model, gint column, const gchar *key, 
 						GtkTreeIter *iter, gpointer search_data) 
@@ -1533,7 +1533,7 @@ static void account_create_list_view_columns(GtkWidget *list_view)
 		     "activatable", TRUE,
 		      NULL);
 	column = gtk_tree_view_column_new_with_attributes
-		(Q_("Accounts List Get Column Name|G"), renderer,
+		(C_("Accounts List Get Column Name", "G"), renderer,
 		 "active", ACCOUNT_ENABLE_GET_ALL,
 		 NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(list_view), column);		
@@ -1850,3 +1850,29 @@ PrefsAccount *account_get_cur_account (void)
 {
 	return cur_account;
 }
+
+gboolean password_get(const gchar *user,
+		    const gchar *server,
+		    const gchar *protocol,
+		    guint16 port,
+		    gchar **password)
+{
+	PasswordRequest req;
+
+	/* all have to be set */
+	cm_return_val_if_fail(user != NULL, FALSE);
+	cm_return_val_if_fail(server != NULL, FALSE);
+	cm_return_val_if_fail(protocol != NULL, FALSE);
+	cm_return_val_if_fail(port != 0, FALSE);
+
+	req.user = user;
+	req.server = server;
+	req.protocol = protocol;
+	req.port = port;
+
+	if (hooks_invoke(PASSWORD_GET_HOOKLIST, &req)) {
+		*password = req.password;
+		return TRUE;
+	}
+	return FALSE;
+}
