@@ -20,6 +20,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 #include "defs.h"
 
@@ -42,6 +43,7 @@
 #include "claws.h"
 #include "hooks.h"
 #include "gtkutils.h"
+#include "stock_pixmap.h"
 #include <pthread.h>
 
 #ifndef USE_NEW_ADDRBOOK
@@ -162,12 +164,22 @@ static gchar *completion_func(gpointer data)
 	return ((completion_entry *)data)->string;
 } 
 
+static gint addr_completion_func(const gchar *needle, const gchar *haystack,
+		gsize n)
+{
+	if (needle == NULL || haystack == NULL)
+		return 1;
+
+	return (strcasestr(haystack, needle) != NULL ? 0 : 1);
+}
+
 /**
  * Initialize all completion index data.
  */
 static void init_all(void)
 {
 	g_completion = g_completion_new(completion_func);
+	g_completion_set_compare(g_completion, addr_completion_func);
 	cm_return_if_fail(g_completion != NULL);
 }
 
@@ -252,35 +264,32 @@ void addr_compl_add_address1(const char *str, address_entry *ae)
 static gint add_address(const gchar *name, const gchar *address, 
 			const gchar *nick, const gchar *alias, GList *grp_emails)
 {
-	address_entry    *ae;
-	gboolean is_group = FALSE;
+	address_entry *ae;
 
-	if (!name || !address) {
-		if (!address && !nick && !alias && grp_emails) {
-			is_group = TRUE;
-		} else
-			return -1;
-	}
+	if (!address && !grp_emails)
+		return -1;
+
+	if (!name)
+		name = "";
 
 	ae = g_new0(address_entry, 1);
-
 	cm_return_val_if_fail(ae != NULL, -1);
 
-	ae->name    = g_strdup(name);
+	ae->name = g_strdup(name);
 	ae->address = g_strdup(address);
 	ae->grp_emails = grp_emails;
 	g_address_list = g_list_prepend(g_address_list, ae);
 
 	addr_compl_add_address1(name, ae);
+
 	if (address != NULL && *address != '\0')
 		addr_compl_add_address1(address, ae);
 
 	if (nick != NULL && *nick != '\0')
 		addr_compl_add_address1(nick, ae);
 
-	if ( alias != NULL && *alias != '\0') {
+	if (alias != NULL && *alias != '\0')
 		addr_compl_add_address1(alias, ae);
-	}
 
 	return 0;
 }
@@ -860,11 +869,20 @@ static void addrcompl_resize_window( CompletionWindow *cw ) {
 	gint x, y, width, height, depth;
 
 	/* Get current geometry of window */
+#if !GTK_CHECK_VERSION(3, 0, 0)
 	gdk_window_get_geometry( gtk_widget_get_window( cw->window ), &x, &y, &width, &height, &depth );
+#else
+	gdk_window_get_geometry( gtk_widget_get_window( cw->window ), &x, &y, &width, &height );
+#endif
 
 	/* simple _hide breaks size requisition !? */
+#if !GTK_CHECK_VERSION(3, 0, 0)
 	gtk_widget_hide_all( cw->window );
 	gtk_widget_show_all( cw->window );
+#else
+	gtk_widget_hide( cw->window );
+	gtk_widget_show( cw->window );
+#endif
 	gtk_widget_size_request( cw->list_view, &r );
 
 	/* Adjust window height to available screen space */
@@ -1370,7 +1388,11 @@ static void address_completion_create_completion_window( GtkEntry *entry_ )
 		GTK_SHADOW_OUT);
 	/* Use entry widget to create initial window */
 	gdkwin = gtk_widget_get_window(entry),
+#if !GTK_CHECK_VERSION(3, 0, 0)
 	gdk_window_get_geometry(gdkwin, &x, &y, &width, &height, &depth);
+#else
+	gdk_window_get_geometry(gdkwin, &x, &y, &width, &height);
+#endif
 	gdk_window_get_origin (gdkwin, &x, &y);
 	y += height;
 	gtk_window_move(GTK_WINDOW(window), x, y);
