@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2007-2012 The Claws Mail Team
+ * Copyright (C) 2007-2013 The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -279,15 +280,8 @@ static GtkWidget *custom_attr_window_list_view_create	(void)
 	/* create the columns */
 	custom_attr_window_create_list_view_columns(GTK_WIDGET(list_view));
 
-#ifndef MAEMO
 	g_signal_connect(G_OBJECT(list_view), "popup-menu",
 			 G_CALLBACK(custom_attr_list_popup_menu), list_view);
-#else
-	gtk_widget_tap_and_hold_setup(GTK_WIDGET(list_view), NULL, NULL,
-			GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS);
-	g_signal_connect(G_OBJECT(list_view), "tap-and-hold",
-			 G_CALLBACK(custom_attr_list_popup_menu), list_view);
-#endif
 	g_signal_connect(G_OBJECT(list_view), "button-press-event",
 			G_CALLBACK(custom_attr_list_btn_pressed), list_view);
 	return GTK_WIDGET(list_view);
@@ -323,10 +317,6 @@ static void custom_attr_selected_attr_edited(GtkCellRendererText *widget,
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(list_view));
-	SummaryView *summaryview = NULL;
-
-	if (mainwindow_get_mainwindow() != NULL)
-		summaryview = mainwindow_get_mainwindow()->summaryview;
 
 	if (!gtk_tree_model_get_iter_from_string(model, &iter, path))
 		return;
@@ -469,7 +459,7 @@ static void custom_attr_window_create(void)
 
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "custom_attr_edit_window");
 	gtk_window_set_title (GTK_WINDOW(window),
-			      Q_("Dialog title|Edit attribute names"));
+			      C_("Dialog title", "Edit attribute names"));
 
 	gtk_container_set_border_width (GTK_CONTAINER (window), 8);
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
