@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2009 Match Grun and the Claws Mail team
+ * Copyright (C) 2002-2012 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,11 +25,20 @@
 #define __ADDR_GATHER_H__
 
 /* Function prototypes */
+#include "folder.h"
+
+#ifndef USE_NEW_ADDRBOOK
+#include "addrbook.h"
+
 AddressBookFile *addrgather_dlg_execute( FolderItem *folderItem,
 					 AddressIndex *addrIndex,
 					 gboolean sourceInd,
 					 GList *msgList );
-
+#else
+void addrgather_dlg_execute( FolderItem *folderItem,
+					 		 gboolean sourceInd,
+					 		 GList *msgList );
+#endif
 #endif /* __ADDR_GATHER_H__ */
 
 /*
