@@ -577,13 +577,10 @@ static void addrharvest_parse_address(
 			mgu_str_ltc2space( buffer, '(', ')' );
 			g_strstrip( buffer );
 
-			if( g_ascii_strcasecmp( buffer, email ) == 0 ) {
+			if( g_ascii_strcasecmp( buffer, email ) == 0 )
 				name = g_strdup("");
-			}
-			else {
-				name = buffer;
+			else
 				name = conv_unmime_header(buffer, NULL, TRUE);
-			}
 
 			/* Insert into address book */
 #ifndef USE_NEW_ADDRBOOK
@@ -816,11 +813,16 @@ static void addrharvest_harvest_list(
 	int r;
 
 	if( ( dp = opendir( harvester->path ) ) == NULL ) {
+		g_message("cannot opendir %s\n", harvester->path);
 		return;
 	}
 
 	/* Process message list */
 	r = chdir( harvester->path );
+	if (r != 0) {
+		g_message("cannot chdir %s\n", harvester->path);
+		return;
+	}
 	node = msgList;
 	while( node ) {
 		num = GPOINTER_TO_UINT( node->data );
