@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail Team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ const gchar *plugin_desc	(void);
 const gchar *plugin_version	(void);
 struct PluginFeature *plugin_provides (void);
 
-/* Functions by the sylpheed plugin system */
+/* Functions by the Claws Mail plugin system */
 Plugin *plugin_load		(const gchar	 *filename,
 				 gchar		**error);
 void plugin_unload		(Plugin		 *plugin);
@@ -64,6 +64,7 @@ const gchar *plugin_get_name	(Plugin		 *plugin);
 const gchar *plugin_get_desc	(Plugin		 *plugin);
 const gchar *plugin_get_version	(Plugin		 *plugin);
 const gchar *plugin_get_error	(Plugin		 *plugin);
+Plugin      *plugin_get_loaded_by_name(const gchar *name);
 gint check_plugin_version	(guint32 minimum_claws_version,
 				 guint32 compiled_claws_version,
 				 const gchar *plugin_name,
