@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -99,6 +100,8 @@ void session_init(Session *session, const void *prefs_account, gboolean is_smtp)
 	session->data = NULL;
 	session->account = prefs_account;
 	session->is_smtp = is_smtp;
+
+	session->ping_tag = -1;
 }
 
 /*!
@@ -163,6 +166,8 @@ static gint session_connect_cb(SockInfo *sock, gpointer data)
 	sock->account = session->account;
 	sock->is_smtp = session->is_smtp;
 #ifdef USE_GNUTLS
+	sock->gnutls_priority = session->gnutls_priority;
+
 	if (session->ssl_type == SSL_TUNNEL) {
 		sock_set_nonblocking_mode(sock, FALSE);
 		if (!ssl_init_socket(sock)) {
@@ -214,6 +219,8 @@ void session_destroy(Session *session)
 	cm_return_if_fail(session != NULL);
 	cm_return_if_fail(session->destroy != NULL);
 
+	session_register_ping(session, NULL);
+
 	session_close(session);
 	session->destroy(session);
 	g_free(session->server);
@@ -221,6 +228,9 @@ void session_destroy(Session *session)
 	g_byte_array_free(session->read_data_buf, TRUE);
 	g_free(session->read_data_terminator);
 	g_free(session->write_buf);
+#ifdef USE_GNUTLS
+	g_free(session->gnutls_priority);
+#endif
 
 	debug_print("session (%p): destroyed\n", session);
 
@@ -866,3 +876,22 @@ static gboolean session_write_data_cb(SockInfo *source,
 
 	return FALSE;
 }
+
+void session_register_ping(Session *session, gboolean (*ping_cb)(gpointer data))
+{
+	if (!session)
+		return;
+	if (session->ping_tag > -1)
+		g_source_remove(session->ping_tag);
+
+	session->ping_tag = -1;
+
+	if (ping_cb != NULL)
+#if GLIB_CHECK_VERSION(2,14,0)
+		session->ping_tag =
+			g_timeout_add_seconds(60, ping_cb, session);
+#else
+		session->ping_tag =
+			g_timeout_add(60*1000, ping_cb, session);
+#endif
+}
