@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #ifdef USE_GNUTLS
@@ -51,21 +52,28 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 
 #ifdef USE_PTHREAD
 typedef struct _thread_data {
-	gnutls_session ssl;
+	gnutls_session_t ssl;
 	gboolean done;
 } thread_data;
 #endif
 
-static int gnutls_client_cert_cb(gnutls_session session,
-                               const gnutls_datum *req_ca_rdn, int nreqs,
-                               const gnutls_pk_algorithm *sign_algos,
+#if GNUTLS_VERSION_NUMBER <= 0x020c00
+static int gnutls_client_cert_cb(gnutls_session_t session,
+                               const gnutls_datum_t *req_ca_rdn, int nreqs,
+                               const gnutls_pk_algorithm_t *sign_algos,
                                int sign_algos_length, gnutls_retr_st *st)
+#else
+static int gnutls_cert_cb(gnutls_session_t session,
+                               const gnutls_datum_t *req_ca_rdn, int nreqs,
+                               const gnutls_pk_algorithm_t *sign_algos,
+                               int sign_algos_length, gnutls_retr2_st *st)
+#endif
 {
 	SSLClientCertHookData hookdata;
 	SockInfo *sockinfo = (SockInfo *)gnutls_session_get_ptr(session);
-	gnutls_certificate_type type = gnutls_certificate_type_get(session);
-	gnutls_x509_crt crt;
-	gnutls_x509_privkey key;
+	gnutls_certificate_type_t type = gnutls_certificate_type_get(session);
+	gnutls_x509_crt_t crt;
+	gnutls_x509_privkey_t key;
 
 	st->ncerts = 0;
 
@@ -90,7 +98,11 @@ static int gnutls_client_cert_cb(gnutls_session session,
 
 	if (type == GNUTLS_CRT_X509 && sockinfo->client_crt && sockinfo->client_key) {
 		st->ncerts = 1;
+#if GNUTLS_VERSION_NUMBER <= 0x020c00
 		st->type = type;
+#else
+		st->key_type = type;
+#endif
 		st->cert.x509 = &(sockinfo->client_crt);
 		st->key.x509 = sockinfo->client_key;
 		st->deinit_all = 0;
@@ -104,6 +116,7 @@ const gchar *claws_ssl_get_cert_file(void)
 	const char *cert_files[]={
 		"/etc/pki/tls/certs/ca-bundle.crt",
 		"/etc/certs/ca-bundle.crt",
+		"/etc/ssl/ca-bundle.pem",
 		"/usr/share/ssl/certs/ca-bundle.crt",
 		"/etc/ssl/certs/ca-certificates.crt",
 		"/usr/local/ssl/certs/ca-bundle.crt",
@@ -150,7 +163,7 @@ const gchar *claws_ssl_get_cert_dir(void)
 	}
 	return NULL;
 #else
-	return "put_what_s_needed_here";
+	return NULL;
 #endif
 }
 
@@ -188,7 +201,7 @@ static void *SSL_connect_thread(void *data)
 }
 #endif
 
-static gint SSL_connect_nb(gnutls_session ssl)
+static gint SSL_connect_nb(gnutls_session_t ssl)
 {
 	int result;
 #ifdef USE_PTHREAD
@@ -249,11 +262,11 @@ gboolean ssl_init_socket(SockInfo *sockinfo)
 
 gboolean ssl_init_socket_with_method(SockInfo *sockinfo, SSLMethod method)
 {
-	gnutls_session session;
+	gnutls_session_t session;
 	int r;
-	const gnutls_datum *raw_cert_list;
+	const gnutls_datum_t *raw_cert_list;
 	unsigned int raw_cert_list_length;
-	gnutls_x509_crt cert = NULL;
+	gnutls_x509_crt_t cert = NULL;
 	guint status;
 	gnutls_certificate_credentials_t xcred;
 
@@ -264,13 +277,17 @@ gboolean ssl_init_socket_with_method(SockInfo *sockinfo, SSLMethod method)
 	if (session == NULL || r != 0)
 		return FALSE;
 
-#if GNUTLS_VERSION_NUMBER < 0x030003
-	gnutls_transport_set_lowat (session, 0); 
-#endif
-	if (method == 0)
-		gnutls_priority_set_direct(session, "NORMAL:-VERS-TLS1.0:-VERS-TLS1.1:-VERS-TLS1.2", NULL);
-	else
-		gnutls_priority_set_direct(session, "NORMAL", NULL);
+	if (sockinfo->gnutls_priority && strlen(sockinfo->gnutls_priority)) {
+		r = gnutls_priority_set_direct(session, sockinfo->gnutls_priority, NULL);
+		debug_print("Setting GnuTLS priority to %s, status = %d\n",
+			    sockinfo->gnutls_priority, r);
+	}
+	else {
+		if (method == 0)
+			gnutls_priority_set_direct(session, "NORMAL:-VERS-TLS1.0:-VERS-TLS1.1:-VERS-TLS1.2", NULL);
+		else
+			gnutls_priority_set_direct(session, "NORMAL", NULL);
+	}
 	gnutls_record_disable_padding(session);
 
 	gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, xcred);
@@ -286,9 +303,13 @@ gboolean ssl_init_socket_with_method(SockInfo *sockinfo, SSLMethod method)
 	}
 	gnutls_certificate_set_verify_flags (xcred, GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT);
 
-	gnutls_transport_set_ptr(session, (gnutls_transport_ptr) sockinfo->sock);
+	gnutls_transport_set_ptr(session, (gnutls_transport_ptr_t) GINT_TO_POINTER(sockinfo->sock));
 	gnutls_session_set_ptr(session, sockinfo);
+#if GNUTLS_VERSION_NUMBER <= 0x020c00
 	gnutls_certificate_client_set_retrieve_function(xcred, gnutls_client_cert_cb);
+#else
+	gnutls_certificate_set_retrieve_function(xcred, gnutls_cert_cb);
+#endif
 
 	gnutls_dh_set_prime_bits(session, 512);
 
@@ -314,7 +335,7 @@ gboolean ssl_init_socket_with_method(SockInfo *sockinfo, SSLMethod method)
 
 	r = gnutls_certificate_verify_peers2(session, &status);
 
-	if (!ssl_certificate_check(cert, status, sockinfo->hostname, sockinfo->port)) {
+	if (r < 0 || !ssl_certificate_check(cert, status, sockinfo->hostname, sockinfo->port)) {
 		gnutls_x509_crt_deinit(cert);
 		gnutls_certificate_free_credentials(xcred);
 		gnutls_deinit(session);
@@ -331,7 +352,8 @@ gboolean ssl_init_socket_with_method(SockInfo *sockinfo, SSLMethod method)
 void ssl_done_socket(SockInfo *sockinfo)
 {
 	if (sockinfo && sockinfo->ssl) {
-		gnutls_certificate_free_credentials(sockinfo->xcred);
+		if (sockinfo->xcred)
+			gnutls_certificate_free_credentials(sockinfo->xcred);
 		gnutls_deinit(sockinfo->ssl);
 		if (sockinfo->client_crt)
 			gnutls_x509_crt_deinit(sockinfo->client_crt);
@@ -339,6 +361,7 @@ void ssl_done_socket(SockInfo *sockinfo)
 			gnutls_x509_privkey_deinit(sockinfo->client_key);
 		sockinfo->client_key = NULL;
 		sockinfo->client_crt = NULL;
+		sockinfo->xcred = NULL;
 		sockinfo->ssl = NULL;
 	}
 }
