@@ -21,7 +21,7 @@
 #define __SSL_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 typedef enum {
