@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #define __UTILS_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #ifdef HAVE_BACKTRACE
@@ -278,6 +278,7 @@ gboolean superuser_p (void);
 
 void list_free_strings		(GList		*list);
 void slist_free_strings		(GSList		*list);
+void slist_free_strings_full	(GSList		*list);
 
 void hash_free_strings		(GHashTable	*table);
 
@@ -308,6 +309,9 @@ gchar *strcrchomp	(gchar		*str);
 gint file_strip_crs	(const gchar 	*file);
 gchar *strcasestr	(const gchar	*haystack,
 			 const gchar	*needle);
+gchar *strncasestr	(const gchar	*haystack,
+			 gint		 haystack_len,
+			 const gchar	*needle);
 gpointer my_memmem	(gconstpointer	 haystack,
 			 size_t		 haystacklen,
 			 gconstpointer	 needle,
@@ -334,6 +338,8 @@ void extract_parenthesis		(gchar		*str,
 
 void extract_quote			(gchar		*str,
 					 gchar		 quote_chr);
+gchar *escape_internal_quotes		(gchar		*str,
+					 gchar		 quote_chr);
 void eliminate_address_comment		(gchar		*str);
 gchar *strchr_with_skip_quote		(const gchar	*str,
 					 gint		 quote_chr,
@@ -583,6 +589,11 @@ gboolean sc_g_list_bigger(GList *list, gint max);
 gboolean sc_g_slist_bigger(GSList *list, gint max);
 
 int claws_unlink(const gchar *filename);
+
+GMutex *cm_mutex_new(void);
+void cm_mutex_free(GMutex *mutex);
+
+int cm_canonicalize_filename(const gchar *filename, gchar **canonical_name);
 #ifdef __cplusplus
 }
 #endif
