@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,14 +28,12 @@ typedef struct _AttachInfo	AttachInfo;
 
 #include "procmsg.h"
 #include "procmime.h"
-#include "addressbook.h"
 #include "prefs_account.h"
 #include "undo.h"
 #include "toolbar.h"
-#include "messageview.h"
 #include "codeconv.h"
 #include "template.h"
-#include "textview.h"
+#include "viewtypes.h"
 #include "folder.h"
 
 #ifdef USE_ENCHANT
@@ -52,7 +50,8 @@ typedef enum
 	COMPOSE_BCC,
 	COMPOSE_REPLYTO,
 	COMPOSE_NEWSGROUPS,
-	COMPOSE_FOLLOWUPTO
+	COMPOSE_FOLLOWUPTO,
+	COMPOSE_INREPLYTO
 } ComposeEntryType;
 
 typedef enum
@@ -61,6 +60,7 @@ typedef enum
 	COMPOSE_REPLY_WITH_QUOTE,
 	COMPOSE_REPLY_WITHOUT_QUOTE,
 	COMPOSE_REPLY_TO_SENDER,
+	COMPOSE_REPLY_TO_ADDRESS,
 	COMPOSE_FOLLOWUP_AND_REPLY_TO,
 	COMPOSE_REPLY_TO_SENDER_WITH_QUOTE,
 	COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE,
@@ -113,6 +113,7 @@ struct _Compose
 	/* Header */
 	GtkWidget *table_vbox;
 	GtkWidget *table;
+	GtkWidget *account_combo;
 	GtkWidget *subject_entry;
 	GtkWidget *paned;
 
@@ -258,6 +259,7 @@ struct _AttachInfo
 	EncodingType encoding;
 	gchar *name;
 	goffset size;
+	gchar *charset;
 };
 
 typedef enum
@@ -272,7 +274,7 @@ typedef enum
 /* attache_files will be locale encode */
 Compose *compose_new			(PrefsAccount	*account,
 				 	 const gchar	*mailto,
-				 	 GPtrArray	*attach_files);
+				 	 GList		*attach_files);
 
 Compose *compose_new_with_folderitem	(PrefsAccount	*account,
 					 FolderItem	*item,
@@ -312,6 +314,9 @@ void compose_destroy_all                (void);
 gboolean compose_draft	                (gpointer data, guint action);
 void compose_toolbar_cb			(gint 		action, 
 					 gpointer 	data);
+void compose_reply_to_address		(MessageView	*msgview,
+					 MsgInfo	*msginfo,
+					 const gchar	*address);
 void compose_reply_from_messageview	(MessageView 	*msgview, 
 					 GSList 	*msginfo_list, 
 					 guint 		 action);
@@ -335,4 +340,5 @@ void compose_close_toolbar		(Compose *compose);
 void compose_clear_exit_drafts		(void);
 void compose_reopen_exit_drafts		(void);
 void compose_attach_from_list (Compose *compose, GList *file_list, gboolean free_data);
+void compose_check_for_email_account(Compose *compose);
 #endif /* __COMPOSE_H__ */
