@@ -42,7 +42,7 @@
 #	include <sys/utsname.h>
 #endif
 
-#if defined(__GNU_LIBRARY__)
+#if defined(__GNU_LIBRARY__) && !defined(__UCLIBC__)
 #	include <gnu/libc-version.h>
 #endif
 
@@ -53,6 +53,7 @@
 #include "filesel.h"
 #include "version.h"
 #include "prefs_common.h"
+#include "manage_window.h"
 
 /*
  * NOTE: the crash dialog is called when claws is not 
@@ -272,6 +273,8 @@ static GtkWidget *crash_dialog_show(const gchar *text, const gchar *debug_output
 	g_signal_connect(G_OBJECT(button5), "clicked",
 			 G_CALLBACK(crash_create_bug_report), NULL);
 
+	MANAGE_WINDOW_SIGNALS_CONNECT(window1);
+
 	gtk_widget_show(window1);
 
 	gtk_main();
@@ -403,9 +406,6 @@ static void crash_debug(unsigned long crash_pid,
 static const gchar *get_compiled_in_features(void)
 {
 	return g_strdup_printf("%s",
-#if USE_THREADS
-		   " gthread"
-#endif
 #if INET6
 		   " IPv6"
 #endif
@@ -443,7 +443,9 @@ static const gchar *get_compiled_in_features(void)
  */
 static const gchar *get_lib_version(void)
 {
-#if defined(__GNU_LIBRARY__)
+#if defined(__UCLIBC__)
+	return g_strdup_printf("uClibc %i.%i.%i", __UCLIBC_MAJOR__, __UCLIBC_MINOR__, __UCLIBC_SUBLEVEL__);
+#elif defined(__GNU_LIBRARY__)
 	return g_strdup_printf("GNU libc %s", gnu_get_libc_version());
 #else
 	return g_strdup(_("Unknown"));
