@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -29,6 +30,7 @@
 #include <gtk/gtk.h>
 
 #include "alertpanel.h"
+#include "stock_pixmap.h"
 #include "mgutils.h"
 #include "addressbook.h"
 #include "addressitem.h"
@@ -882,7 +884,6 @@ static void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 	GtkWidget *entry_nn;
 	const gchar *locale;
 	gint top = 0;
-	GtkActionGroup *action_group;
 
 	vbox = gtk_vbox_new( FALSE, 20 );
 	hbox = gtk_hbox_new( FALSE, 8 );
@@ -890,7 +891,7 @@ static void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 	gtk_widget_show( vbox );	
 
 	if (!editaddr_popup_menu) {
-		action_group = cm_menu_create_action_group("EditAddressPopup", editaddr_popup_entries,
+		cm_menu_create_action_group("EditAddressPopup", editaddr_popup_entries,
 			G_N_ELEMENTS(editaddr_popup_entries), (gpointer)NULL);
 		MENUITEM_ADDUI("/Menus", "EditAddressPopup", "EditAddressPopup", GTK_UI_MANAGER_MENU)
 		MENUITEM_ADDUI("/Menus/EditAddressPopup", "SetPicture", "EditAddressPopup/SetPicture", GTK_UI_MANAGER_MENUITEM)
@@ -922,15 +923,8 @@ static void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 		GTK_NOTEBOOK( personeditdlg.notebook ),
 		gtk_notebook_get_nth_page( GTK_NOTEBOOK( personeditdlg.notebook ), pageNum ), label );
 	
-#ifndef MAEMO
 	g_signal_connect(G_OBJECT(ebox_picture), "popup-menu",
 			 G_CALLBACK(addressbook_edit_person_picture_popup_menu), NULL);
-#else
-	gtk_widget_tap_and_hold_setup(GTK_WIDGET(ebox_picture), NULL, NULL,
-			GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS);
-	g_signal_connect(G_OBJECT(ebox_picture), "tap-and-hold",
-			 G_CALLBACK(addressbook_edit_person_picture_popup_menu), NULL);
-#endif
 	g_signal_connect(G_OBJECT(ebox_picture), "button_press_event", 
 			G_CALLBACK(addressbook_edit_person_set_picture_cb), NULL);
 
@@ -1327,7 +1321,11 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, top, (top + 1), GTK_FILL, 0, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	entry_name = gtk_combo_box_entry_new_text ();
+#else
+	entry_name = gtk_combo_box_text_new_with_entry ();
+#endif
 	gtk_table_attach(GTK_TABLE(table), entry_name, 1, 2, top, (top + 1), GTK_EXPAND|GTK_SHRINK|GTK_FILL, 0, 0, 0);
 
 	/* Next row */
@@ -1343,7 +1341,11 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	entry_name = gtk_combo_box_entry_new_text ();
+#else
+	entry_name = gtk_combo_box_text_new_with_entry ();
+#endif
 	gtk_table_attach(GTK_TABLE(table), entry_name, 1, 2, 0, 1, GTK_EXPAND|GTK_SHRINK|GTK_FILL, 0, 0, 0);
 
 	/* Next row */
@@ -1357,9 +1359,13 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 #endif
 	gtk_combo_box_set_active(GTK_COMBO_BOX(entry_name), -1);
 	if (prefs_common.addressbook_custom_attributes)
+#if !GTK_CHECK_VERSION(2, 24, 0)
 		combobox_set_popdown_strings(GTK_COMBO_BOX(entry_name),
 				prefs_common.addressbook_custom_attributes);
-
+#else
+		combobox_set_popdown_strings(GTK_COMBO_BOX_TEXT(entry_name),
+				prefs_common.addressbook_custom_attributes);		
+#endif
 	/* Button box */
 	vboxb = gtk_vbox_new( FALSE, 4 );
 	gtk_box_pack_start(GTK_BOX(hbox), vboxb, FALSE, FALSE, 2);
@@ -1751,10 +1757,19 @@ no_img:
 void addressbook_edit_reload_attr_list( void )
 {
 	if (personeditdlg.entry_atname) {
+#if !GTK_CHECK_VERSION(2, 24, 0)
 		combobox_unset_popdown_strings(GTK_COMBO_BOX(personeditdlg.entry_atname));
+#else		
+		combobox_unset_popdown_strings(GTK_COMBO_BOX_TEXT(personeditdlg.entry_atname));
+#endif
 		if (prefs_common.addressbook_custom_attributes)
+#if !GTK_CHECK_VERSION(2, 24, 0)
 			combobox_set_popdown_strings(GTK_COMBO_BOX(personeditdlg.entry_atname),
 					prefs_common.addressbook_custom_attributes);
+#else		
+			combobox_set_popdown_strings(GTK_COMBO_BOX_TEXT(personeditdlg.entry_atname),
+					prefs_common.addressbook_custom_attributes);
+#endif
 	}
 }
 
