@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2007-2012 The Claws Mail Team
+ * Copyright (C) 2007-2013 The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -235,7 +236,7 @@ static void apply_popup_delete (GtkAction *action, gpointer data)
 
 static void apply_popup_delete_all (GtkAction *action, gpointer data)
 {
-	GSList *cur;
+	GSList *cur, *tags;
 	GtkTreeModel *model;
 	SummaryView *summaryview = NULL;
 	
@@ -251,13 +252,14 @@ static void apply_popup_delete_all (GtkAction *action, gpointer data)
 
 	if (mainwindow_get_mainwindow() != NULL)
 		summaryview = mainwindow_get_mainwindow()->summaryview;
-	cur = tags_get_list();
+	cur = tags = tags_get_list();
 	for (; cur; cur = cur->next) {
 		gint id = GPOINTER_TO_INT(cur->data);
 		if (summaryview)
 			summary_set_tag(summaryview, -id, NULL);
 		tags_remove_tag(id);
 	}
+	g_slist_free(tags);
 	tags_write_tags();
 
 	APPLYWINDOW_UNLOCK();
@@ -273,7 +275,6 @@ static GtkActionEntry apply_popup_actions[] =
 static gint apply_list_btn_pressed(GtkWidget *widget, GdkEventButton *event,
 				    GtkTreeView *list_view)
 {
-	GtkActionGroup *actions;
 	GtkUIManager *gui_manager = gtkut_ui_manager();
 
 	if (applywindow.busy)
@@ -285,7 +286,7 @@ static gint apply_list_btn_pressed(GtkWidget *widget, GdkEventButton *event,
 		gboolean non_empty;
 
 		if (!apply_popup_menu) {
-			actions = cm_menu_create_action_group("EditTags", apply_popup_actions,
+			(void) cm_menu_create_action_group("EditTags", apply_popup_actions,
 					G_N_ELEMENTS(apply_popup_actions), (gpointer)list_view);
 
 			MENUITEM_ADDUI("/Menus", "EditTags", "EditTags", GTK_UI_MANAGER_MENU)
@@ -344,15 +345,8 @@ static GtkWidget *apply_window_list_view_create	(void)
 	/* create the columns */
 	apply_window_create_list_view_columns(GTK_WIDGET(list_view));
 
-#ifndef MAEMO
 	g_signal_connect(G_OBJECT(list_view), "popup-menu",
 			 G_CALLBACK(apply_list_popup_menu), list_view);
-#else
-	gtk_widget_tap_and_hold_setup(GTK_WIDGET(list_view), NULL, NULL,
-			GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS);
-	g_signal_connect(G_OBJECT(list_view), "tap-and-hold",
-			 G_CALLBACK(apply_list_popup_menu), list_view);
-#endif
 	g_signal_connect(G_OBJECT(list_view), "button-press-event",
 			G_CALLBACK(apply_list_btn_pressed), list_view);
 	return GTK_WIDGET(list_view);
@@ -525,7 +519,7 @@ static void apply_window_create(void)
 
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "tag_apply_window");
 	gtk_window_set_title (GTK_WINDOW(window),
-			      Q_("Dialog title|Apply tags"));
+			      C_("Dialog title", "Apply tags"));
 
 	gtk_container_set_border_width (GTK_CONTAINER (window), 8);
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
@@ -755,13 +749,14 @@ static void apply_window_list_view_insert_tag(GtkWidget *list_view,
 
 static void apply_window_load_tags (void) 
 {
-	GSList *cur;
+	GSList *cur, *tags;
 	gint id;
 	apply_window_list_view_clear_tags(applywindow.taglist);
 	
-	cur = tags_get_list();
+	cur = tags = tags_get_list();
 	for (; cur; cur = cur->next) {
 		id = GPOINTER_TO_INT(cur->data);
 		apply_window_list_view_insert_tag(applywindow.taglist, NULL, id);
 	}
+	g_slist_free(tags);
 }
