@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #ifdef HAVE_LIBETPAN
@@ -60,12 +61,9 @@ static GIOChannel * io_channel = NULL;
 static void delete_imap(Folder *folder, mailimap *imap)
 {
 	chashdatum key;
-	chashdatum value;
 
 	key.data = &folder;
 	key.len = sizeof(folder);
-	value.data = imap;
-	value.len = 0;
 	chash_delete(session_hash, &key, NULL);
 	
 	key.data = &imap;
@@ -525,8 +523,8 @@ static int etpan_certificate_check(const unsigned char *certificate, int len, vo
 {
 #ifdef USE_GNUTLS
 	struct connect_param *param = (struct connect_param *)data;
-	gnutls_x509_crt cert = NULL;
-	gnutls_datum tmp;
+	gnutls_x509_crt_t cert = NULL;
+	gnutls_datum_t tmp;
 	
 	if (certificate == NULL || len < 0) {
 		g_warning("no cert presented.\n");
@@ -558,8 +556,8 @@ static void connect_ssl_context_cb(struct mailstream_ssl_context * ssl_context,
 	PrefsAccount *account = (PrefsAccount *)data;
 	const gchar *cert_path = NULL;
 	const gchar *password = NULL;
-	gnutls_x509_crt x509 = NULL;
-	gnutls_x509_privkey pkey = NULL;
+	gnutls_x509_crt_t x509 = NULL;
+	gnutls_x509_privkey_t pkey = NULL;
 
 	if (account->in_ssl_client_cert_file && *account->in_ssl_client_cert_file)
 		cert_path = account->in_ssl_client_cert_file;
@@ -1555,7 +1553,9 @@ int imap_threaded_examine(Folder * folder, const char * mb,
 struct search_param {
 	mailimap * imap;
 	int type;
+	const char *charset;
 	struct mailimap_set * set;
+	IMAPSearchKey* key;
 };
 
 struct search_result {
@@ -1590,9 +1590,9 @@ static void search_run(struct etpan_thread_op * op)
 	int r;
 	struct mailimap_search_key * key = NULL;
 	struct mailimap_search_key * uid_key = NULL;
-	struct mailimap_search_key * search_type_key;
+	struct mailimap_search_key * search_type_key = NULL;
 	clist * search_result;
-	
+
 	param = op->param;
 	result = op->result;
 
@@ -1604,70 +1604,33 @@ static void search_run(struct etpan_thread_op * op)
 	} else if (param->type == IMAP_SEARCH_TYPE_SIMPLE) {
 		uid_key = mailimap_search_key_new_all();
 	}
-	search_type_key = NULL;
 	switch (param->type) {
 	case IMAP_SEARCH_TYPE_SIMPLE:
 		search_type_key = NULL;
 		break;
-		
 	case IMAP_SEARCH_TYPE_SEEN:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_SEEN,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_READ, NULL, NULL, 0);
 		break;
-		
 	case IMAP_SEARCH_TYPE_UNSEEN:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_UNSEEN,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_UNREAD, NULL, NULL, 0);
 		break;
-		
 	case IMAP_SEARCH_TYPE_ANSWERED:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_ANSWERED,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_REPLIED, NULL, NULL, 0);
 		break;
-		
 	case IMAP_SEARCH_TYPE_FLAGGED:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_FLAGGED,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_MARKED, NULL, NULL, 0);
 		break;
 	case IMAP_SEARCH_TYPE_DELETED:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_DELETED,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_DELETED, NULL, NULL, 0);
 		break;
 	case IMAP_SEARCH_TYPE_FORWARDED:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_KEYWORD,
-							  NULL, NULL, NULL, NULL, NULL,
-							  strdup(RTAG_FORWARDED), NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_TAG, NULL, RTAG_FORWARDED, 0);
 		break;
 	case IMAP_SEARCH_TYPE_SPAM:
-		search_type_key = mailimap_search_key_new(MAILIMAP_SEARCH_KEY_KEYWORD,
-							  NULL, NULL, NULL, NULL, NULL,
-							  strdup(RTAG_JUNK), NULL, NULL, NULL, NULL,
-							  NULL, NULL, NULL, NULL, 0,
-							  NULL, NULL, NULL, NULL, NULL,
-							  NULL, 0, NULL, NULL, NULL);
+		search_type_key = imap_search_new(IMAP_SEARCH_CRITERIA_TAG, NULL, RTAG_JUNK, 0);
+		break;
+	case IMAP_SEARCH_TYPE_KEYED:
+		search_type_key = param->key;
 		break;
 	}
 	
@@ -1691,7 +1654,7 @@ static void search_run(struct etpan_thread_op * op)
 	} else {
 		mailstream_logger = imap_logger_uid;
 
-		r = mailimap_uid_search(param->imap, NULL, key, &search_result);
+		r = mailimap_uid_search(param->imap, param->charset, key, &search_result);
 
 		mailstream_logger = imap_logger_cmd;
 
@@ -1704,8 +1667,9 @@ static void search_run(struct etpan_thread_op * op)
 	debug_print("imap search run - end %i\n", result->error);
 }
 
-int imap_threaded_search(Folder * folder, int search_type,
-			 struct mailimap_set * set, clist ** search_result)
+int imap_threaded_search(Folder * folder, int search_type, IMAPSearchKey* key,
+			 const char *charset, struct mailimap_set * set,
+			 clist ** search_result)
 {
 	struct search_param param;
 	struct search_result result;
@@ -1716,8 +1680,10 @@ int imap_threaded_search(Folder * folder, int search_type,
 	imap = get_imap(folder);
 	param.imap = imap;
 	param.set = set;
+	param.charset = charset;
 	param.type = search_type;
-	
+	param.key = key;
+
 	threaded_run(folder, &param, &result, search_run);
 	
 	if (result.error != MAILIMAP_NO_ERROR)
@@ -1731,6 +1697,160 @@ int imap_threaded_search(Folder * folder, int search_type,
 }
 
 
+struct _IMAPSearchKey {
+	struct mailimap_search_key* key;
+};
+
+IMAPSearchKey*	imap_search_new(gint		 criteria, 
+				const gchar	*header,
+				const gchar	*expr,
+				int		 value)
+{
+	char* sk_bcc = NULL;
+	struct mailimap_date* sk_before = NULL;
+	char* sk_body = NULL;
+	char* sk_cc = NULL;
+	char* sk_from = NULL;
+	char* sk_keyword = NULL;
+	struct mailimap_date* sk_on = NULL;
+	struct mailimap_date* sk_since = NULL;
+	char* sk_subject = NULL;
+	char* sk_text = NULL;
+	char* sk_to = NULL;
+	char* sk_unkeyword = NULL;
+	char* sk_header_name = NULL;
+	char* sk_header_value = NULL;
+	uint32_t sk_larger = 0;
+	struct mailimap_search_key* sk_not = NULL;
+	struct mailimap_search_key* sk_or1 = NULL;
+	struct mailimap_search_key* sk_or2 = NULL;
+	struct mailimap_date* sk_sentbefore = NULL;
+	struct mailimap_date* sk_senton = NULL;
+	struct mailimap_date* sk_sentsince = NULL;
+	uint32_t sk_smaller = 0;
+	struct mailimap_set* sk_uid = NULL;
+	struct mailimap_set* sk_set = NULL;
+	clist* sk_multiple = NULL;
+	int etpan_matcher_type;
+
+	switch (criteria) {
+	case IMAP_SEARCH_CRITERIA_ALL: etpan_matcher_type = MAILIMAP_SEARCH_KEY_ALL; break;
+	case IMAP_SEARCH_CRITERIA_READ: etpan_matcher_type = MAILIMAP_SEARCH_KEY_SEEN; break;
+	case IMAP_SEARCH_CRITERIA_UNREAD: etpan_matcher_type = MAILIMAP_SEARCH_KEY_UNSEEN; break;
+	case IMAP_SEARCH_CRITERIA_NEW: etpan_matcher_type = MAILIMAP_SEARCH_KEY_NEW; break;
+	case IMAP_SEARCH_CRITERIA_MARKED: etpan_matcher_type = MAILIMAP_SEARCH_KEY_FLAGGED; break;
+	case IMAP_SEARCH_CRITERIA_REPLIED: etpan_matcher_type = MAILIMAP_SEARCH_KEY_ANSWERED; break;
+	case IMAP_SEARCH_CRITERIA_DELETED: etpan_matcher_type = MAILIMAP_SEARCH_KEY_DELETED; break;
+
+	case IMAP_SEARCH_CRITERIA_TAG:
+		sk_keyword = strdup(expr);
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_KEYWORD;
+		break;
+
+	case IMAP_SEARCH_CRITERIA_SUBJECT:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_SUBJECT;
+		sk_subject = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_TO:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_TO;
+		sk_to = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_CC:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_CC;
+		sk_cc = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_AGE_GREATER:
+	case IMAP_SEARCH_CRITERIA_AGE_LOWER:
+		{
+			struct tm tm;
+			time_t limit = time(NULL) - 60 * 60 * 24 * value;
+
+			tzset();
+			localtime_r(&limit, &tm);
+			if (criteria == IMAP_SEARCH_CRITERIA_AGE_GREATER) {
+				etpan_matcher_type = MAILIMAP_SEARCH_KEY_SENTBEFORE;
+				sk_sentbefore = mailimap_date_new(tm.tm_mday, tm.tm_mon, tm.tm_year + 1900);
+			} else {
+				etpan_matcher_type = MAILIMAP_SEARCH_KEY_SENTSINCE;
+				sk_sentsince = mailimap_date_new(tm.tm_mday, tm.tm_mon, tm.tm_year + 1900);
+			}
+			break;
+		}
+
+	case IMAP_SEARCH_CRITERIA_BODY:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_BODY;
+		sk_body = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_MESSAGE:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_TEXT;
+		sk_text = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_HEADER:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_HEADER;
+		sk_header_name = strdup(header);
+		sk_header_value = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_FROM:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_FROM;
+		sk_from = strdup(expr);
+		break;
+
+	case IMAP_SEARCH_CRITERIA_SIZE_GREATER:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_LARGER;
+		sk_larger = value;
+		break;
+
+	case IMAP_SEARCH_CRITERIA_SIZE_SMALLER:
+		etpan_matcher_type = MAILIMAP_SEARCH_KEY_SMALLER;
+		sk_smaller = value;
+		break;
+
+	default:
+		return NULL;
+	}
+
+	return mailimap_search_key_new(etpan_matcher_type,
+		sk_bcc, sk_before, sk_body, sk_cc, sk_from, sk_keyword,
+		sk_on, sk_since, sk_subject, sk_text, sk_to,
+		sk_unkeyword, sk_header_name,sk_header_value, sk_larger,
+		sk_not, sk_or1, sk_or2, sk_sentbefore, sk_senton,
+		sk_sentsince, sk_smaller, sk_uid, sk_set, sk_multiple);
+}
+
+IMAPSearchKey* imap_search_not(IMAPSearchKey* key)
+{
+	return mailimap_search_key_new_not(key);
+}
+
+IMAPSearchKey* imap_search_or(IMAPSearchKey* l, IMAPSearchKey* r)
+{
+	return mailimap_search_key_new_or(l, r);
+}
+
+IMAPSearchKey* imap_search_and(IMAPSearchKey* l, IMAPSearchKey* r)
+{
+	IMAPSearchKey* result = mailimap_search_key_new_multiple_empty();
+	mailimap_search_key_multiple_add(result, l);
+	mailimap_search_key_multiple_add(result, r);
+
+	return result;
+}
+
+void imap_search_free(IMAPSearchKey* key)
+{
+	if (!key)
+	    return;
+
+	mailimap_search_key_free(key);
+}
+
+
 
 static int imap_get_msg_att_info(struct mailimap_msg_att * msg_att,
 				 uint32_t * puid,
@@ -2019,8 +2139,7 @@ result_to_uid_flags_list(clist * fetch_result, carray ** result)
   
  free_list:
 	imap_fetch_uid_flags_list_free(tab);
-	slist_free_strings(tags);
-	g_slist_free(tags);
+	slist_free_strings_full(tags);
  err:
 	return res;
 }
@@ -2648,10 +2767,8 @@ imap_fetch_result_to_envelop_list(clist * fetch_result,
 				  carray ** p_env_list)
 {
 	clistiter * cur;
-	unsigned int i;
 	carray * env_list;
 
-	i = 0;
 	env_list = carray_new(16);
   
   	if (fetch_result) {
@@ -2680,30 +2797,24 @@ imap_fetch_result_to_envelop_list(clist * fetch_result,
 static int imap_add_envelope_fetch_att(struct mailimap_fetch_type * fetch_type)
 {
 	struct mailimap_fetch_att * fetch_att;
-	int r;
+	int i;
 	char * header;
 	clist * hdrlist;
 	struct mailimap_header_list * imap_hdrlist;
 	struct mailimap_section * section;
+	char *headers[] = {
+			"Date", "From", "To", "Cc", "Subject", "Message-ID",
+			"References", "In-Reply-To", NULL
+		};
 
 	hdrlist = clist_new();
-  
-	header = strdup("Date");
-	r = clist_append(hdrlist, header);
-	header = strdup("From");
-	r = clist_append(hdrlist, header);
-	header = strdup("To");
-	r = clist_append(hdrlist, header);
-	header = strdup("Cc");
-	r = clist_append(hdrlist, header);
-	header = strdup("Subject");
-	r = clist_append(hdrlist, header);
-	header = strdup("Message-ID");
-	r = clist_append(hdrlist, header);
-	header = strdup("References");
-	r = clist_append(hdrlist, header);
-	header = strdup("In-Reply-To");
-	r = clist_append(hdrlist, header);
+	i = 0;
+	while (headers[i] != NULL) {
+  		header = strdup(headers[i]);
+		if (header == NULL || clist_append(hdrlist, header) != 0)
+			return MAIL_ERROR_MEMORY;
+		++i;
+	}
   
 	imap_hdrlist = mailimap_header_list_new(hdrlist);
 	section = mailimap_section_new_header_fields(imap_hdrlist);
