@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #ifdef HAVE_LIBETPAN
@@ -45,6 +46,8 @@
 #include "ssl_certificate.h"
 #include "socket.h"
 #include "remotefolder.h"
+#include "main.h"
+#include "account.h"
 
 #define DISABLE_LOG_DURING_LOGIN
 
@@ -95,12 +98,9 @@ static void nntp_logger(int direction, const char * str, size_t size)
 static void delete_nntp(Folder *folder, newsnntp *nntp)
 {
 	chashdatum key;
-	chashdatum value;
 
 	key.data = &folder;
 	key.len = sizeof(folder);
-	value.data = nntp;
-	value.len = 0;
 	chash_delete(session_hash, &key, NULL);
 	
 	key.data = &nntp;
@@ -160,6 +160,7 @@ void nntp_main_init(gboolean skip_ssl_cert_check)
 
 void nntp_main_done(gboolean have_connectivity)
 {
+	nntp_disconnect_all(have_connectivity);
 	etpan_thread_manager_stop(thread_manager);
 #if defined(__NetBSD__) || defined(__OpenBSD__) || defined(__FreeBSD__)
 	return;
@@ -376,8 +377,8 @@ static int etpan_certificate_check(const unsigned char *certificate, int len, vo
 {
 #ifdef USE_GNUTLS
 	struct connect_param *param = (struct connect_param *)data;
-	gnutls_x509_crt cert = NULL;
-	gnutls_datum tmp;
+	gnutls_x509_crt_t cert = NULL;
+	gnutls_datum_t tmp;
 	
 	if (certificate == NULL || len < 0) {
 		g_warning("no cert presented.\n");
@@ -409,8 +410,8 @@ static void connect_ssl_context_cb(struct mailstream_ssl_context * ssl_context,
 	PrefsAccount *account = (PrefsAccount *)data;
 	const gchar *cert_path = NULL;
 	const gchar *password = NULL;
-	gnutls_x509_crt x509 = NULL;
-	gnutls_x509_privkey pkey = NULL;
+	gnutls_x509_crt_t x509 = NULL;
+	gnutls_x509_privkey_t pkey = NULL;
 
 	if (account->in_ssl_client_cert_file && *account->in_ssl_client_cert_file)
 		cert_path = account->in_ssl_client_cert_file;
@@ -773,7 +774,7 @@ int nntp_threaded_article(Folder * folder, guint32 num, char **contents, size_t
 
 	threaded_run(folder, &param, &result, article_run);
 	
-	debug_print("nntp post - end\n");
+	debug_print("nntp article - end\n");
 	
 	return result.error;
 }
@@ -970,6 +971,11 @@ int nntp_threaded_xhdr(Folder * folder, const char *header, guint32 beg, guint32
 	return result.error;
 }
 
+void nntp_main_set_timeout(int sec)
+{
+	mailstream_network_delay.tv_sec = sec;
+	mailstream_network_delay.tv_usec = 0;
+}
 
 #else
 
