@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -470,15 +470,8 @@ static GtkWidget *folderview_ctree_create(FolderView *folderview)
 	g_signal_connect(G_OBJECT(ctree), "button_press_event",
 			 G_CALLBACK(folderview_button_pressed),
 			 folderview);
-#ifndef MAEMO
 	g_signal_connect(G_OBJECT(ctree), "popup-menu",
 			 G_CALLBACK(folderview_popup_menu), folderview);
-#else
-	gtk_widget_tap_and_hold_setup(GTK_WIDGET(ctree), NULL, NULL,
-			GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS);
-	g_signal_connect(G_OBJECT(ctree), "tap-and-hold",
-			 G_CALLBACK(folderview_popup_menu), folderview);
-#endif
 	g_signal_connect(G_OBJECT(ctree), "button_release_event",
 			 G_CALLBACK(folderview_button_released),
 			 folderview);
@@ -796,7 +789,7 @@ static void mark_all_read_cb(GtkAction *action, gpointer data)
 	&&  prefs_common.ask_mark_all_read) {
 		val = alertpanel_full(_("Mark all as read"),
 			_("Do you really want to mark all mails in this "
-			  "folder as read ?"), GTK_STOCK_NO, GTK_STOCK_YES, NULL,
+			  "folder as read?"), GTK_STOCK_NO, GTK_STOCK_YES, NULL,
 			  TRUE, NULL, ALERT_QUESTION, G_ALERTDEFAULT);
 
 		if ((val & ~G_ALERTDISABLE) != G_ALERTALTERNATE)
@@ -1018,11 +1011,11 @@ static void folderview_set_folders(FolderView *folderview)
 static gchar *get_scan_str(FolderItem *item)
 {
 	if (item->path)
-		return g_strdup_printf(_("Scanning folder %s%c%s ..."),
+		return g_strdup_printf(_("Scanning folder %s%c%s..."),
 				      item->folder->name, G_DIR_SEPARATOR,
 				      item->path);
 	else
-		return g_strdup_printf(_("Scanning folder %s ..."),
+		return g_strdup_printf(_("Scanning folder %s..."),
 				      item->folder->name);	
 }
 static void folderview_scan_tree_func(Folder *folder, FolderItem *item,
@@ -1713,7 +1706,7 @@ static gboolean folderview_update_item_claws(gpointer source, gpointer data)
 		if ((update_info->update_flags & F_ITEM_UPDATE_CONTENT) && 
 		     update_info->item == folderview->summaryview->folder_item &&
 		     update_info->item != NULL)
-			if (!quicksearch_is_active(folderview->summaryview->quicksearch))
+			if (!quicksearch_has_sat_predicate(folderview->summaryview->quicksearch))
 				summary_show(folderview->summaryview, update_info->item);
 	}
 	
@@ -2473,9 +2466,7 @@ static void folderview_recollapse_nodes(FolderView *folderview, GtkCMCTreeNode *
 void folderview_move_folder(FolderView *folderview, FolderItem *from_folder,
 		            FolderItem *to_folder, gboolean copy)
 {
-	FolderItem *from_parent = NULL;
 	FolderItem *new_folder = NULL;
-	GtkCMCTreeNode *src_node = NULL;
 	gchar *buf;
 	gint status;
 
@@ -2483,12 +2474,9 @@ void folderview_move_folder(FolderView *folderview, FolderItem *from_folder,
 	cm_return_if_fail(from_folder != NULL);
 	cm_return_if_fail(to_folder != NULL);
 
-	src_node = gtk_cmctree_find_by_row_data(GTK_CMCTREE(folderview->ctree), NULL, from_folder);
-	from_parent = folder_item_parent(from_folder);
-	
 	if (prefs_common.warn_dnd) {
-		buf = g_strdup_printf(copy ? _("Do you really want to copy folder '%s' in '%s' ?"):
-					     _("Do you really want to make folder '%s' a subfolder of '%s' ?"), 
+		buf = g_strdup_printf(copy ? _("Do you really want to copy folder '%s' in '%s'?"):
+					     _("Do you really want to make folder '%s' a subfolder of '%s'?"), 
 					from_folder->name, to_folder->name);
 		status = alertpanel_full(copy ? _("Copy folder"):_("Move folder"), buf,
 				       	 GTK_STOCK_NO, GTK_STOCK_YES, NULL, TRUE,
