@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -134,6 +135,11 @@ static GtkWidget *about_create_child_page_info(void)
 				"website:\n"), -1);
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, HOMEPAGE_URI, -1,
 				"link", NULL);
+	gtk_text_buffer_insert(buffer, &iter, _("\n\n"
+				"For support and discussion subscribe to the Claws Mail "
+				"users' mailing list:\n"),-1);
+	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, USERS_ML_URI, -1,
+				"link", NULL);
 	gtk_text_buffer_insert(buffer, &iter, _("\n\n"
 				"Claws Mail is free software released "
 				"under the GPL. If you wish to donate "
@@ -150,7 +156,7 @@ static GtkWidget *about_create_child_page_info(void)
 				NULL);
 #ifdef GENERIC_UMPC
 	gtk_text_buffer_insert(buffer, &iter, _(
-				"\n\nCopyright (C) 1999-2012\nThe Claws Mail Team\n"
+				"\n\nCopyright (C) 1999-2013\nThe Claws Mail Team\n"
 				" and Hiroyuki Yamamoto"), -1);
 #endif
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (_("\n\nSystem Information\n")), -1,
@@ -412,7 +418,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" compface "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("compface|adds support for the X-Face header\n"), -1);
+		(gchar *)C_("compface", "adds support for the X-Face header\n"), -1);
 
 #if USE_ENCHANT
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -422,7 +428,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" Enchant "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("Enchant|adds support for spell checking\n"), -1);
+		(gchar *)C_("Enchant", "adds support for spell checking\n"), -1);
 
 #if USE_GNUTLS
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -432,7 +438,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" GnuTLS "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("GnuTLS|adds support for encrypted connections to servers\n"), -1);
+		(gchar *)C_("GnuTLS", "adds support for encrypted connections to servers\n"), -1);
 
 #if INET6
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -442,7 +448,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" IPv6 "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("IPv6|adds support for IPv6 addresses, the new Internet "
+		(gchar *)C_("IPv6", "adds support for IPv6 addresses, the new Internet "
 			    "addressing protocol\n"), -1);
 
 #if HAVE_ICONV
@@ -453,7 +459,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" iconv "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("iconv|allows converting to and from different character sets\n"), -1);
+		(gchar *)C_("iconv", "allows converting to and from different character sets\n"), -1);
 
 #if USE_JPILOT
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -463,7 +469,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" JPilot "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("JPilot|adds support for PalmOS addressbooks\n"), -1);
+		(gchar *)C_("JPilot", "adds support for PalmOS addressbooks\n"), -1);
 
 #if USE_LDAP
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -473,7 +479,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" LDAP "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("LDAP|adds support for LDAP shared addressbooks\n"), -1);
+		(gchar *)C_("LDAP", "adds support for LDAP shared addressbooks\n"), -1);
 
 #if HAVE_LIBETPAN
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -483,7 +489,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" libetpan "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("libetpan|adds support for IMAP and NNTP servers\n"), -1);
+		(gchar *)C_("libetpan", "adds support for IMAP and NNTP servers\n"), -1);
 
 #if HAVE_LIBSM
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -493,7 +499,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" libSM "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("libSM|adds support for session handling\n"), -1);
+		(gchar *)C_("libSM", "adds support for session handling\n"), -1);
 
 #if HAVE_NETWORKMANAGER_SUPPORT
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -503,7 +509,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" NetworkManager "), -1,
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter,
-		(gchar *)Q_("NetworkManager|adds support for detection of network connection changes\n"), -1);
+		(gchar *)C_("NetworkManager", "adds support for detection of network connection changes\n"), -1);
 
 	return scrolledwin;
 }
@@ -693,11 +699,22 @@ static void about_update_stats(void)
 				(_("Session statistics\n")), -1,
 				"underlined-list-title", NULL);
 
-		g_snprintf(buf, sizeof(buf), _("Started: %s\n"),
-					ctime(&session_stats.time_started));
+		if (prefs_common.date_format) {
+			struct tm *lt;
+			gint len = 100;
+			gchar date[len];
+
+			lt = localtime(&session_stats.time_started);
+			fast_strftime(date, len, prefs_common.date_format, lt);
+			g_snprintf(buf, sizeof(buf), _("Started: %s\n"),
+						lt ? date : ctime(&session_stats.time_started));
+		} else
+			g_snprintf(buf, sizeof(buf), _("Started: %s\n"),
+						ctime(&session_stats.time_started));
 		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
 				"indented-list-item", NULL);
 
+		gtk_text_buffer_insert(stats_text_buffer, &iter, "\n", 1);
 		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter,
 				(_("Incoming traffic\n")), -1,
 				"underlined-list-title", NULL);
@@ -804,7 +821,7 @@ static void about_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox2), label, FALSE, FALSE, 0);
 	markup = g_markup_printf_escaped
 		("<span weight=\"bold\" size=\"xx-large\">Claws Mail</span>\nversion %s",
-		 VERSION);
+		 VERSION_GIT_FULL);
 	gtk_label_set_markup(GTK_LABEL(label), markup);
 	g_free(markup);
 
@@ -812,7 +829,7 @@ static void about_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 0);
 #ifndef GENERIC_UMPC
 	label = gtk_label_new
-		(_("Copyright (C) 1999-2012\nThe Claws Mail Team\n"
+		(_("Copyright (C) 1999-2013\nThe Claws Mail Team\n"
 		 "and Hiroyuki Yamamoto"));
 	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
