@@ -3,9 +3,9 @@ static char *TEAM_LIST[] = {
 "Tristan Chabredier <wwp@claws-mail.org>",
 "Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
-"Ricardo Mones Lastra <ricardo@mones.org>",
 "Colin Leroy <colin@colino.net>",
 "Paul Mangan <paul@claws-mail.org>",
+"Ricardo Mones Lastra <ricardo@mones.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>",
 "Paweł Pękala <c0rn@o2.pl>",
 "Michael Rasmussen <mir@datanom.net>",
@@ -71,7 +71,7 @@ NULL
 
 static char *ICONS_LIST[] = {
 "Jakub 'jimmac' Steiner <jimmac@ximian.com>",
-"Aleksandar Urosevic <urke@users.sf.net>",
+"Aleksandar Urošević <urke@users.sf.net>",
 NULL
 };
 
@@ -79,9 +79,11 @@ static char *CONTRIBS_LIST[] = {
 "Alte",
 "Jeremy Andrews",
 "Stephen Anthony",
+"André Filipe de Assunção e Brito",
 "Sergei Astanin",
 "Ruslan N. Balkin",
-"Fabio Junior Beneditto",
+"Henri Bauer",
+"Fabio Júnior Beneditto",
 "M. Benkmann",
 "Wilbert Berendsen",
 "Didier Barvaux",
@@ -90,7 +92,7 @@ static char *CONTRIBS_LIST[] = {
 "Jean-Luc Biord",
 "Pavlo Bohmat",
 "Eugene Brevdo",
-"André Filipe de Assunção e Brito",
+"Sean Buckheister",
 "Henrik Carlqvist",
 "Luca Cavalli",
 "David Chalmers",
@@ -99,11 +101,14 @@ static char *CONTRIBS_LIST[] = {
 "Tsu-Fan Cheng",
 "Manrat Chobchuen",
 "Rich Coe",
+"Natanael Copa",
 "Jonathan Corbet",
 "Christian Cornelssen",
 "George Danchev",
 "Matthieu Dazy",
+"Ben Deering",
 "Pierric Descamps",
+"Rodrigo Dias Arruda Senra",
 "Frank Dietrich",
 "Tim Dijkstra",
 "Nicolas Doualot",
@@ -119,12 +124,14 @@ static char *CONTRIBS_LIST[] = {
 "Lars Persson Fink",
 "Bob Forsman",
 "Matthias Förste",
+"Ivan Francolin Martinez",
 "Stoyan Genov",
 "Stavros Giannouris",
 "Thomas Gilgin",
 "Marius Glauser",
 "Thierry Godefroy",
 "Alex Gorbachenko",
+"Michał Górny",
 "Bodo Graumann",
 "Yang Guilong",
 "Daniel Gustafson",
@@ -137,6 +144,7 @@ static char *CONTRIBS_LIST[] = {
 "Federico Heinz",
 "Geir Helland",
 "Jorge Van Hemelryck",
+"Christian Hesse",
 "Higuchi",
 "Hiramatu",
 "Marc Hoper",
@@ -162,6 +170,7 @@ static char *CONTRIBS_LIST[] = {
 "Fabian Keil",
 "Martin Kluge",
 "IWAMOTO Kouichi",
+"Abhay S. Kushwaha",
 "Joshua M. Kwan",
 "Jean-Yves Lefort",
 "Jérôme Lelong",
@@ -172,8 +181,8 @@ static char *CONTRIBS_LIST[] = {
 "Alessandro Maestri",
 "Maki",
 "Jindrich Makovicka",
+"Igor Mammedov",
 "Tim Mann",
-"Ivan Francolin Martinez",
 "HIRAMATSU Masami",
 "Yasuzaki Masayoshi",
 "Jason McCarver",
@@ -198,6 +207,7 @@ static char *CONTRIBS_LIST[] = {
 "Nishimura",
 "Nishiyama",
 "Masaaki Noro",
+"Gustavo Noronha Silva",
 "Ales Nosek",
 "Emilian Nowak",
 "James Noyes",
@@ -208,6 +218,7 @@ static char *CONTRIBS_LIST[] = {
 "Paul Ollis",
 "Fredrik Olofssen",
 "Reza Pakdel",
+"Richard Palo",
 "Marcel Pol",
 "Martin Pool",
 "Quar",
@@ -231,11 +242,9 @@ static char *CONTRIBS_LIST[] = {
 "Simon 'corecode' Schubert",
 "Kim Schulz",
 "Markus Schwarzenberg",
-"Rodrigo Dias Arruda Senra",
 "Setoh",
 "Michael Shell",
 "shigeri",
-"Gustavo Noronha Silva",
 "Jesse Skinner",
 "Ville Skyttä",
 "Dale P. Smith",
@@ -255,7 +264,7 @@ static char *CONTRIBS_LIST[] = {
 "Topia",
 "Anders Troback",
 "Tsutsui",
-"Aleksandar Urosevic",
+"Aleksandar Urošević",
 "Petr Vanek",
 "Jeroen Versteeg",
 "Kevin Vigor",
