@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 2001-2012 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #define COLORLABEL_H__
 
 #include <glib.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 
 /* max value of color label index (0..max) - see also procmsg.h */
 #define COLORLABELS 15
