@@ -35,6 +35,16 @@
 G_BEGIN_DECLS
 
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+/* Generic visibility flags */
+typedef enum
+{
+  GTK_VISIBILITY_NONE,
+  GTK_VISIBILITY_PARTIAL,
+  GTK_VISIBILITY_FULL
+} GtkVisibility;
+#endif
+
 /* clist flags */
 enum {
   GTK_CMCLIST_IN_DRAG             = 1 <<  0,
@@ -206,12 +216,7 @@ struct _GtkCMCList
   GtkAdjustment *hadjustment;
   GtkAdjustment *vadjustment;
   
-  /* xor GC for the vertical drag line */
-  GdkGC *xor_gc;
-  
-  /* gc for drawing unselected cells */
-  GdkGC *fg_gc;
-  GdkGC *bg_gc;
+  gint dash_mode;
   
   /* cursor used to indicate dragging */
   GdkCursor *cursor_drag;
@@ -243,9 +248,11 @@ struct _GtkCMCListClass
 {
   GtkContainerClass parent_class;
   
+#if !GTK_CHECK_VERSION(3, 0, 0)
   void  (*set_scroll_adjustments) (GtkCMCList       *clist,
 				   GtkAdjustment  *hadjustment,
 				   GtkAdjustment  *vadjustment);
+#endif
   void   (*refresh)             (GtkCMCList       *clist);
   void   (*select_row)          (GtkCMCList       *clist,
 				 gint            row,
@@ -290,10 +297,6 @@ struct _GtkCMCListClass
 				 GdkRectangle   *area,
 				 gint            row,
 				 GtkCMCListRow    *clist_row);
-  void   (*draw_drag_highlight) (GtkCMCList        *clist,
-				 GtkCMCListRow     *target_row,
-				 gint             target_row_number,
-				 GtkCMCListDragPos  drag_pos);
   void   (*clear)               (GtkCMCList       *clist);
   void   (*fake_unselect_all)   (GtkCMCList       *clist,
 				 gint            row);
