@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -100,10 +101,6 @@ gchar *input_dialog(const gchar *title, const gchar *message,
 	gtk_widget_hide(icon_p);
 	is_pass = FALSE;
 	gtk_entry_set_visibility(GTK_ENTRY(entry), TRUE);
-#ifdef MAEMO
-	hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry), 
-		HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP);
-#endif
 
 	return input_dialog_open(title, message, NULL, default_string, FALSE, NULL);
 }
@@ -125,10 +122,6 @@ gchar *input_dialog_with_invisible(const gchar *title, const gchar *message,
 	gtk_widget_show(icon_p);
 	is_pass = TRUE;
 	gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
-#ifdef MAEMO
-	hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry), 
-		HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_INVISIBLE);
-#endif
 
 	return input_dialog_open(title, message, NULL, default_string, FALSE, NULL);
 }
@@ -159,10 +152,6 @@ gchar *input_dialog_with_invisible_checkbtn(const gchar *title, const gchar *mes
 	gtk_widget_show(icon_p);
 	is_pass = TRUE;
 	gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
-#ifdef MAEMO
-	hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry), 
-		HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_INVISIBLE);
-#endif
 
 	return input_dialog_open(title, message, checkbtn_label, default_string, (checkbtn_state? *checkbtn_state:FALSE), checkbtn_state);
 }
@@ -196,10 +185,13 @@ gchar *input_dialog_combo_remember(const gchar *title, const gchar *message,
 	gtk_widget_show(icon_q);
 	gtk_widget_hide(icon_p);
 	is_pass = FALSE;
-
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	combobox_unset_popdown_strings(GTK_COMBO_BOX(combo));
 	combobox_set_popdown_strings(GTK_COMBO_BOX(combo), list);
-
+#else
+	combobox_unset_popdown_strings(GTK_COMBO_BOX_TEXT(combo));
+	combobox_set_popdown_strings(GTK_COMBO_BOX_TEXT(combo), list);
+#endif
 	return input_dialog_open(title, message, NULL, default_string, FALSE, remember);
 }
 
@@ -227,10 +219,6 @@ gchar *input_dialog_with_checkbtn(const gchar	*title,
 	gtk_widget_hide(icon_p);
 	is_pass = FALSE;
 	gtk_entry_set_visibility(GTK_ENTRY(entry), TRUE);
-#ifdef MAEMO
-	hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry), 
-		HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP);
-#endif
 
 	return input_dialog_open(title, message, checkbtn_label, default_string, 
 	       			 prefs_common.inherit_folder_props, checkbtn_state);
@@ -302,7 +290,6 @@ gchar *input_dialog_query_password_keep(const gchar *server, const gchar *user,
 static void input_dialog_create(gboolean is_password)
 {
 	static PangoFontDescription *font_desc;
-	GtkWidget *w_hbox;
 	GtkWidget *hbox;
 	GtkWidget *vbox;
 	GtkWidget *cancel_button;
@@ -329,8 +316,6 @@ static void input_dialog_create(gboolean is_password)
 			    FALSE, FALSE, 0);
 
 	/* for title label */
-	w_hbox = gtk_hbox_new(FALSE, 0);
-	
 	icon_q = gtk_image_new_from_stock(GTK_STOCK_DIALOG_QUESTION,
         			GTK_ICON_SIZE_DIALOG); 
 	gtk_misc_set_alignment (GTK_MISC (icon_q), 0.5, 0.0);
@@ -375,7 +360,11 @@ static void input_dialog_create(gboolean is_password)
 	g_signal_connect(G_OBJECT(entry), "activate",
 			 G_CALLBACK(entry_activated), NULL);
 
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	combo = gtk_combo_box_entry_new_text();
+#else
+	combo = gtk_combo_box_text_new_with_entry();
+#endif
 	gtk_box_pack_start(GTK_BOX(vbox), combo, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((combo)))), "activate",
 			 G_CALLBACK(combo_activated), NULL);
@@ -432,7 +421,7 @@ static gchar *input_dialog_open(const gchar *title, const gchar *message,
 		gtk_button_set_label(GTK_BUTTON(remember_checkbtn), _("Remember this"));
 
 	input_dialog_set(title, message, default_string);
-	gtk_widget_show(dialog);
+	gtk_window_present(GTK_WINDOW(dialog));
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(remember_checkbtn),
 				     default_checkbtn_state);
@@ -450,7 +439,6 @@ static gchar *input_dialog_open(const gchar *title, const gchar *message,
 		gtk_main_iteration();
 
 	manage_window_focus_out(dialog, NULL, NULL);
-	gtk_widget_hide(dialog);
 
 	if (ack) {
 		GtkEditable *editable;
@@ -473,6 +461,10 @@ static gchar *input_dialog_open(const gchar *title, const gchar *message,
 	if (remember) {
 		*remember = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(remember_checkbtn));
 	}
+
+	gtk_widget_destroy(dialog);
+	dialog = NULL;
+
 	if (is_pass)
 		debug_print("return string = %s\n", str ? "********": ("none"));
 	else
