@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -331,8 +331,8 @@ SC_HTMLParser *sc_html_parser_new(FILE *fp, CodeConverter *conv)
 {
 	SC_HTMLParser *parser;
 
-	g_return_val_if_fail(fp != NULL, NULL);
-	g_return_val_if_fail(conv != NULL, NULL);
+	cm_return_val_if_fail(fp != NULL, NULL);
+	cm_return_val_if_fail(conv != NULL, NULL);
 
 	parser = g_new0(SC_HTMLParser, 1);
 	parser->fp = fp;
@@ -441,6 +441,9 @@ static SC_HTMLState sc_html_read_line(SC_HTMLParser *parser)
 	gchar buf2[SC_HTMLBUFSIZE];
 	gint index;
 
+	if (parser->fp == NULL)
+		return SC_HTML_EOF;
+
 	if (fgets(buf, sizeof(buf), parser->fp) == NULL) {
 		parser->state = SC_HTML_EOF;
 		return SC_HTML_EOF;
@@ -519,7 +522,7 @@ static SC_HTMLTag *sc_html_get_tag(const gchar *str)
 	gchar *tmp;
 	guchar *tmpp;
 
-	g_return_val_if_fail(str != NULL, NULL);
+	cm_return_val_if_fail(str != NULL, NULL);
 
 	if (*str == '\0' || *str == '!') return NULL;
 
@@ -607,6 +610,24 @@ static void sc_html_free_tag(SC_HTMLTag *tag)
 	g_free(tag);
 }
 
+static void decode_href(SC_HTMLParser *parser)
+{
+	gchar *tmp;
+	SC_HTMLParser *tparser = g_new0(SC_HTMLParser, 1);
+
+	tparser->str = g_string_new(NULL);
+	tparser->buf = g_string_new(parser->href);
+	tparser->bufp = tparser->buf->str;
+	tparser->symbol_table = default_symbol_table;
+	
+	tmp = sc_html_parse(tparser);
+	
+	g_free(parser->href);
+	parser->href = g_strdup(tmp);
+
+	sc_html_parser_destroy(tparser);
+}
+
 static SC_HTMLState sc_html_parse_tag(SC_HTMLParser *parser)
 {
 	gchar buf[SC_HTMLBUFSIZE];
@@ -629,6 +650,7 @@ static SC_HTMLState sc_html_parse_tag(SC_HTMLParser *parser)
 			if (cur->data && !strcmp(((SC_HTMLAttr *)cur->data)->name, "href")) {
 				g_free(parser->href);
 				parser->href = g_strdup(((SC_HTMLAttr *)cur->data)->value);
+				decode_href(parser);
 				parser->state = SC_HTML_HREF_BEG;
 				break;
 			}
@@ -699,7 +721,7 @@ static void sc_html_parse_special(SC_HTMLParser *parser)
 	const gchar *val;
 
 	parser->state = SC_HTML_UNKNOWN;
-	g_return_if_fail(*parser->bufp == '&');
+	cm_return_if_fail(*parser->bufp == '&');
 
 	/* &foo; */
 	for (n = 0; parser->bufp[n] != '\0' && parser->bufp[n] != ';'; n++)
@@ -728,7 +750,7 @@ static void sc_html_get_parenthesis(SC_HTMLParser *parser, gchar *buf, gint len)
 	gchar *p;
 
 	buf[0] = '\0';
-	g_return_if_fail(*parser->bufp == '<');
+	cm_return_if_fail(*parser->bufp == '<');
 
 	/* ignore comment / CSS / script stuff */
 	if (!strncmp(parser->bufp, "<!--", 4)) {
