@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -31,6 +32,7 @@
 
 #include "utils.h"
 #include "folder.h"
+#include "folder_item_prefs.h"
 #include "folderview.h"
 #include "menu.h"
 #include "account.h"
@@ -245,7 +247,6 @@ static void rename_folder_cb(GtkAction *action, gpointer data)
 	gchar *new_folder;
 	gchar *name;
 	gchar *message;
-	gchar *old_path;
 	gchar *old_id;
 	gchar *new_id;
 	gchar *base;
@@ -273,7 +274,7 @@ static void rename_folder_cb(GtkAction *action, gpointer data)
 		return;
 	}
 	if (strchr(new_folder, '/') != NULL) {
-		alertpanel_error(_("`%c' can't be included in folder name."),
+		alertpanel_error(_("'%c' can't be included in folder name."),
 				 '/');
 		return;
 	}
@@ -285,8 +286,6 @@ static void rename_folder_cb(GtkAction *action, gpointer data)
 		return;
 	}
 
-	Xstrdup_a(old_path, item->path, {g_free(new_folder); return;});
-
 	old_id = folder_item_get_identifier(item);
 	
 	if (folder_item_rename(item, new_folder) < 0) {
@@ -346,7 +345,6 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 	FolderItem *item;
 	gchar *message, *name;
 	AlertValue avalue;
-	gchar *old_path;
 	gchar *old_id;
 
 	if (!folderview->selected) return;
@@ -368,7 +366,6 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 	g_free(message);
 	if (avalue != G_ALERTALTERNATE) return;
 
-	Xstrdup_a(old_path, item->path, return);
 	old_id = folder_item_get_identifier(item);
 
 	if (folderview->opened == folderview->selected ||
