@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -59,25 +60,6 @@
 #include "hooks.h"
 #include "logwindow.h"
 
-#ifdef MAEMO
-#ifdef CHINOOK
-#include <hildon/hildon-banner.h>
-#include <hildon/hildon-sound.h>
-#else
-#include <hildon-widgets/hildon-banner.h>
-#include <hildon-widgets/hildon-system-sound.h>
-#endif
-#include <libosso.h>
-
-#ifdef CONIC
-#include <conicconnection.h>
-#include <conicconnectionevent.h>
-
-static ConIcConnection *maemo_connection = NULL;
-static gboolean maemo_warned_offline = FALSE;
-#endif
-#endif
-
 extern SessionStats session_stats;
 
 static GList *inc_dialog_list = NULL;
@@ -88,7 +70,7 @@ static GdkPixbuf *currentpix;
 static GdkPixbuf *errorpix;
 static GdkPixbuf *okpix;
 
-#define MSGBUFSIZE	8192
+#define MESSAGEBUFSIZE	8192
 
 static void inc_update_stats(gint new_msgs);
 static void inc_finished		(MainWindow		*mainwin,
@@ -161,8 +143,6 @@ static void inc_update_stats(gint new_msgs)
 {
 	/* update session statistics */
 	session_stats.received += new_msgs;
-fprintf(stdout, "++ STATS ++ INC %d %d\n", session_stats.received, new_msgs);
-fflush(stdout);
 }
 
 /**
@@ -184,7 +164,7 @@ static void inc_finished(MainWindow *mainwin, gboolean new_messages, gboolean au
 
 		if (cur_account && cur_account->inbox)
 			item = folder_find_item_from_identifier(cur_account->inbox);
-		if (item == NULL && cur_account->folder)
+		if (item == NULL && cur_account && cur_account->folder)
 			item = cur_account->folder->inbox;
 		if (item == NULL)
 			item = folder_get_default_inbox();
@@ -551,6 +531,18 @@ static void inc_session_destroy(IncSession *session)
 	g_free(session);
 }
 
+static gint pop3_get_port(Pop3Session *pop3_session)
+{
+#ifdef USE_GNUTLS
+	return pop3_session->ac_prefs->set_popport ?
+		pop3_session->ac_prefs->popport :
+		pop3_session->ac_prefs->ssl_pop == SSL_TUNNEL ? 995 : 110;
+#else
+	return pop3_session->ac_prefs->set_popport ?
+		pop3_session->ac_prefs->popport : 110;
+#endif
+}
+
 static gint inc_start(IncProgressDialog *inc_dialog)
 {
 	IncSession *session;
@@ -572,7 +564,13 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 		session = qlist->data;
 		pop3_session = POP3_SESSION(session->session); 
 		pop3_session->user = g_strdup(pop3_session->ac_prefs->userid);
-		if (pop3_session->ac_prefs->passwd)
+
+		if (password_get(pop3_session->user,
+					pop3_session->ac_prefs->recv_server,
+					"pop3", pop3_get_port(pop3_session),
+					&(pop3_session->pass))) {
+			/* NOP */;
+		} else if (pop3_session->ac_prefs->passwd)
 			pop3_session->pass =
 				g_strdup(pop3_session->ac_prefs->passwd);
 		else {
@@ -804,10 +802,9 @@ static IncState inc_pop3_session_do(IncSession *session)
 
 	server = pop3_session->ac_prefs->recv_server;
 	account_name = pop3_session->ac_prefs->account_name;
+	port = pop3_get_port(pop3_session);
+
 #ifdef USE_GNUTLS
-	port = pop3_session->ac_prefs->set_popport ?
-		pop3_session->ac_prefs->popport :
-		pop3_session->ac_prefs->ssl_pop == SSL_TUNNEL ? 995 : 110;
 	SESSION(pop3_session)->ssl_type = pop3_session->ac_prefs->ssl_pop;
 	if (pop3_session->ac_prefs->ssl_pop != SSL_NONE)
 		SESSION(pop3_session)->nonblocking =
@@ -826,12 +823,10 @@ static IncState inc_pop3_session_do(IncSession *session)
 			  G_ALERTDEFAULT) != G_ALERTALTERNATE)
 			return INC_CANCEL;
 	}
-	port = pop3_session->ac_prefs->set_popport ?
-		pop3_session->ac_prefs->popport : 110;
 #endif
 
-	buf = g_strdup_printf(_("Account '%s': Connecting to POP3 server: %s..."),
-				account_name, server);
+	buf = g_strdup_printf(_("Account '%s': Connecting to POP3 server: %s:%d..."),
+				account_name, server, port);
 	statuswindow_print_all("%s", buf);
 	log_message(LOG_PROTOCOL, "%s\n", buf);
 
@@ -934,7 +929,7 @@ static void inc_progress_dialog_set_label(IncProgressDialog *inc_dialog,
 	case POP3_GETAUTH_APOP:
 		progress_dialog_set_label(dialog, _("Authenticating..."));
 		statuswindow_pop_all();
-		statusbar_print_all(_("Retrieving messages from %s (%s) ..."),
+		statusbar_print_all(_("Retrieving messages from %s (%s)..."),
 				    SESSION(session)->server,
 				    session->ac_prefs->account_name);
 		break;
@@ -969,7 +964,7 @@ static void inc_progress_dialog_set_label(IncProgressDialog *inc_dialog,
 static void inc_progress_dialog_set_progress(IncProgressDialog *inc_dialog,
 					     IncSession *inc_session)
 {
-	gchar buf[MSGBUFSIZE];
+	gchar buf[MESSAGEBUFSIZE];
 	Pop3Session *pop3_session = POP3_SESSION(inc_session->session);
 	gchar *total_size_str;
 	gint cur_total;
@@ -1153,7 +1148,6 @@ static void inc_put_error(IncState istate, Pop3Session *session)
 
 	switch (istate) {
 	case INC_CONNECT_ERROR:
-		log_msg = _("Connection failed.");
 		fatal_error = TRUE;
 		if (prefs_common.no_recv_err_panel)
 			break;
@@ -1416,13 +1410,8 @@ void inc_unlock_real(void)
 static guint autocheck_timer = 0;
 static gpointer autocheck_data = NULL;
 
-#ifdef MAEMO
-osso_context_t *get_osso_context(void);
-#endif
-
 static void inc_notify_cmd(gint new_msgs, gboolean notify)
 {
-#ifndef MAEMO
 	gchar *buf, *numpos, *ret_str;
 	gssize by_read = 0, by_written = 0;
 
@@ -1450,65 +1439,12 @@ static void inc_notify_cmd(gint new_msgs, gboolean notify)
 	execute_command_line(buf, TRUE);
 
 	g_free(buf);
-
-#else
-	if (new_msgs) {
-		if (prefs_common.maemo_play_sound)
-			hildon_play_system_sound("/usr/share/sounds/ui-new_email.wav");
-		if (prefs_common.maemo_show_banner) {
-			gchar *info = g_strdup_printf(ngettext("Claws Mail: %d new message",
-					  	   "Claws Mail: %d new messages",
-					  	   new_msgs), new_msgs);
-			osso_system_note_infoprint(get_osso_context(), info, NULL);
-			g_free(info);
-		}
-	}
-#endif
 }
 
-#if (defined(MAEMO) && defined(CONIC))
-static void maemo_connection_event(ConIcConnection *connection, 
-                     		   ConIcConnectionEvent *event,
-				   gpointer user_data)
-{
-	ConIcConnectionStatus status =
-		con_ic_connection_event_get_status(event);
-	MainWindow *mainwin = (MainWindow *)user_data;
-	switch(status) {
-	case CON_IC_STATUS_CONNECTED:
-		debug_print("we're connected\n");
-		main_window_toggle_work_offline(mainwin, FALSE, FALSE);
-		break;
-	default:
-		debug_print("we're disconnected\n");
-		main_window_toggle_work_offline(mainwin, TRUE, FALSE);
-		maemo_warned_offline = FALSE;
-		break;
-	}
-}
-
-#endif
-
 void inc_autocheck_timer_init(MainWindow *mainwin)
 {
-#if (defined(MAEMO) && defined(CONIC))
-	GValue *val = g_new0(GValue, 1);
-	maemo_connection = con_ic_connection_new();
-
-	g_value_init(val, G_TYPE_BOOLEAN);
-	g_value_set_boolean(val, TRUE);
-	g_object_set_property(G_OBJECT(maemo_connection),
-			"automatic-connection-events", val);
-	g_free(val);	
-	g_signal_connect (maemo_connection, "connection-event",
-			  G_CALLBACK(maemo_connection_event), mainwin);	
-	con_ic_connection_connect (maemo_connection,
-		CON_IC_CONNECT_FLAG_AUTOMATICALLY_TRIGGERED);
-	autocheck_data = mainwin;
-#else
 	autocheck_data = mainwin;
 	inc_autocheck_timer_set();
-#endif
 }
 
 static void inc_autocheck_timer_set_interval(guint interval)
@@ -1533,10 +1469,6 @@ static void inc_autocheck_timer_set_interval(guint interval)
 void inc_autocheck_timer_set(void)
 {
 	inc_autocheck_timer_set_interval(prefs_common.autochk_itv * 60000);
-#if (defined(MAEMO) && defined(CONIC))
-	con_ic_connection_connect (maemo_connection,
-		CON_IC_CONNECT_FLAG_AUTOMATICALLY_TRIGGERED);
-#endif
 }
 
 void inc_autocheck_timer_remove(void)
@@ -1576,22 +1508,6 @@ gboolean inc_offline_should_override(gboolean force_ask, const gchar *msg)
 		return FALSE;
 #endif
 
-#if (defined(MAEMO) && defined(CONIC))
-	if (prefs_common.work_offline) {
-		if (force_ask && !maemo_warned_offline) {
-			if (mainwindow_get_mainwindow())
-				hildon_banner_show_information(
-					mainwindow_get_mainwindow()->window, 
-					NULL,
-					_("Unable to connect: you are offline."));
-			maemo_warned_offline = TRUE;
-		}
-		return FALSE;
-	} else {
-		return TRUE;
-	}
-#endif	
-
 	if (prefs_common.autochk_newmail)
 		length = prefs_common.autochk_itv; /* minutes */
 
