@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,19 +21,14 @@
 #define __MESSAGEVIEW_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
 #include <gtk/gtk.h>
 
-typedef struct _MessageView	MessageView;
-
 #include "mainwindow.h"
-#include "headerview.h"
-#include "textview.h"
-#include "mimeview.h"
-#include "noticeview.h"
+#include "viewtypes.h"
 #include "procmsg.h"
 #include "procmime.h"
 #include "toolbar.h"
@@ -80,7 +75,10 @@ struct _MessageView
 	
 	gboolean show_full_text;
 	gboolean partial_display_shown;
+	gboolean update_needed;
 	GtkUIManager *ui_manager;
+	GList *trail;
+	gint trail_pos;
 };
 
 MessageView *messageview_create			(MainWindow	*mainwin);
@@ -118,15 +116,18 @@ gchar *messageview_get_selection		(MessageView 	*msgview);
 void messageview_set_menu_sensitive		(MessageView	*msgview);
 void messageview_learn				(MessageView	*msgview,
 						 gboolean is_spam);
-#if defined(USE_GNOMEPRINT) || GTK_CHECK_VERSION(2,10,0)
 void messageview_print				(MsgInfo	*msginfo,
 						 gboolean	 all_headers,
 						 gint		 sel_start,
 						 gint		 sel_end,
 						 gint		 partnum);
-#endif
 void messageview_list_urls			(MessageView	*msgview);
 void messageview_show_partial_display		(MessageView 	*msgview, 
 						 MsgInfo 	*msginfo,
 						 size_t 	 length);
+gboolean messageview_nav_has_prev(MessageView *messageview);
+gboolean messageview_nav_has_next(MessageView *messageview);
+MsgInfo *messageview_nav_get_prev(MessageView *messageview);
+MsgInfo *messageview_nav_get_next(MessageView *messageview);
+
 #endif /* __MESSAGEVIEW_H__ */
