@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -54,15 +55,8 @@
 #include "gtk/gtkvscrollbutton.h"
 #include "gtk/logwindow.h"
 #include "timing.h"
-
-#ifdef MAEMO
-#include <libosso.h>
-#ifndef CHINOOK
-#include <osso-mime.h>
-#else
-#include <hildon-mime.h>
-#endif
-#endif
+#include "manage_window.h"
+#include "privacy.h"
 
 typedef enum
 {
@@ -106,21 +100,15 @@ static void mimeview_drag_data_get      (GtkWidget	  *widget,
 static gboolean mimeview_scrolled	(GtkWidget	*widget,
 					 GdkEventScroll	*event,
 					 MimeView	*mimeview);
-static void mimeview_display_as_text	(MimeView	*mimeview);
-static void mimeview_save_as		(MimeView	*mimeview);
+
 static void mimeview_save_all		(MimeView	*mimeview);
-static void mimeview_launch		(MimeView	*mimeview,
-					 MimeInfo	*partinfo);
 #ifndef G_OS_WIN32
-static void mimeview_open_with		(MimeView	*mimeview);
 static void mimeview_open_part_with	(MimeView	*mimeview,
 					 MimeInfo	*partinfo,
 					 gboolean	 automatic);
 #endif
 static void mimeview_send_to		(MimeView	*mimeview,
 					 MimeInfo	*partinfo);
-static void mimeview_select_next_part	(MimeView	*mimeview);
-static void mimeview_select_prev_part	(MimeView	*mimeview);
 static void mimeview_view_file		(const gchar	*filename,
 					 MimeInfo	*partinfo,
 					 const gchar	*cmd,
@@ -202,16 +190,16 @@ static void mimeview_select_prev_part_cb(GtkAction *action, gpointer data)
 
 static GtkActionEntry mimeview_menu_actions[] = {
 	{ "MimeView", NULL, "MimeView" },
-	{ "MimeView/Open", NULL, N_("_Open (l)"), NULL, "Open MIME part", G_CALLBACK(mimeview_launch_cb) },
-#if (!defined MAEMO && !defined G_OS_WIN32)
-	{ "MimeView/OpenWith", NULL, N_("Open _with (o)..."), NULL, "Open MIME part with...", G_CALLBACK(mimeview_open_with_cb) },
+	{ "MimeView/Open", NULL, N_("_Open"), NULL, "Open MIME part", G_CALLBACK(mimeview_launch_cb) },
+#if (!defined G_OS_WIN32)
+	{ "MimeView/OpenWith", NULL, N_("Open _with..."), NULL, "Open MIME part with...", G_CALLBACK(mimeview_open_with_cb) },
 #endif
 	{ "MimeView/SendTo", NULL, N_("Send to..."), NULL, "Send to", G_CALLBACK(mimeview_send_to_cb) },
-	{ "MimeView/DisplayAsText", NULL, N_("_Display as text (t)"), NULL, "Display as text", G_CALLBACK(mimeview_display_as_text_cb) },
-	{ "MimeView/SaveAs", NULL, N_("_Save as (y)..."), NULL, "Save as", G_CALLBACK(mimeview_save_as_cb) },
+	{ "MimeView/DisplayAsText", NULL, N_("_Display as text"), NULL, "Display as text", G_CALLBACK(mimeview_display_as_text_cb) },
+	{ "MimeView/SaveAs", NULL, N_("_Save as..."), NULL, "Save as", G_CALLBACK(mimeview_save_as_cb) },
 	{ "MimeView/SaveAll", NULL, N_("Save _all..."), NULL, "Save all parts", G_CALLBACK(mimeview_save_all_cb) },
-	{ "MimeView/NextPart", NULL, N_("Next part (a)"), NULL, "Next part", G_CALLBACK(mimeview_select_next_part_cb) },
-	{ "MimeView/PrevPart", NULL, N_("Previous part (z)"), NULL, "Previous part", G_CALLBACK(mimeview_select_prev_part_cb) }
+	{ "MimeView/NextPart", NULL, N_("Next part"), NULL, "Next part", G_CALLBACK(mimeview_select_next_part_cb) },
+	{ "MimeView/PrevPart", NULL, N_("Previous part"), NULL, "Previous part", G_CALLBACK(mimeview_select_prev_part_cb) }
 };
 
 static GtkTargetEntry mimeview_mime_types[] =
@@ -407,7 +395,7 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
 			"/Menus/MimeView/", "Open", "MimeView/Open",
 			GTK_UI_MANAGER_MENUITEM);
-#if (!defined MAEMO && !defined G_OS_WIN32)
+#if (!defined G_OS_WIN32)
 	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
 			"/Menus/MimeView/", "OpenWith", "MimeView/OpenWith",
 			GTK_UI_MANAGER_MENUITEM);
@@ -1007,8 +995,18 @@ void mimeview_clear(MimeView *mimeview)
 	mimeview_change_view_type(mimeview, MIMEVIEW_TEXT);
 }
 
+gchar * get_message_check_signature_shortcut(MessageView *messageview) {
+	GtkUIManager *ui_manager;
+
+	if (messageview->window != NULL)
+			ui_manager = messageview->ui_manager;
+		else
+			ui_manager = messageview->mainwin->ui_manager;
+
+	return cm_menu_item_get_shortcut(ui_manager, "Menu/Message/CheckSignature");
+}
+
 static void check_signature_cb(GtkWidget *widget, gpointer user_data);
-static void mimeview_check_signature(MimeView *mimeview);
 static void display_full_info_cb(GtkWidget *widget, gpointer user_data);
 
 static void update_signature_noticeview(MimeView *mimeview, MimeInfo *mimeinfo, 
@@ -1054,25 +1052,35 @@ static void update_signature_noticeview(MimeView *mimeview, MimeInfo *mimeinfo,
 		icon = STOCK_PIXMAP_PRIVACY_FAILED;
 		break;
 	case SIGNATURE_CHECK_FAILED:
-		button_text = _("Check again");
-		func = check_signature_cb;
-		icon = STOCK_PIXMAP_PRIVACY_UNKNOWN;
 	case SIGNATURE_CHECK_TIMEOUT:
 		button_text = _("Check again");
 		func = check_signature_cb;
 		icon = STOCK_PIXMAP_PRIVACY_UNKNOWN;
+		break;
 	default:
 		break;
 	}
 	if (mycode == SIGNATURE_UNCHECKED) {
 		gchar *tmp = privacy_mimeinfo_sig_info_short(mimeinfo);
-		text = g_strdup_printf("%s %s",
-			tmp, _("Click the icon or hit 'C' to check it."));
+		gchar *shortcut = get_message_check_signature_shortcut(mimeview->messageview);
+
+		if (*shortcut == '\0')
+			text = g_strdup_printf(_("%s Click the icon to check it."), tmp);
+		else
+			text = g_strdup_printf(_("%s Click the icon or hit '%s' to check it."),
+				tmp, shortcut);
 		g_free(tmp);
+		g_free(shortcut);
 	} else if (mycode != SIGNATURE_CHECK_TIMEOUT) {
 		text = privacy_mimeinfo_sig_info_short(mimeinfo);
 	} else if (mycode == SIGNATURE_CHECK_TIMEOUT) {
-		text = g_strdup(_("Timeout checking the signature. Click the icon or hit 'C' to try again."));
+		gchar *shortcut = get_message_check_signature_shortcut(mimeview->messageview);
+
+		if (*shortcut == '\0')
+			text = g_strdup(_("Timeout checking the signature. Click the icon to try again."));
+		else
+			text = g_strdup_printf(_("Timeout checking the signature. Click the icon or hit '%s' to try again."), shortcut);
+		g_free(shortcut);
 	}
 
 	noticeview_set_text(mimeview->siginfoview, text);
@@ -1086,6 +1094,9 @@ static void update_signature_noticeview(MimeView *mimeview, MimeInfo *mimeinfo,
 		(gpointer) mimeview);
 	noticeview_set_icon(mimeview->siginfoview, icon);
 	noticeview_set_tooltip(mimeview->siginfoview, button_text);
+
+	icon_list_clear(mimeview);
+	icon_list_create(mimeview, mimeview->mimeinfo);
 }
 
 #ifdef USE_PTHREAD
@@ -1108,13 +1119,14 @@ static void mimeview_check_data_reset(MimeView *mimeview)
 		pthread_cancel(mimeview->check_data->cancel_th);
 	}
 
-	g_free(mimeview->check_data);
-	mimeview->check_data = NULL;
-
 	if (must_free) {
 		debug_print("freeing deferred mimeinfo\n");
 		procmime_mimeinfo_free_all(mimeview->check_data->siginfo);
 	}
+
+	g_free(mimeview->check_data);
+	mimeview->check_data = NULL;
+
 	if (must_destroy) {
 		debug_print("freeing deferred mimeview\n");
 		mimeview_free_mimeinfo(mimeview);
@@ -1123,7 +1135,6 @@ static void mimeview_check_data_reset(MimeView *mimeview)
 		g_free(mimeview);
 		mimeviews = g_slist_remove(mimeviews, mimeview);
 	}
-
 }
 
 /* GUI update once the checker thread is done or killed */
@@ -1164,9 +1175,7 @@ static gboolean mimeview_check_sig_thread_cb(void *data)
 	else
 		update_signature_noticeview(mimeview, mimeview->siginfo, 
 			FALSE, 0);
-	icon_list_clear(mimeview);
-	icon_list_create(mimeview, mimeview->mimeinfo);
-	
+
 end:
 	mimeview_check_data_reset(mimeview);
 	return FALSE;
@@ -1321,12 +1330,10 @@ static void check_signature_cb(GtkWidget *widget, gpointer user_data)
 		debug_print("checking without thread\n");
 		privacy_mimeinfo_check_signature(mimeinfo);
 		update_signature_noticeview(mimeview, mimeview->siginfo, FALSE, 0);
-		icon_list_clear(mimeview);
-		icon_list_create(mimeview, mimeview->mimeinfo);
 	}
 }
 
-static void mimeview_check_signature(MimeView *mimeview)
+void mimeview_check_signature(MimeView *mimeview)
 {
 	check_signature_cb(NULL, mimeview);	
 }
@@ -1384,7 +1391,13 @@ static void update_signature_info(MimeView *mimeview, MimeInfo *selected)
 		siginfo = procmime_mimeinfo_parent(siginfo);
 	}
 	mimeview->siginfo = siginfo;
-	
+
+	/* This shortcut boolean is there to correctly set the menu's
+	 * CheckSignature item sensitivity without killing performance
+	 * each time the menu sensitiveness is updated (a lot).
+	 */
+	mimeview->signed_part = (siginfo != NULL);
+
 	if (siginfo == NULL) {
 		noticeview_hide(mimeview->siginfoview);
 		return;
@@ -1448,6 +1461,10 @@ static void mimeview_selected(GtkTreeSelection *selection, MimeView *mimeview)
 			break;
 		}
 	}
+
+	if (mimeview->siginfo && privacy_auto_check_signatures(mimeview->siginfo)) {
+		mimeview_check_signature(mimeview);
+	}
 }
 
 static gint mimeview_button_pressed(GtkWidget *widget, GdkEventButton *event,
@@ -1533,7 +1550,7 @@ gboolean mimeview_pass_key_press_event(MimeView *mimeview, GdkEventKey *event)
 	return mimeview_key_pressed(mimeview->ctree, event, mimeview);
 }
 
-static void mimeview_select_next_part(MimeView *mimeview)
+void mimeview_select_next_part(MimeView *mimeview)
 {
 	GtkTreeView *ctree = GTK_TREE_VIEW(mimeview->ctree);
 	GtkTreeModel *model = gtk_tree_view_get_model(ctree);
@@ -1566,7 +1583,7 @@ skip:
 	gtk_tree_path_free(path);
 }
 
-static void mimeview_select_prev_part(MimeView *mimeview)
+void mimeview_select_prev_part(MimeView *mimeview)
 {
 	GtkTreeView *ctree = GTK_TREE_VIEW(mimeview->ctree);
 	GtkTreeModel *model = gtk_tree_view_get_model(ctree);
@@ -1642,36 +1659,6 @@ static gint mimeview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 	case GDK_KEY_Down:
 		mimeview_scroll_one_line(mimeview, (event->keyval == GDK_KEY_Up));
 		return TRUE;
-	case GDK_KEY_y:
-		BREAK_ON_MODIFIER_KEY();
-		mimeview_save_as(mimeview);
-		return TRUE;
-	case GDK_KEY_t:
-		BREAK_ON_MODIFIER_KEY();
-		mimeview_display_as_text(mimeview);
-		return TRUE;	
-	case GDK_KEY_l:
-		BREAK_ON_MODIFIER_KEY();
-		mimeview_launch(mimeview, NULL);
-		return TRUE;
-	case GDK_KEY_o:
-		BREAK_ON_MODIFIER_KEY();
-#ifndef G_OS_WIN32
-		mimeview_open_with(mimeview);
-#endif
-		return TRUE;
-	case GDK_KEY_c:
-		BREAK_ON_MODIFIER_KEY();
-		mimeview_check_signature(mimeview);
-		return TRUE;
-	case GDK_KEY_a:
-		BREAK_ON_MODIFIER_KEY();
-		mimeview_select_next_part(mimeview);
-		return TRUE;
-	case GDK_KEY_z:
-		BREAK_ON_MODIFIER_KEY();
-		mimeview_select_prev_part(mimeview);
-		return TRUE;
 	default:
 		break;
 	}
@@ -1892,6 +1879,7 @@ static void mimeview_save_all(MimeView *mimeview)
 	else
 		startdir = g_strdup(get_home_dir());
 
+	manage_window_focus_in(gtk_widget_get_ancestor(mimeview->hbox, GTK_TYPE_WINDOW), NULL, NULL);
 	dirname = filesel_select_file_save_folder(_("Select destination folder"), startdir);
 	if (!dirname) {
 		g_free(startdir);
@@ -1962,7 +1950,7 @@ static MimeInfo *mimeview_get_part_to_use(MimeView *mimeview)
  * Menu callback: Save the selected attachment
  * \param mimeview Current display
  */
-static void mimeview_save_as(MimeView *mimeview)
+void mimeview_save_as(MimeView *mimeview)
 {
 	gchar *filename;
 	gchar *filepath = NULL;
@@ -2005,6 +1993,7 @@ static void mimeview_save_as(MimeView *mimeview)
 
 	g_free(partname);
 
+	manage_window_focus_in(gtk_widget_get_ancestor(mimeview->hbox, GTK_TYPE_WINDOW), NULL, NULL);
 	filename = filesel_select_file_save(_("Save as"), filepath);
 	if (!filename) {
 		g_free(filepath);
@@ -2023,7 +2012,7 @@ static void mimeview_save_as(MimeView *mimeview)
 	g_free(filepath);
 }
 
-static void mimeview_display_as_text(MimeView *mimeview)
+void mimeview_display_as_text(MimeView *mimeview)
 {
 	MimeInfo *partinfo;
 
@@ -2035,7 +2024,7 @@ static void mimeview_display_as_text(MimeView *mimeview)
 	mimeview_show_message_part(mimeview, partinfo);
 }
 
-static void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
+void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
 {
 	gchar *filename;
 	gint err;
@@ -2061,7 +2050,7 @@ static void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
 }
 
 #ifndef G_OS_WIN32
-static void mimeview_open_with(MimeView *mimeview)
+void mimeview_open_with(MimeView *mimeview)
 {
 	MimeInfo *partinfo;
 
@@ -2074,9 +2063,6 @@ static void mimeview_open_with(MimeView *mimeview)
 	mimeview_open_part_with(mimeview, partinfo, FALSE);
 }
 
-#ifdef MAEMO
-osso_context_t *get_osso_context(void);
-#endif
 static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboolean automatic)
 {
 	gchar *filename;
@@ -2084,11 +2070,7 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 	gchar *mime_command = NULL;
 	gchar *content_type = NULL;
 	gint err;
-#ifdef MAEMO
-	DBusConnection *dbusconn;
-	gchar *uri;
-	int r = 0;
-#endif
+
 	cm_return_if_fail(partinfo != NULL);
 
 	filename = procmime_get_tmp_file_name(partinfo);
@@ -2115,23 +2097,6 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 			partinfo->subtype);
 	}
 	
-#ifdef MAEMO
-	if (content_type != NULL) {
-		uri = g_filename_to_uri(filename, NULL, NULL);
-		dbusconn = osso_get_dbus_connection (get_osso_context());
-#ifdef CHINOOK
-		r = hildon_mime_open_file_with_mime_type (dbusconn, uri, content_type);
-#else
-		r = osso_mime_open_file_with_mime_type (dbusconn, uri, content_type);
-#endif
-		g_free(uri);
-	}
-	if (r != 1) {
-		alertpanel_error(_("No registered viewer for this file type."));
-	}
-	goto out;
-#endif
-	
 	if ((partinfo->type == MIMETYPE_TEXT && !strcmp(partinfo->subtype, "html"))
 	&& prefs_common_get_uri_cmd() && prefs_common.uri_cmd[0]) {
 		mime_command = g_strdup(prefs_common_get_uri_cmd());
@@ -2185,9 +2150,7 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 		prefs_common.mime_open_cmd_history =
 			add_history(prefs_common.mime_open_cmd_history, cmd);
 	}
-#ifdef MAEMO
-out:
-#endif
+
 	g_free(content_type);
 	g_free(filename);
 }
@@ -2362,18 +2325,10 @@ void mimeview_select_mimepart_icon(MimeView *mimeview, MimeInfo *partinfo)
 static gint icon_key_pressed(GtkWidget *button, GdkEventKey *event,
 			     MimeView *mimeview)
 {
-	gint          num;
-	MimeInfo     *partinfo;
 	SummaryView  *summaryview;
-	TextView     *textview;
-
-	num      = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(button), "icon_number"));
-	partinfo = g_object_get_data(G_OBJECT(button), "partinfo");
 	
 	if (!event) return FALSE;
 
-	textview = mimeview->textview;
-
 	switch (event->keyval) {
 	case GDK_KEY_space:
 		if (mimeview_scroll_page(mimeview, FALSE))
@@ -2589,7 +2544,7 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 		tiptmp = g_strconcat(tip, "\n<b>",
 				prefs_common.attach_desc && mimeinfo->description ?
 				_("Description:") : _("Filename:"),
-				" </b>", tmp, NULL);
+				" </b>", g_markup_escape_text(tmp,-1), NULL);
 		g_free(tip);
 		tip = tiptmp;
 		g_free(tmp);
@@ -2606,15 +2561,9 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 	gtk_widget_show_all(button);
 	gtk_drag_source_set(button, GDK_BUTTON1_MASK|GDK_BUTTON3_MASK, 
 			    mimeview_mime_types, 1, GDK_ACTION_COPY);
-#ifndef MAEMO
+
 	g_signal_connect(G_OBJECT(button), "popup-menu",
 			 G_CALLBACK(icon_popup_menu), mimeview);
-#else
-	gtk_widget_tap_and_hold_setup(GTK_WIDGET(button), NULL, NULL,
-			GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS);
-	g_signal_connect(G_OBJECT(button), "tap-and-hold",
-			 G_CALLBACK(icon_popup_menu), mimeview);
-#endif
 	g_signal_connect(G_OBJECT(button), "button_release_event", 
 			 G_CALLBACK(icon_clicked_cb), mimeview);
 	g_signal_connect(G_OBJECT(button), "key_press_event", 
@@ -2823,7 +2772,7 @@ void mimeview_handle_cmd(MimeView *mimeview, const gchar *cmd, GdkEventButton *e
 				GTK_TOGGLE_BUTTON(mimeview->messageview->mainwin->summaryview->toggle_search), 
 				TRUE);
 		quicksearch_set(mimeview->messageview->mainwin->summaryview->quicksearch, 
-				QUICK_SEARCH_EXTENDED, buf);
+				ADVANCED_SEARCH_EXTENDED, buf);
 		g_free(buf);
 	}
 }
