@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,14 +20,12 @@
 #ifndef MIMEVIEW_H
 #define MIMEVIEW_H
 
-typedef struct _MimeView		MimeView;
 typedef struct _MimeViewerFactory 	MimeViewerFactory;
 typedef struct _MimeViewer 		MimeViewer;
 
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
-#include "gtk/gtksctree.h"
 #ifdef USE_PTHREAD
 #include <pthread.h>
 #endif
@@ -48,6 +46,10 @@ typedef struct _SigCheckData SigCheckData;
 struct _SigCheckData
 {
 	pthread_t th;
+	pthread_t cancel_th;
+	gboolean th_init;
+	gboolean cancel_th_init;
+
 	MimeInfo *siginfo;
 	gboolean free_after_use;
 	gboolean destroy_mimeview;
@@ -73,7 +75,7 @@ struct _MimeView
 
 	GtkWidget *popupmenu;
 
-	GtkCMCTreeNode *opened;
+	GtkTreePath *opened;
 
 	TextView *textview;
 	MimeViewer *mimeviewer;
@@ -93,13 +95,14 @@ struct _MimeView
 #if !GTK_CHECK_VERSION(2,12,0)
 	GtkTooltips *tooltips;
 #endif
-	gint oldsize;
 
 	NoticeView *siginfoview;
 	MimeInfo *siginfo;
 	MimeInfo *spec_part;
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
+	gboolean signed_part;
+
 #ifdef USE_PTHREAD
 	SigCheckData *check_data;
 #endif
@@ -153,7 +156,7 @@ void mimeview_clear		(MimeView	*mimeview);
 
 MimeInfo *mimeview_get_selected_part	(MimeView	*mimeview);
 
-void mimeview_pass_key_press_event	(MimeView	*mimeview,
+gboolean mimeview_pass_key_press_event	(MimeView	*mimeview,
 					 GdkEventKey	*event);
 
 void mimeview_register_viewer_factory	(MimeViewerFactory *factory);
@@ -174,6 +177,18 @@ void mimeview_select_part_num		(MimeView 	*mimeview,
 gboolean mimeview_has_viewer_for_content_type
 					(MimeView	*mimeview,
 					 const gchar	*content_type);
+gboolean mimeview_tree_is_empty		(MimeView 	*mimeview);
+void mimeview_save_as		(MimeView	*mimeview);
+void mimeview_display_as_text	(MimeView	*mimeview);
+void mimeview_launch		(MimeView	*mimeview,
+				 MimeInfo	*partinfo);
+#ifndef G_OS_WIN32
+void mimeview_open_with		(MimeView	*mimeview);
+#endif
+void mimeview_check_signature(MimeView *mimeview);
+void mimeview_select_next_part(MimeView *mimeview);
+void mimeview_select_prev_part(MimeView *mimeview);
+
 
 #ifdef __cplusplus
 }
