@@ -1,5 +1,5 @@
 /* passphrase.c - GTK+ based passphrase callback
- *      Copyright (C) 2001-2012 Werner Koch (dd9jn) and the Claws Mail team
+ *      Copyright (C) 2001-2013 Werner Koch (dd9jn) and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,8 +58,7 @@ static gint passphrase_deleted(GtkWidget *widget, GdkEventAny *event,
 static gboolean passphrase_key_pressed(GtkWidget *widget, GdkEventKey *event,
 				       gpointer data);
 
-static GtkWidget *create_description(const gchar *uid_hint,
-				     const gchar *pass_hint, gint prev_bad, gint new_key);
+static GtkWidget *create_description(const gchar *uid_hint, gint prev_bad, gint new_key);
 
 void
 gpgmegtk_set_passphrase_grab(gint yes)
@@ -102,7 +101,7 @@ passphrase_mbox(const gchar *uid_hint, const gchar *pass_hint, gint prev_bad, gi
 
     if (uid_hint || pass_hint) {
         GtkWidget *label, *icon;
-        label = create_description (uid_hint, pass_hint, prev_bad, new_key);
+        label = create_description (uid_hint, prev_bad, new_key);
 	icon = gtk_image_new_from_stock(GTK_STOCK_DIALOG_AUTHENTICATION,
         			GTK_ICON_SIZE_DIALOG); 
 
@@ -117,10 +116,6 @@ passphrase_mbox(const gchar *uid_hint, const gchar *pass_hint, gint prev_bad, gi
     pass_entry = gtk_entry_new();
     gtk_box_pack_start(GTK_BOX(vbox), pass_entry, FALSE, FALSE, 0);
     gtk_entry_set_visibility(GTK_ENTRY(pass_entry), FALSE);
-#ifdef MAEMO
-    hildon_gtk_entry_set_input_mode(GTK_ENTRY(pass_entry), 
-    	HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_INVISIBLE);
-#endif
     gtk_widget_grab_focus(pass_entry);
 
     gtkut_stock_button_set_create(&confirm_box, 
@@ -244,9 +239,9 @@ linelen (const gchar *s)
 }
 
 static GtkWidget *
-create_description(const gchar *uid_hint, const gchar *pass_hint, gint prev_bad, gint new_key)
+create_description(const gchar *uid_hint, gint prev_bad, gint new_key)
 {
-    const gchar *uid = NULL, *info = NULL;
+    const gchar *uid = NULL;
     gchar *buf;
     GtkWidget *label;
     gchar *my_uid = NULL;
@@ -254,10 +249,6 @@ create_description(const gchar *uid_hint, const gchar *pass_hint, gint prev_bad,
         uid = _("[no user id]");
     else
         uid = uid_hint;
-    if (!pass_hint)
-        info = "";
-    else
-        info = pass_hint;
 
     my_uid = g_strdup(uid);
     while (strchr(my_uid, '<')) 
