@@ -17,6 +17,11 @@
  * 
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#include "claws-features.h"
+#endif
+
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -123,7 +128,7 @@ static void prefs_gpg_create_widget_func(PrefsPage *_page,
 	gtk_box_pack_start (GTK_BOX (hbox1), label_expire1, FALSE, FALSE, 0);
 
 	spinbtn_store_passphrase_adj =
-	    gtk_adjustment_new(1, 0, 1440, 1, 10, 0);
+	    GTK_ADJUSTMENT(gtk_adjustment_new(1, 0, 1440, 1, 10, 0));
 	spinbtn_store_passphrase =
 	    gtk_spin_button_new(GTK_ADJUSTMENT
 				(spinbtn_store_passphrase_adj), 1, 0);
@@ -645,3 +650,8 @@ void prefs_gpg_remove_skip_encryption_warning(const gchar *systemid)
 	}
 	prefs_gpg_save_config();
 }
+
+gboolean prefs_gpg_auto_check_signatures(void)
+{
+	return prefs_gpg_get_config()->auto_check_signatures;
+}
