@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #ifdef USE_GPGME
@@ -39,6 +40,7 @@
 #include <plugins/pgpcore/sgpgme.h>
 #include <plugins/pgpcore/prefs_gpg.h>
 #include <plugins/pgpcore/passphrase.h>
+#include <plugins/pgpcore/pgp_utils.h>
 
 #include "prefs_common.h"
 
@@ -239,10 +241,6 @@ static SignatureStatus pgpmime_get_sig_status(MimeInfo *mimeinfo)
 	
 	cm_return_val_if_fail(data != NULL, SIGNATURE_INVALID);
 
-	if (data->sigstatus == NULL && 
-	    prefs_gpg_get_config()->auto_check_signatures)
-		pgpmime_check_signature(mimeinfo);
-	
 	return sgpgme_sigstat_gpgme_to_privacy(data->ctx, data->sigstatus);
 }
 
@@ -252,23 +250,15 @@ static gchar *pgpmime_get_sig_info_short(MimeInfo *mimeinfo)
 	
 	cm_return_val_if_fail(data != NULL, g_strdup("Error"));
 
-	if (data->sigstatus == NULL && 
-	    prefs_gpg_get_config()->auto_check_signatures)
-		pgpmime_check_signature(mimeinfo);
-	
 	return sgpgme_sigstat_info_short(data->ctx, data->sigstatus);
 }
 
 static gchar *pgpmime_get_sig_info_full(MimeInfo *mimeinfo)
 {
 	PrivacyDataPGP *data = (PrivacyDataPGP *) mimeinfo->privacy;
-	
+
 	cm_return_val_if_fail(data != NULL, g_strdup("Error"));
 
-	if (data->sigstatus == NULL && 
-	    prefs_gpg_get_config()->auto_check_signatures)
-		pgpmime_check_signature(mimeinfo);
-	
 	return sgpgme_sigstat_info_full(data->ctx, data->sigstatus);
 }
 
@@ -276,7 +266,10 @@ static gboolean pgpmime_is_encrypted(MimeInfo *mimeinfo)
 {
 	MimeInfo *tmpinfo;
 	const gchar *tmpstr;
-	
+	const gchar *begin_indicator = "-----BEGIN PGP MESSAGE-----";
+	const gchar *end_indicator = "-----END PGP MESSAGE-----";
+	gchar *textdata;
+
 	if (mimeinfo->type != MIMETYPE_MULTIPART)
 		return FALSE;
 	if (g_ascii_strcasecmp(mimeinfo->subtype, "encrypted"))
@@ -299,6 +292,21 @@ static gboolean pgpmime_is_encrypted(MimeInfo *mimeinfo)
 	if (g_ascii_strcasecmp(tmpinfo->subtype, "octet-stream"))
 		return FALSE;
 	
+	textdata = get_part_as_string(tmpinfo);
+	if (!textdata)
+		return FALSE;
+	
+	if (!pgp_locate_armor_header(textdata, begin_indicator)) {
+		g_free(textdata);
+		return FALSE;
+	}
+	if (!pgp_locate_armor_header(textdata, end_indicator)) {
+		g_free(textdata);
+		return FALSE;
+	}
+
+	g_free(textdata);
+
 	return TRUE;
 }
 
@@ -533,8 +541,8 @@ gboolean pgpmime_sign(MimeInfo *mimeinfo, PrefsAccount *account, const gchar *fr
 	if (result && result->signatures) {
 		gpgme_new_signature_t sig = result->signatures;
 		if (gpgme_get_protocol(ctx) == GPGME_PROTOCOL_OpenPGP) {
-			micalg = g_strdup_printf("PGP-%s", gpgme_hash_algo_name(
-				result->signatures->hash_algo));
+			micalg = g_strdup_printf("pgp-%s", g_ascii_strdown(gpgme_hash_algo_name(
+				result->signatures->hash_algo),-1));
 		} else {
 			micalg = g_strdup(gpgme_hash_algo_name(
 				result->signatures->hash_algo));
@@ -761,6 +769,7 @@ static PrivacySystem pgpmime_system = {
 	pgpmime_encrypt,
 	pgpmime_get_encrypt_warning,
 	pgpmime_inhibit_encrypt_warning,
+	prefs_gpg_auto_check_signatures,
 };
 
 void pgpmime_init()
