@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #define __PREFS_COMMON_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -104,9 +104,6 @@ typedef enum
 
 struct _PrefsCommon
 {
-#ifdef MAEMO
-	gchar *data_root;
-#endif
 	/* Receive */
 	gboolean use_extinc;
 	gchar *extinc_cmd;
@@ -118,11 +115,6 @@ struct _PrefsCommon
  	gboolean newmail_notify_auto;
  	gboolean newmail_notify_manu;
  	gchar   *newmail_notify_cmd;
-#ifdef MAEMO
-	gboolean maemo_show_led;
-	gboolean maemo_play_sound;
-	gboolean maemo_show_banner;
-#endif
 	RecvDialogMode recv_dialog_mode;
 	gint receivewin_width;
 	gint receivewin_height;
@@ -138,6 +130,7 @@ struct _PrefsCommon
 	gchar *outgoing_charset;
 	TransferEncodingMethod encoding_method;
 	gboolean outgoing_fallback_to_ascii;
+	gboolean warn_empty_subj;
 
 	gboolean allow_jisx0201_kana;
 
@@ -378,6 +371,8 @@ struct _PrefsCommon
 	/* Other */
 #ifndef G_OS_WIN32
 	gchar *uri_cmd;
+#else
+	gchar *gtk_theme;
 #endif
 	gchar *ext_editor_cmd;
 	gboolean cmds_use_system_default;
