@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -123,7 +124,7 @@ static gchar *defaults[] =
 	"-Message-ID",
 	"-In-Reply-To",
 	"-References",
-	"-Mime-Version",
+	"-MIME-Version",
 	"-Content-Type",
 	"-Content-Transfer-Encoding",
 	"-X-UIDL",
@@ -152,7 +153,7 @@ static gchar *defaults[] =
 	"-Message-ID",
 	"-In-Reply-To",
 	"-References",
-	"-Mime-Version",
+	"-MIME-Version",
 	"-Content-Type",
 	"-Content-Transfer-Encoding",
 	"-X-UIDL",
@@ -274,9 +275,17 @@ static void prefs_display_header_create(void)
 	gtk_widget_show (hdr_label);
 	gtk_box_pack_start (GTK_BOX (hbox1), hdr_label, FALSE, FALSE, 0);
 
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	hdr_combo = gtk_combo_box_entry_new_text();
+#else
+	hdr_combo = gtk_combo_box_text_new_with_entry();
+#endif
 	for(i=0; i < 9 ; i++)
+#if !GTK_CHECK_VERSION(2, 24, 0)
 		gtk_combo_box_append_text(GTK_COMBO_BOX (hdr_combo),
+#else
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT (hdr_combo),
+#endif
 			(*defaults[i] == '-') ? defaults[i]+1 : defaults[i]);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(hdr_combo), 0);
 	gtk_widget_show (hdr_combo);
@@ -578,7 +587,11 @@ static void prefs_display_header_list_view_set_row(gboolean hidden)
 	gchar *entry_text;
 	GtkTreeModel *model;
 
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	entry_text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(dispheader.hdr_combo));
+#else
+	entry_text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(dispheader.hdr_combo));
+#endif
 	if (!entry_text)
 		entry_text = gtk_editable_get_chars(
 				GTK_EDITABLE(gtk_bin_get_child(GTK_BIN(dispheader.hdr_combo))),0,-1);
