@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -45,11 +46,13 @@
 #include "gtkutils.h"
 #include "alertpanel.h"
 #include "folder.h"
+#include "folder_item_prefs.h"
 #include "filtering.h"
 #include "addr_compl.h"
 #include "manual.h"
 #include "combobox.h"
 #include "menu.h"
+#include "account.h"
 
 #include "matcher_parser.h"
 #include "matcher.h"
@@ -260,7 +263,7 @@ static void prefs_filtering_account_option_menu_populate(void)
 
 	cm_return_if_fail(accounts != NULL);
 
-	COMBOBOX_ADD(filtering.account_combobox_list, Q_("Filtering Account Menu|All"), 0);
+	COMBOBOX_ADD(filtering.account_combobox_list, C_("Filtering Account Menu", "All"), 0);
 	COMBOBOX_ADD(filtering.account_combobox_list, NULL, 0);
 	for (; accounts != NULL; accounts = accounts->next) {
 		PrefsAccount *ac = (PrefsAccount *)accounts->data;
@@ -418,7 +421,7 @@ static void prefs_filtering_create(void)
                     	  (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
                     	  (GtkAttachOptions) (0), 0, 0);
 
-	cond_btn = gtk_button_new_with_label (_(" Define... "));
+	cond_btn =  gtk_button_new_with_mnemonic (_(" D_efine... "));
 	gtk_widget_show (cond_btn);
   	gtk_table_attach (GTK_TABLE (table), cond_btn, 2, 3, 2, 3,
                     	  (GtkAttachOptions) (GTK_FILL),
@@ -440,7 +443,7 @@ static void prefs_filtering_create(void)
                     	  (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
                     	  (GtkAttachOptions) (0), 0, 0);
 
-	action_btn = gtk_button_new_with_label (_(" Define... "));
+	action_btn =  gtk_button_new_with_mnemonic (_(" De_fine... "));
 	gtk_widget_show (action_btn);
   	gtk_table_attach (GTK_TABLE (table), action_btn, 2, 3, 3, 4,
                     	  (GtkAttachOptions) (GTK_FILL),
@@ -471,7 +474,7 @@ static void prefs_filtering_create(void)
 	CLAWS_SET_TIP(reg_btn,
 			_("Append the new rule above to the list"));
 
-	subst_btn = gtkut_get_replace_btn (_("Replace"));
+	subst_btn = gtkut_get_replace_btn (_("_Replace"));
 	gtk_widget_show (subst_btn);
 	gtk_box_pack_start (GTK_BOX (btn_hbox), subst_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT (subst_btn), "clicked",
@@ -480,15 +483,18 @@ static void prefs_filtering_create(void)
 	CLAWS_SET_TIP(subst_btn,
 			_("Replace the selected rule in list with the rule above"));
 
-	del_btn = gtk_button_new_from_stock (GTK_STOCK_DELETE);
-	gtk_widget_show (del_btn);
+	del_btn = gtk_button_new_with_mnemonic (_("Re_move"));
+	gtk_button_set_image(GTK_BUTTON(del_btn),
+			gtk_image_new_from_stock(GTK_STOCK_REMOVE,GTK_ICON_SIZE_BUTTON));
 	gtk_box_pack_start (GTK_BOX (btn_hbox), del_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT (del_btn), "clicked",
 			G_CALLBACK(prefs_filtering_delete_cb), NULL);
 	CLAWS_SET_TIP(del_btn,
 			_("Delete the selected rule from the list"));
 
-	clear_btn = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
+	clear_btn = gtk_button_new_with_mnemonic (_("C_lear"));
+	gtk_button_set_image(GTK_BUTTON(clear_btn),
+			gtk_image_new_from_stock(GTK_STOCK_CLEAR,GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show (clear_btn);
 	gtk_box_pack_start (GTK_BOX (btn_hbox), clear_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT (clear_btn), "clicked",
@@ -526,7 +532,7 @@ static void prefs_filtering_create(void)
 			_("Move the selected rule to the top"));
 
 #ifndef GENERIC_UMPC
-	page_up_btn = gtk_button_new_with_mnemonic (_("Page up"));
+	page_up_btn = gtk_button_new_with_mnemonic (_("Page u_p"));
 	gtk_button_set_image(GTK_BUTTON(page_up_btn),
 			gtk_image_new_from_stock(GTK_STOCK_GO_UP,GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show (page_up_btn);
@@ -554,7 +560,7 @@ static void prefs_filtering_create(void)
 			_("Move the selected rule down"));
 
 #ifndef GENERIC_UMPC
-	page_down_btn = gtk_button_new_with_mnemonic (_("Page down"));
+	page_down_btn = gtk_button_new_with_mnemonic (_("Page dow_n"));
 	gtk_button_set_image(GTK_BUTTON(page_down_btn),
 			gtk_image_new_from_stock(GTK_STOCK_GO_DOWN,GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show (page_down_btn);
@@ -858,7 +864,7 @@ static void prefs_filtering_set_dialog(const gchar *header, const gchar *key)
 				account_name = ac_prefs->account_name;
 		}
 		if (account_name == NULL)
-			account_name = (gchar *)Q_("Filtering Account Menu|All");
+			account_name = (gchar *)C_("Filtering Account Menu", "All");
 
 		cond_str = filteringprop_to_string(prop);
 		subst_char(cond_str, '\t', ':');
@@ -910,7 +916,7 @@ static gboolean prefs_filtering_search_func_cb (GtkTreeModel *model, gint column
 	if (!store_string || !key) return FALSE;
 
 
-	retval = (strncmp (key, store_string, strlen(key)) != 0);
+	retval = (g_ascii_strncasecmp (key, store_string, strlen(key)) != 0);
 
 	g_free(store_string);
 	debug_print("selecting row\n");
@@ -972,7 +978,7 @@ static gint prefs_filtering_list_view_set_row(gint row, FilteringProp * prop)
 	GtkListStore *list_store;
 	gchar *name = NULL;
 	gint account_id = 0;
-	gchar *account_name = (gchar *)Q_("Filtering Account Menu|All");
+	gchar *account_name = (gchar *)C_("Filtering Account Menu", "All");
 	gboolean enabled = TRUE;
 
 	if (prop)
@@ -1286,14 +1292,13 @@ static void prefs_filtering_top(gpointer action, gpointer data)
 
 static void prefs_filtering_page_up(gpointer action, gpointer data)
 {
-	gint row, target_row, n_rows;
+	gint row, target_row;
 	GtkTreeIter selected, target;
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GdkRectangle cell_rect, view_rect;
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(filtering.cond_list_view));	
-	n_rows = gtk_tree_model_iter_n_children(model, NULL);
 	row = gtkut_list_view_get_selected_row(filtering.cond_list_view);
 	if (row <= 1)
 		return;
@@ -1798,15 +1803,8 @@ static GtkWidget *prefs_filtering_list_view_create(void)
 	g_object_set(list_view, "allow-checkbox-mode", FALSE, NULL);
 #endif
 
-#ifndef MAEMO
 	g_signal_connect(G_OBJECT(list_view), "popup-menu",
 			 G_CALLBACK(prefs_filtering_list_popup_menu), list_view);
-#else
-	gtk_widget_tap_and_hold_setup(GTK_WIDGET(list_view), NULL, NULL,
-			GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS);
-	g_signal_connect(G_OBJECT(list_view), "tap-and-hold",
-			 G_CALLBACK(prefs_filtering_list_popup_menu), list_view);
-#endif
 	g_signal_connect(G_OBJECT(list_view), "button-press-event",
 			G_CALLBACK(prefs_filtering_list_btn_pressed), list_view);
 	
