@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #define _GNU_SOURCE
@@ -451,11 +452,9 @@ void prefs_set_default(PrefParam *param)
 						g_strconcat(get_home_dir(),
 							    param[i].defval + 1,
 							    NULL);
-				else if (param[i].defval[0] != '\0')
+				else 
 					*((gchar **)param[i].data) =
 						g_strdup(param[i].defval);
-				else
-					*((gchar **)param[i].data) = NULL;
 			} else
 				*((gchar **)param[i].data) = NULL;
 			break;
