@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,16 +28,9 @@ typedef struct _PrefParam	PrefParam;
 typedef struct _PrefsDialog	PrefsDialog;
 
 #include "prefs.h"
-#include "account.h"
 #include "gtk/prefswindow.h"
 
-#define HSPACING_NARROW		4
-#define VSPACING		10
-#define VSPACING_NARROW		4
-#define VSPACING_NARROW_2	2
-#define VBOX_BORDER		8
-#define DEFAULT_ENTRY_WIDTH	80
-#define PREFSBUFSIZE		1024
+#define PREFSBUFSIZE		32768
 
 typedef enum
 {
