@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -54,6 +55,9 @@
 #include "matcher_parser.h"
 #include "colorlabel.h"
 #include "tags.h"
+#ifndef USE_NEW_ADDRBOOK
+	#include "addressbook.h"
+#endif
 
 #ifndef USE_NEW_ADDRBOOK
 static void prefs_matcher_addressbook_select(void);
@@ -179,7 +183,10 @@ enum {
 	CRITERIA_TAGGED = 36,
 
 	CRITERIA_HAS_ATTACHMENT = 37,
-	CRITERIA_SIGNED = 38
+	CRITERIA_SIGNED = 38,
+
+	CRITERIA_AGE_GREATER_HOURS = 39,
+	CRITERIA_AGE_LOWER_HOURS = 40
 };
 
 enum {
@@ -199,8 +206,9 @@ enum {
 };
 
 enum {
-	AGE_DAYS  = 0,
-	AGE_WEEKS = 1
+	AGE_HOURS = 0,
+	AGE_DAYS  = 1,
+	AGE_WEEKS = 2
 };
 
 enum {
@@ -322,6 +330,7 @@ static void prefs_matcher_models_create(void)
 	matcher.model_age = GTK_TREE_MODEL(store);
 
 	store = gtk_list_store_new(3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_BOOLEAN);
+	COMBOBOX_ADD(store, _("hours"), AGE_HOURS);
 	COMBOBOX_ADD(store, _("days"), AGE_DAYS);
 	COMBOBOX_ADD(store, _("weeks"), AGE_WEEKS);
 	matcher.model_age_units = GTK_TREE_MODEL(store);
@@ -530,7 +539,9 @@ static void prefs_matcher_create(void)
 
 	GtkWidget *test_btn;
 	GtkWidget *addressbook_select_btn;
+#if !GTK_CHECK_VERSION(3, 0, 0)
 	GtkWidget *color_optmenu;
+#endif
 
 	static GdkGeometry geometry;
 	GtkSizeGroup *size_group;
@@ -637,7 +648,15 @@ static void prefs_matcher_create(void)
 	gtk_box_pack_start(GTK_BOX(upper_hbox), criteria_label2, FALSE, FALSE, 0);
 
 	/* headers combo box entry */
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	headers_combo = gtk_combo_box_entry_new_with_model(matcher.model_headers, 0);
+#else
+	headers_combo = gtk_combo_box_new_with_model_and_entry(matcher.model_headers);
+	GtkCellRenderer *cell = gtk_cell_renderer_text_new();
+	gtk_cell_renderer_set_alignment(cell, 0.0, 0.5);
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(headers_combo), cell, TRUE);
+	gtk_combo_box_set_entry_text_column(GTK_COMBO_BOX(headers_combo), 0);
+#endif
 	gtk_widget_set_size_request(headers_combo, 100, -1);
 	gtk_box_pack_start(GTK_BOX(upper_hbox), headers_combo, TRUE, TRUE, 0);
 	header_entry = gtk_bin_get_child(GTK_BIN((headers_combo)));
@@ -654,7 +673,7 @@ static void prefs_matcher_create(void)
 	gtk_widget_set_size_request(addressbook_folder_combo, 150, -1);
 	gtk_box_pack_start(GTK_BOX(upper_hbox), addressbook_folder_combo, TRUE, TRUE, 0);			 
 
-	addressbook_select_btn = gtk_button_new_with_label(_("Select ..."));
+	addressbook_select_btn = gtk_button_new_with_label(_("Select..."));
 	gtk_box_pack_start(GTK_BOX(upper_hbox), addressbook_select_btn, FALSE, FALSE, 0);
 #ifndef USE_NEW_ADDRBOOK
 	g_signal_connect(G_OBJECT (addressbook_select_btn), "clicked",
@@ -685,7 +704,7 @@ static void prefs_matcher_create(void)
 	
 	/* address header name */
 	header_addr_combo = combobox_text_new(TRUE,
-			      Q_("Filtering Matcher Menu|All"), _("Any"),
+			      C_("Filtering Matcher Menu", "All"), _("Any"),
 			      "From", "To", "Cc", "Reply-To", "Sender", NULL);
 	gtk_box_pack_start(GTK_BOX(match_hbox), header_addr_combo, FALSE, FALSE, 0);
 	header_addr_entry = gtk_bin_get_child(GTK_BIN((header_addr_combo)));
@@ -715,10 +734,14 @@ static void prefs_matcher_create(void)
 
 	hbox = gtk_hbox_new(FALSE, HSPACING_NARROW);
 	gtk_size_group_add_widget(size_group, hbox);
-	PACK_CHECK_BUTTON(hbox, case_checkbtn, _("Case sensitive"));
+
+	vbox = gtk_vbox_new(FALSE, VSPACING_NARROW);
+	PACK_CHECK_BUTTON(vbox, case_checkbtn, _("Case sensitive"));
 #ifndef G_OS_WIN32
-	PACK_CHECK_BUTTON(hbox, regexp_checkbtn, _("Use regexp"));
+	PACK_CHECK_BUTTON(vbox, regexp_checkbtn, _("Use regexp"));
 #endif
+	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
+
 	gtk_box_pack_end(GTK_BOX(hbox), gtk_label_new(""), TRUE, TRUE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 2, 3, 2, 3,
 			 GTK_FILL, GTK_SHRINK, 4, 0);
@@ -746,13 +769,15 @@ static void prefs_matcher_create(void)
 	g_signal_connect(G_OBJECT(reg_btn), "clicked",
 			 G_CALLBACK(prefs_matcher_register_cb), NULL);
 
-	subst_btn = gtkut_get_replace_btn(_("Replace"));
+	subst_btn = gtkut_get_replace_btn(_("_Replace"));
 	gtk_box_pack_start(GTK_BOX(btn_hbox), subst_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(subst_btn), "clicked",
 			 G_CALLBACK(prefs_matcher_substitute_cb),
 			 NULL);
 
-	del_btn = gtk_button_new_from_stock(GTK_STOCK_DELETE);
+	del_btn = gtk_button_new_with_mnemonic (_("Re_move"));
+	gtk_button_set_image(GTK_BUTTON(del_btn),
+			gtk_image_new_from_stock(GTK_STOCK_REMOVE,GTK_ICON_SIZE_BUTTON));
 	gtk_box_pack_start(GTK_BOX(btn_hbox), del_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(del_btn), "clicked",
 			 G_CALLBACK(prefs_matcher_delete_cb), NULL);
@@ -838,7 +863,9 @@ static void prefs_matcher_create(void)
 #ifndef USE_NEW_ADDRBOOK
 	matcher.addressbook_select_btn = addressbook_select_btn;
 #endif
+#if !GTK_CHECK_VERSION(3, 0, 0)
 	matcher.color_optmenu = color_optmenu;
+#endif
 	matcher.match_label = match_label;
 	matcher.criteria_label2 = criteria_label2;
 	matcher.headers_combo = headers_combo;
@@ -1124,6 +1151,10 @@ static gint prefs_matcher_get_criteria_from_matching(gint matching_id)
 	case MATCHCRITERIA_NOT_HEADER:
 	case MATCHCRITERIA_HEADER:
 		return CRITERIA_HEADER;
+	case MATCHCRITERIA_AGE_GREATER_HOURS:
+		return CRITERIA_AGE_GREATER_HOURS;
+	case MATCHCRITERIA_AGE_LOWER_HOURS:
+		return CRITERIA_AGE_LOWER_HOURS;
 	case MATCHCRITERIA_AGE_GREATER:
 		return CRITERIA_AGE_GREATER;
 	case MATCHCRITERIA_AGE_LOWER:
@@ -1218,6 +1249,10 @@ static gint prefs_matcher_get_matching_from_criteria(gint criteria_id)
 		return MATCHCRITERIA_AGE_GREATER;
 	case CRITERIA_AGE_LOWER:
 		return MATCHCRITERIA_AGE_LOWER;
+	case CRITERIA_AGE_GREATER_HOURS:
+		return MATCHCRITERIA_AGE_GREATER_HOURS;
+	case CRITERIA_AGE_LOWER_HOURS:
+		return MATCHCRITERIA_AGE_LOWER_HOURS;
 	case CRITERIA_SCORE_GREATER:
 		return MATCHCRITERIA_SCORE_GREATER;
 	case CRITERIA_SCORE_LOWER:
@@ -1427,12 +1462,6 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 	if (value_criteria == -1)
 		return NULL;
 
-	criteria = prefs_matcher_get_matching_from_criteria(value_criteria);
-
-	value_pred = prefs_matcher_get_pred(value_criteria);
-	if(value_pred)
-		criteria = prefs_matcher_not_criteria(criteria);
-
 #ifndef G_OS_WIN32
 	use_regexp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(matcher.regexp_checkbtn));
 #else
@@ -1511,6 +1540,12 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 		sel = gtk_combo_box_get_active(GTK_COMBO_BOX(matcher.match_combo2));
 		if(sel == AGE_WEEKS)
 			value *= 7;
+		else if (sel == AGE_HOURS) {
+			if (value_criteria == CRITERIA_AGE_GREATER)
+				value_criteria = CRITERIA_AGE_GREATER_HOURS;
+			else 
+				value_criteria = CRITERIA_AGE_LOWER_HOURS;
+		}
 		break;
 			
 	case CRITERIA_SCORE_GREATER:
@@ -1566,7 +1601,7 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 		if (*expr == '\0') {
 			gchar *tmp;
 
-			if (g_utf8_collate(header, Q_("Filtering Matcher Menu|All")) == 0)
+			if (g_utf8_collate(header, C_("Filtering Matcher Menu", "All")) == 0)
 				tmp = g_strdup(_("all addresses in all headers"));
 			else
 			if (g_utf8_collate(header, _("Any")) == 0)
@@ -1581,7 +1616,7 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 		    return NULL;
 		}
 		/* store UNtranslated "Any"/"All" in matcher expressions */
-		if (g_utf8_collate(header, Q_("Filtering Matcher Menu|All")) == 0)
+		if (g_utf8_collate(header, C_("Filtering Matcher Menu", "All")) == 0)
 			header = "All";
 		else
 			if (g_utf8_collate(header, _("Any")) == 0)
@@ -1591,7 +1626,13 @@ static MatcherProp *prefs_matcher_dialog_to_matcher(void)
 		break;
 	}
 
-	matcherprop = matcherprop_new_create(criteria, header, matchtype,
+	criteria = prefs_matcher_get_matching_from_criteria(value_criteria);
+
+	value_pred = prefs_matcher_get_pred(value_criteria);
+	if(value_pred)
+		criteria = prefs_matcher_not_criteria(criteria);
+
+	matcherprop = matcherprop_new(criteria, header, matchtype,
 				      expr, value);
 
 	return matcherprop;
@@ -1923,6 +1964,7 @@ static void prefs_matcher_criteria_select(GtkWidget *widget,
 		gtk_spin_button_set_range(GTK_SPIN_BUTTON(
 				  matcher.numeric_entry), 0, 1000);
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(matcher.numeric_entry), 0);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(matcher.match_combo2), AGE_DAYS);
 		gtk_label_set_text(GTK_LABEL(matcher.match_label), _("Age is"));
 		break;
 	case MATCH_FLAG:
@@ -2127,6 +2169,7 @@ static gchar *test_desc_strings[] = {
 static DescriptionWindow test_desc_win = { 
 	NULL,
         NULL, 
+	TRUE,
         2,
         N_("Match Type: 'Test'"),
 	N_("'Test' allows you to test a message or message element "
@@ -2248,6 +2291,8 @@ static void prefs_matcher_set_criteria(const gint criteria)
 		break;
 	case CRITERIA_AGE_GREATER:
 	case CRITERIA_AGE_LOWER:
+	case CRITERIA_AGE_GREATER_HOURS:
+	case CRITERIA_AGE_LOWER_HOURS:
 		match_criteria = MATCH_AGE;
 		break;
 	case CRITERIA_SCORE_GREATER:
@@ -2453,7 +2498,7 @@ static gboolean prefs_matcher_selected(GtkTreeSelection *selector,
 		/* matcher expressions contain UNtranslated "Any"/"All",
 		  select the relevant translated combo item */
 		if (strcasecmp(prop->header, "All") == 0)
-			header = (gchar*)Q_("Filtering Matcher Menu|All");
+			header = (gchar*)C_("Filtering Matcher Menu", "All");
 		else
 			if (strcasecmp(prop->header, "Any") == 0)
 				header = _("Any");
@@ -2484,6 +2529,14 @@ static gboolean prefs_matcher_selected(GtkTreeSelection *selector,
 		}
 		break;
 		
+	case MATCHCRITERIA_AGE_GREATER_HOURS:
+	case MATCHCRITERIA_AGE_LOWER_HOURS:
+		gtk_combo_box_set_active(GTK_COMBO_BOX(matcher.match_combo2),
+					 AGE_HOURS);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(
+				matcher.numeric_entry), prop->value);
+		break;
+		
 	case MATCHCRITERIA_SCORE_GREATER:
 	case MATCHCRITERIA_SCORE_LOWER:
 	case MATCHCRITERIA_SCORE_EQUAL:
