@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2012 Colin Leroy <colin@colino.net> & The Claws Mail Team
+ * Copyright (C) 2005-2013 Colin Leroy <colin@colino.net> & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -55,16 +56,10 @@ typedef struct _ReceivePage
 	GtkWidget *checkbtn_chkonstartup;
 	GtkWidget *checkbtn_openinbox;
 	GtkWidget *checkbtn_scan_after_inc;
-#ifndef MAEMO
 	GtkWidget *checkbtn_newmail_auto;
 	GtkWidget *checkbtn_newmail_manu;
 	GtkWidget *entry_newmail_notify_cmd;
 	GtkWidget *hbox_newmail_notify;
-#else
-	GtkWidget *checkbtn_maemo_show_led;
-	GtkWidget *checkbtn_maemo_play_sound;
-	GtkWidget *checkbtn_maemo_show_banner;
-#endif
 	GtkWidget *optmenu_recvdialog;
 	GtkWidget *checkbtn_no_recv_err_panel;
 	GtkWidget *checkbtn_close_recv_dialog;
@@ -72,7 +67,6 @@ typedef struct _ReceivePage
 
 ReceivePage *prefs_receive;
 
-#ifndef MAEMO
 static void prefs_common_recv_dialog_newmail_notify_toggle_cb(GtkWidget *w, gpointer data)
 {
 	gboolean toggled;
@@ -83,7 +77,6 @@ static void prefs_common_recv_dialog_newmail_notify_toggle_cb(GtkWidget *w, gpoi
 			(GTK_TOGGLE_BUTTON(prefs_receive->checkbtn_newmail_auto));
 	gtk_widget_set_sensitive(prefs_receive->hbox_newmail_notify, toggled);
 }
-#endif
 
 
 static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window, 
@@ -108,18 +101,12 @@ static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *checkbtn_scan_after_inc;
 
 	GtkWidget *frame;
-#ifndef MAEMO
 	GtkWidget *vbox3;
 	GtkWidget *hbox_newmail_notify;
 	GtkWidget *checkbtn_newmail_auto;
 	GtkWidget *checkbtn_newmail_manu;
 	GtkWidget *entry_newmail_notify_cmd;
 	GtkWidget *label_newmail_notify_cmd;
-#else
-	GtkWidget *checkbtn_maemo_show_led;
-	GtkWidget *checkbtn_maemo_play_sound;
-	GtkWidget *checkbtn_maemo_show_banner;
-#endif
 	
 	GtkWidget *label_recvdialog;
 	GtkListStore *menu;
@@ -161,7 +148,7 @@ static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window,
 	PACK_CHECK_BUTTON (hbox_autochk, checkbtn_autochk,
 			   _("Check for new mail every"));
 
-	spinbtn_autochk_adj = gtk_adjustment_new (5, 1, 100, 1, 10, 0);
+	spinbtn_autochk_adj = GTK_ADJUSTMENT(gtk_adjustment_new (5, 1, 100, 1, 10, 0));
 	spinbtn_autochk = gtk_spin_button_new
 		(GTK_ADJUSTMENT (spinbtn_autochk_adj), 1, 0);
 	gtk_widget_show (spinbtn_autochk);
@@ -209,13 +196,12 @@ static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window,
 			   _("Don't popup error dialog on receive error"));
 
  	vbox2 = gtkut_get_options_frame(vbox1, &frame, 
-					_("After checking for new mail"));
+					_("After receiving new mail"));
 
  	PACK_CHECK_BUTTON (vbox2, checkbtn_openinbox, _("Go to Inbox"));
  	PACK_CHECK_BUTTON (vbox2, checkbtn_scan_after_inc,
  			   _("Update all local folders"));
 
-#ifndef MAEMO 
  	vbox3 = gtkut_get_options_frame(vbox2, &frame, _("Run command"));
  	
 	hbox = gtk_hbox_new (TRUE, 8);
@@ -255,20 +241,6 @@ static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window,
 		prefs_common.newmail_notify_manu);
 	gtk_entry_set_text(GTK_ENTRY(entry_newmail_notify_cmd), 
 		prefs_common.newmail_notify_cmd);
-#else
- 	PACK_CHECK_BUTTON (vbox2, checkbtn_maemo_show_led, _("Blink LED"));
- 	PACK_CHECK_BUTTON (vbox2, checkbtn_maemo_play_sound, _("Play sound"));
- 	PACK_CHECK_BUTTON (vbox2, checkbtn_maemo_show_banner,
- 			   _("Show info banner"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_maemo_show_led),
-		prefs_common.maemo_show_led);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_maemo_play_sound),
-		prefs_common.maemo_play_sound);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_maemo_show_banner),
-		prefs_common.maemo_show_banner);
-
-#endif
-
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_autochk),
 		prefs_common.autochk_newmail);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_incext),
@@ -299,31 +271,22 @@ static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window,
 	prefs_receive->checkbtn_chkonstartup = checkbtn_chkonstartup;
 	prefs_receive->checkbtn_openinbox = checkbtn_openinbox;
 	prefs_receive->checkbtn_scan_after_inc = checkbtn_scan_after_inc;
-
-#ifndef MAEMO 
 	prefs_receive->checkbtn_newmail_auto = checkbtn_newmail_auto;
 	prefs_receive->checkbtn_newmail_manu = checkbtn_newmail_manu;
 	prefs_receive->entry_newmail_notify_cmd = entry_newmail_notify_cmd;
 	prefs_receive->hbox_newmail_notify = hbox_newmail_notify;
-#else
-	prefs_receive->checkbtn_maemo_show_led = checkbtn_maemo_show_led;
-	prefs_receive->checkbtn_maemo_play_sound = checkbtn_maemo_play_sound;
-	prefs_receive->checkbtn_maemo_show_banner = checkbtn_maemo_show_banner;
-#endif
 
 	prefs_receive->optmenu_recvdialog = optmenu_recvdialog;
 	prefs_receive->checkbtn_no_recv_err_panel = checkbtn_no_recv_err_panel;
 	prefs_receive->checkbtn_close_recv_dialog = checkbtn_close_recv_dialog;
 	prefs_receive->page.widget = vbox1;
 
-#ifndef MAEMO 
 	g_signal_connect(G_OBJECT(checkbtn_newmail_auto), "toggled",
 			 G_CALLBACK(prefs_common_recv_dialog_newmail_notify_toggle_cb),
 			 NULL);
 	g_signal_connect(G_OBJECT(checkbtn_newmail_manu), "toggled",
 			 G_CALLBACK(prefs_common_recv_dialog_newmail_notify_toggle_cb),
 			 NULL);
-#endif
 }
 
 static void prefs_receive_save(PrefsPage *_page)
@@ -344,23 +307,10 @@ static void prefs_receive_save(PrefsPage *_page)
 	prefs_common.scan_all_after_inc = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_scan_after_inc));
 
-#ifndef MAEMO
 	prefs_common.newmail_notify_auto = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_newmail_auto));
 	prefs_common.newmail_notify_manu = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_newmail_manu));
-#else
-	prefs_common.maemo_show_led = TRUE;
-	if (!gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->checkbtn_maemo_show_led))) {
-		mainwindow_maemo_led_set(FALSE);
-		prefs_common.maemo_show_led = FALSE;
-	}
-	prefs_common.maemo_play_sound = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->checkbtn_maemo_play_sound));
-	prefs_common.maemo_show_banner = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->checkbtn_maemo_show_banner));
-#endif
 	prefs_common.autochk_newmail = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_autochk));
 	prefs_common.autochk_itv = gtk_spin_button_get_value_as_int(
@@ -370,12 +320,9 @@ static void prefs_receive_save(PrefsPage *_page)
 	g_free(prefs_common.extinc_cmd);
 	prefs_common.extinc_cmd = tmp;
 	
-#ifndef MAEMO
 	tmp = gtk_editable_get_chars(GTK_EDITABLE(page->entry_newmail_notify_cmd), 0, -1);
 	g_free(prefs_common.newmail_notify_cmd);
 	prefs_common.newmail_notify_cmd = tmp;
-#endif
-	
 	prefs_common.recv_dialog_mode =
 		combobox_get_active_data(GTK_COMBO_BOX(page->optmenu_recvdialog));
 
