@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2012 Hiroyuki Yamamoto & the Claws Mail team
+ * Copyright (C) 2002-2013 Hiroyuki Yamamoto & the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -382,8 +382,13 @@ static void prefs_toolbar_populate(ToolbarPage *prefs_toolbar)
 	GHashTable **hash;
 
 	prefs_toolbar->combo_action_list = toolbar_get_action_items(prefs_toolbar->source);
+#if !GTK_CHECK_VERSION(2, 24, 0)
 	combobox_set_popdown_strings(GTK_COMBO_BOX(prefs_toolbar->item_func_combo),
 				     prefs_toolbar->combo_action_list);
+#else
+	combobox_set_popdown_strings(GTK_COMBO_BOX_TEXT(prefs_toolbar->item_func_combo),
+				     prefs_toolbar->combo_action_list);
+#endif
 	
 	/* get currently defined sylpheed actions */
 	if (prefs_common.actions_list != NULL) {
@@ -1034,19 +1039,23 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 	btn_hbox = gtk_hbox_new(TRUE, 4);
 	gtk_box_pack_start(GTK_BOX(reg_hbox), btn_hbox, FALSE, FALSE, 0);
 
-	reg_btn = gtk_button_new_from_stock(GTK_STOCK_ADD);
+	reg_btn = gtk_button_new_with_mnemonic (_("A_dd"));
+	gtk_button_set_image(GTK_BUTTON(reg_btn),
+			gtk_image_new_from_stock(GTK_STOCK_ADD,GTK_ICON_SIZE_BUTTON));
 	gtk_box_pack_start(GTK_BOX(btn_hbox), reg_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(reg_btn), "clicked",
 			 G_CALLBACK(prefs_toolbar_register), 
 			 prefs_toolbar);
 
-	subst_btn = gtkut_get_replace_btn(_("Replace"));
+	subst_btn = gtkut_get_replace_btn(_("_Replace"));
 	gtk_box_pack_start(GTK_BOX(btn_hbox), subst_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(subst_btn), "clicked",
 			 G_CALLBACK(prefs_toolbar_substitute),
 			 prefs_toolbar);
 
-	del_btn = gtk_button_new_from_stock(GTK_STOCK_DELETE);
+	del_btn = gtk_button_new_with_mnemonic (_("Re_move"));
+	gtk_button_set_image(GTK_BUTTON(del_btn),
+			gtk_image_new_from_stock(GTK_STOCK_REMOVE,GTK_ICON_SIZE_BUTTON));
 	gtk_box_pack_start(GTK_BOX(btn_hbox), del_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(del_btn), "clicked",
 			 G_CALLBACK(prefs_toolbar_delete), 
@@ -1699,9 +1708,7 @@ static void icon_chooser_create(GtkButton *button, ToolbarPage *prefs_toolbar)
 	
 	icon_chooser_win = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "prefs_toolbar");
 	gtk_window_set_title(GTK_WINDOW(icon_chooser_win), _("Toolbar item icon"));
-#ifndef MAEMO
 	gtk_window_set_decorated(GTK_WINDOW(icon_chooser_win), FALSE);
-#endif
 	gdk_window_get_origin(gtk_widget_get_window(
 			GTK_WIDGET(prefs_toolbar->icon_button)), 
 			&x, &y);
