@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -283,7 +284,7 @@ static gboolean header_is_addr_field(const gchar *hdr)
 
 Header * procheader_parse_header(gchar * buf)
 {
-	gchar *p = buf;
+	gchar *p;
 	Header * header;
 	gboolean addr_field = FALSE;
 
