@@ -19,14 +19,16 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
+#define _GNU_SOURCE
+#include <stdio.h>
+
 #include "defs.h"
 
-#include <stdio.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <stdio.h>
 #include <string.h>
 #if HAVE_LOCALE_H
 #  include <locale.h>
@@ -51,6 +53,7 @@
 #include "prefs_gtk.h"
 #include "alertpanel.h"
 #include "timing.h"
+#include "privacy.h"
 
 static GHashTable *procmime_get_mime_type_table	(void);
 static MimeInfo *procmime_scan_file_short(const gchar *filename);
@@ -251,6 +254,40 @@ const gchar *procmime_mimeinfo_get_parameter(MimeInfo *mimeinfo, const gchar *na
 	return value;
 }
 
+#ifdef HAVE_FGETS_UNLOCKED
+#define SC_FGETS fgets_unlocked
+#define SC_FPUTS fputs_unlocked
+#define SC_FPUTC fputc_unlocked
+#define SC_FREAD fread_unlocked
+#define SC_FWRITE fwrite_unlocked
+#define SC_FEOF feof_unlocked
+#define SC_FERROR ferror_unlocked
+
+static FILE *procmime_fopen(const gchar *file, const gchar *mode)
+{
+	FILE *fp = g_fopen(file, mode);
+	if (!fp)
+		return NULL;
+	flockfile(fp);
+	return fp;
+}
+static int procmime_fclose(FILE *fp)
+{
+	funlockfile(fp);
+	return fclose(fp);
+}
+#else
+#define SC_FGETS fgets
+#define SC_FPUTS fputs
+#define SC_FPUTC fputc
+#define SC_FREAD fread
+#define SC_FWRITE fwrite
+#define SC_FEOF feof
+#define SC_FERROR ferror
+#define procmime_fopen g_fopen
+#define procmime_fclose fclose
+#endif
+
 #define FLUSH_LASTLINE() {							\
 	if (*lastline != '\0') {						\
 		gint llen = 0;							\
@@ -260,12 +297,12 @@ const gchar *procmime_mimeinfo_get_parameter(MimeInfo *mimeinfo, const gchar *na
 			/* this is flowed */					\
 			if (delsp)						\
 				lastline[llen-1] = '\0';			\
-			if (fputs(lastline, outfp) == EOF)			\
+			if (SC_FPUTS(lastline, outfp) == EOF)			\
 				err = TRUE;					\
 		} else {							\
-			if (fputs(lastline, outfp) == EOF)			\
+			if (SC_FPUTS(lastline, outfp) == EOF)			\
 				err = TRUE;					\
-			if (fputs("\n", outfp) == EOF)				\
+			if (SC_FPUTS("\n", outfp) == EOF)				\
 				err = TRUE;					\
 		}								\
 	} 									\
@@ -289,7 +326,7 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 				: mimeinfo->encoding_type;
 	gchar lastline[BUFFSIZE];
 	memset(lastline, 0, BUFFSIZE);
-		   
+
 	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
 
 	if (prefs_common.respect_flowed_format &&
@@ -312,7 +349,10 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 	    ))
 		return TRUE;
 
-	infp = g_fopen(mimeinfo->data.filename, "rb");
+	if (mimeinfo->type == MIMETYPE_MULTIPART || mimeinfo->type == MIMETYPE_MESSAGE)
+		return TRUE;
+
+	infp = procmime_fopen(mimeinfo->data.filename, "rb");
 	if (!infp) {
 		perror("fopen");
 		return FALSE;
@@ -322,19 +362,19 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 	outfp = get_tmpfile_in_dir(get_mime_tmp_dir(), &tmpfilename);
 	if (!outfp) {
 		perror("tmpfile");
-		fclose(infp);
+		procmime_fclose(infp);
 		return FALSE;
 	}
 	tmp_file = TRUE;
 	readend = mimeinfo->offset + mimeinfo->length;
 
 	if (encoding == ENC_QUOTED_PRINTABLE) {
-		while ((ftell(infp) < readend) && (fgets(buf, sizeof(buf), infp) != NULL)) {
+		while ((ftell(infp) < readend) && (SC_FGETS(buf, sizeof(buf), infp) != NULL)) {
 			gint len;
 			len = qp_decode_line(buf);
 			buf[len]='\0';
 			if (!flowed) {
-				if (fwrite(buf, 1, len, outfp) < len)
+				if (SC_FWRITE(buf, 1, len, outfp) < len)
 					err = TRUE;
 			} else {
 				FLUSH_LASTLINE();
@@ -358,15 +398,19 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 			tmpfp = my_tmpfile();
 			if (!tmpfp) {
 				perror("tmpfile");
-				if (tmp_file) fclose(outfp);
-				fclose(infp);
+				if (tmp_file) 
+					procmime_fclose(outfp);
+				procmime_fclose(infp);
 				return FALSE;
 			}
+#ifdef HAVE_FGETS_UNLOCKED
+			flockfile(tmpfp);
+#endif
 		}
 
 		decoder = base64_decoder_new();
 		while ((inlen = MIN(readend - ftell(infp), sizeof(buf))) > 0 && !err) {
-			inread = fread(buf, 1, inlen, infp);
+			inread = SC_FREAD(buf, 1, inlen, infp);
 			len = base64_decoder_decode(decoder, buf, outbuf, inread);
 			if (uncanonicalize == TRUE && strlen(outbuf) < len && starting) {
 				uncanonicalize = FALSE;
@@ -375,7 +419,7 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 			starting = FALSE;
 			if (((inread != inlen) || len < 0) && !got_error) {
 				g_warning("Bad BASE64 content.\n");
-				if (fwrite(_("[Error decoding BASE64]\n"),
+				if (SC_FWRITE(_("[Error decoding BASE64]\n"),
 					sizeof(gchar),
 					strlen(_("[Error decoding BASE64]\n")),
 					tmpfp) < strlen(_("[Error decoding BASE64]\n")))
@@ -387,10 +431,10 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 				 * per block */
 				if (null_bytes) {
 					/* we won't uncanonicalize, output to outfp directly */
-					if (fwrite(outbuf, sizeof(gchar), len, outfp) < len)
+					if (SC_FWRITE(outbuf, sizeof(gchar), len, outfp) < len)
 						err = TRUE;
 				} else {
-					if (fwrite(outbuf, sizeof(gchar), len, tmpfp) < len)
+					if (SC_FWRITE(outbuf, sizeof(gchar), len, tmpfp) < len)
 						err = TRUE;
 				}
 				got_error = FALSE;
@@ -400,19 +444,19 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 
 		if (uncanonicalize) {
 			rewind(tmpfp);
-			while (fgets(buf, sizeof(buf), tmpfp) != NULL) {
+			while (SC_FGETS(buf, sizeof(buf), tmpfp) != NULL) {
 				strcrchomp(buf);
-				if (fputs(buf, outfp) == EOF)
+				if (SC_FPUTS(buf, outfp) == EOF)
 					err = TRUE;
 			}
-			fclose(tmpfp);
+			procmime_fclose(tmpfp);
 		}
 	} else if (encoding == ENC_X_UUENCODE) {
 		gchar outbuf[BUFFSIZE];
 		gint len;
 		gboolean flag = FALSE;
 
-		while ((ftell(infp) < readend) && (fgets(buf, sizeof(buf), infp) != NULL)) {
+		while ((ftell(infp) < readend) && (SC_FGETS(buf, sizeof(buf), infp) != NULL)) {
 			if (!flag && strncmp(buf,"begin ", 6)) continue;
 
 			if (flag) {
@@ -422,15 +466,15 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 						g_warning("Bad UUENCODE content(%d)\n", len);
 					break;
 				}
-				if (fwrite(outbuf, sizeof(gchar), len, outfp) < len)
+				if (SC_FWRITE(outbuf, sizeof(gchar), len, outfp) < len)
 					err = TRUE;
 			} else
 				flag = TRUE;
 		}
 	} else {
-		while ((ftell(infp) < readend) && (fgets(buf, sizeof(buf), infp) != NULL)) {
+		while ((ftell(infp) < readend) && (SC_FGETS(buf, sizeof(buf), infp) != NULL)) {
 			if (!flowed) {
-				if (fputs(buf, outfp) == EOF)
+				if (SC_FPUTS(buf, outfp) == EOF)
 					err = TRUE;
 			} else {
 				FLUSH_LASTLINE();
@@ -442,8 +486,8 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 			g_warning("write error");
 	}
 
-	fclose(outfp);
-	fclose(infp);
+	procmime_fclose(outfp);
+	procmime_fclose(infp);
 
 	if (err == TRUE) {
 		return FALSE;
@@ -488,19 +532,26 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 		perror("tmpfile");
 		return FALSE;
 	}
+#ifdef HAVE_FGETS_UNLOCKED
+	flockfile(outfp);
+#endif
 
 	if (mimeinfo->content == MIMECONTENT_FILE && mimeinfo->data.filename) {
-		if ((infp = g_fopen(mimeinfo->data.filename, "rb")) == NULL) {
+		if ((infp = procmime_fopen(mimeinfo->data.filename, "rb")) == NULL) {
 			g_warning("Can't open file %s\n", mimeinfo->data.filename);
-			fclose(outfp);
+			procmime_fclose(outfp);
 			return FALSE;
 		}
 	} else if (mimeinfo->content == MIMECONTENT_MEM) {
 		infp = str_open_as_stream(mimeinfo->data.mem);
 		if (infp == NULL) {
-			fclose(outfp);
+			procmime_fclose(outfp);
 			return FALSE;
 		}
+#ifdef HAVE_FGETS_UNLOCKED
+		flockfile(infp);
+#endif
+
 	}
 
 	if (encoding == ENC_BASE64) {
@@ -514,57 +565,60 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 				tmp_file = get_tmp_file();
 				if (canonicalize_file(mimeinfo->data.filename, tmp_file) < 0) {
 					g_free(tmp_file);
-					fclose(infp);
-					fclose(outfp);
+					procmime_fclose(infp);
+					procmime_fclose(outfp);
 					return FALSE;
 				}
-				if ((tmp_fp = g_fopen(tmp_file, "rb")) == NULL) {
+				if ((tmp_fp = procmime_fopen(tmp_file, "rb")) == NULL) {
 					FILE_OP_ERROR(tmp_file, "fopen");
 					claws_unlink(tmp_file);
 					g_free(tmp_file);
-					fclose(infp);
-					fclose(outfp);
+					procmime_fclose(infp);
+					procmime_fclose(outfp);
 					return FALSE;
 				}
 			} else {
 				gchar *out = canonicalize_str(mimeinfo->data.mem);
-				fclose(infp);
+				procmime_fclose(infp);
 				infp = str_open_as_stream(out);
 				tmp_fp = infp;
 				g_free(out);
 				if (infp == NULL) {
-					fclose(outfp);
+					procmime_fclose(outfp);
 					return FALSE;
 				}
+#ifdef HAVE_FGETS_UNLOCKED
+				flockfile(infp);
+#endif
 			}
 		}
 
-		while ((len = fread(inbuf, sizeof(gchar),
+		while ((len = SC_FREAD(inbuf, sizeof(gchar),
 				    B64_LINE_SIZE, tmp_fp))
 		       == B64_LINE_SIZE) {
 			base64_encode(outbuf, inbuf, B64_LINE_SIZE);
-			if (fputs(outbuf, outfp) == EOF)
+			if (SC_FPUTS(outbuf, outfp) == EOF)
 				err = TRUE;
-			if (fputc('\n', outfp) == EOF)
+			if (SC_FPUTC('\n', outfp) == EOF)
 				err = TRUE;
 		}
-		if (len > 0 && feof(tmp_fp)) {
+		if (len > 0 && SC_FEOF(tmp_fp)) {
 			base64_encode(outbuf, inbuf, len);
-			if (fputs(outbuf, outfp) == EOF)
+			if (SC_FPUTS(outbuf, outfp) == EOF)
 				err = TRUE;
-			if (fputc('\n', outfp) == EOF)
+			if (SC_FPUTC('\n', outfp) == EOF)
 				err = TRUE;
 		}
 
 		if (tmp_file) {
-			fclose(tmp_fp);
+			procmime_fclose(tmp_fp);
 			claws_unlink(tmp_file);
 			g_free(tmp_file);
 		}
 	} else if (encoding == ENC_QUOTED_PRINTABLE) {
 		gchar inbuf[BUFFSIZE], outbuf[BUFFSIZE * 4];
 
-		while (fgets(inbuf, sizeof(inbuf), infp) != NULL) {
+		while (SC_FGETS(inbuf, sizeof(inbuf), infp) != NULL) {
 			qp_encode_line(outbuf, inbuf);
 
 			if (!strncmp("From ", outbuf, sizeof("From ")-1)) {
@@ -572,27 +626,27 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 				
 				tmpbuf += sizeof("From ")-1;
 				
-				if (fputs("=46rom ", outfp) == EOF)
+				if (SC_FPUTS("=46rom ", outfp) == EOF)
 					err = TRUE;
-				if (fputs(tmpbuf, outfp) == EOF)
+				if (SC_FPUTS(tmpbuf, outfp) == EOF)
 					err = TRUE;
 			} else {
-				if (fputs(outbuf, outfp) == EOF)
+				if (SC_FPUTS(outbuf, outfp) == EOF)
 					err = TRUE;
 			}
 		}
 	} else {
 		gchar buf[BUFFSIZE];
 
-		while (fgets(buf, sizeof(buf), infp) != NULL) {
+		while (SC_FGETS(buf, sizeof(buf), infp) != NULL) {
 			strcrchomp(buf);
-			if (fputs(buf, outfp) == EOF)
+			if (SC_FPUTS(buf, outfp) == EOF)
 				err = TRUE;
 		}
 	}
 
-	fclose(outfp);
-	fclose(infp);
+	procmime_fclose(outfp);
+	procmime_fclose(infp);
 
 	if (err == TRUE)
 		return FALSE;
@@ -630,7 +684,7 @@ gint procmime_get_part(const gchar *outfile, MimeInfo *mimeinfo)
 	if (mimeinfo->encoding_type != ENC_BINARY && !procmime_decode_content(mimeinfo))
 		return -EINVAL;
 
-	if ((infp = g_fopen(mimeinfo->data.filename, "rb")) == NULL) {
+	if ((infp = procmime_fopen(mimeinfo->data.filename, "rb")) == NULL) {
 		saved_errno = errno;
 		FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 		return -(saved_errno);
@@ -638,30 +692,30 @@ gint procmime_get_part(const gchar *outfile, MimeInfo *mimeinfo)
 	if (fseek(infp, mimeinfo->offset, SEEK_SET) < 0) {
 		saved_errno = errno;
 		FILE_OP_ERROR(mimeinfo->data.filename, "fseek");
-		fclose(infp);
+		procmime_fclose(infp);
 		return -(saved_errno);
 	}
-	if ((outfp = g_fopen(outfile, "wb")) == NULL) {
+	if ((outfp = procmime_fopen(outfile, "wb")) == NULL) {
 		saved_errno = errno;
 		FILE_OP_ERROR(outfile, "fopen");
-		fclose(infp);
+		procmime_fclose(infp);
 		return -(saved_errno);
 	}
 
 	restlength = mimeinfo->length;
 
-	while ((restlength > 0) && ((readlength = fread(buf, 1, restlength > BUFFSIZE ? BUFFSIZE : restlength, infp)) > 0)) {
-		if (fwrite(buf, 1, readlength, outfp) != readlength) {
+	while ((restlength > 0) && ((readlength = SC_FREAD(buf, 1, restlength > BUFFSIZE ? BUFFSIZE : restlength, infp)) > 0)) {
+		if (SC_FWRITE(buf, 1, readlength, outfp) != readlength) {
 			saved_errno = errno;
-			fclose(infp);
-			fclose(outfp);
+			procmime_fclose(infp);
+			procmime_fclose(outfp);
 			return -(saved_errno);
 		}
 		restlength -= readlength;
 	}
 
-	fclose(infp);
-	if (fclose(outfp) == EOF) {
+	procmime_fclose(infp);
+	if (procmime_fclose(outfp) == EOF) {
 		saved_errno = errno;
 		FILE_OP_ERROR(outfile, "fclose");
 		claws_unlink(outfile);
@@ -671,41 +725,37 @@ gint procmime_get_part(const gchar *outfile, MimeInfo *mimeinfo)
 	return 0;
 }
 
-FILE *procmime_get_text_content(MimeInfo *mimeinfo)
+gboolean procmime_scan_text_content(MimeInfo *mimeinfo,
+		gboolean (*scan_callback)(const gchar *str, gpointer cb_data),
+		gpointer cb_data) 
 {
-	FILE *tmpfp, *outfp;
+	FILE *tmpfp;
 	const gchar *src_codeset;
 	gboolean conv_fail = FALSE;
 	gchar buf[BUFFSIZE];
 	gchar *str;
 	gchar *tmpfile;
-	gboolean err = FALSE;
+	gboolean scan_ret = FALSE;
 
-	cm_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, TRUE);
+	cm_return_val_if_fail(scan_callback != NULL, TRUE);
 
 	if (!procmime_decode_content(mimeinfo))
-		return NULL;
+		return TRUE;
 
 	tmpfile = procmime_get_tmp_file_name(mimeinfo);
 	if (tmpfile == NULL)
-		return NULL;
+		return TRUE;
 
 	if (procmime_get_part(tmpfile, mimeinfo) < 0) {
 		g_free(tmpfile);
-		return NULL;
+		return TRUE;
 	}
 
-	tmpfp = g_fopen(tmpfile, "rb");
+	tmpfp = procmime_fopen(tmpfile, "rb");
 	if (tmpfp == NULL) {
 		g_free(tmpfile);
-		return NULL;
-	}
-
-	if ((outfp = my_tmpfile()) == NULL) {
-		perror("tmpfile");
-		fclose(tmpfp);
-		g_free(tmpfile);
-		return NULL;
+		return TRUE;
 	}
 
 	src_codeset = forced_charset
@@ -721,6 +771,8 @@ FILE *procmime_get_text_content(MimeInfo *mimeinfo)
 		src_codeset = CS_GB18030;
 	else if (!forced_charset && src_codeset && !strcasecmp(src_codeset, CS_GB2312))
 		src_codeset = CS_GB18030;
+	else if (!forced_charset && src_codeset && !strcasecmp(src_codeset, CS_X_VIET_VPS))
+		src_codeset = CS_WINDOWS_874;
 
 	if (mimeinfo->type == MIMETYPE_TEXT && !g_ascii_strcasecmp(mimeinfo->subtype, "html")) {
 		SC_HTMLParser *parser;
@@ -729,8 +781,8 @@ FILE *procmime_get_text_content(MimeInfo *mimeinfo)
 		conv = conv_code_converter_new(src_codeset);
 		parser = sc_html_parser_new(tmpfp, conv);
 		while ((str = sc_html_parse(parser)) != NULL) {
-			if (fputs(str, outfp) == EOF)
-				err = TRUE;
+			if ((scan_ret = scan_callback(str, cb_data)) == TRUE)
+				break;
 		}
 		sc_html_parser_destroy(parser);
 		conv_code_converter_destroy(conv);
@@ -741,22 +793,24 @@ FILE *procmime_get_text_content(MimeInfo *mimeinfo)
 		conv = conv_code_converter_new(src_codeset);
 		parser = ertf_parser_new(tmpfp, conv);
 		while ((str = ertf_parse(parser)) != NULL) {
-			if (fputs(str, outfp) == EOF)
-				err = TRUE;
+			if ((scan_ret = scan_callback(str, cb_data)) == TRUE)
+				break;
 		}
 		ertf_parser_destroy(parser);
 		conv_code_converter_destroy(conv);
 	} else if (mimeinfo->type == MIMETYPE_TEXT) {
-		while (fgets(buf, sizeof(buf), tmpfp) != NULL) {
+		while (SC_FGETS(buf, sizeof(buf), tmpfp) != NULL) {
 			str = conv_codeset_strdup(buf, src_codeset, CS_UTF_8);
 			if (str) {
-				if (fputs(str, outfp) == EOF)
-					err = TRUE;
+				if ((scan_ret = scan_callback(str, cb_data)) == TRUE) {
+					g_free(str);
+					break;
+				}
 				g_free(str);
 			} else {
 				conv_fail = TRUE;
-				if (fputs(buf, outfp) == EOF)
-					err = TRUE;
+				if ((scan_ret = scan_callback(buf, cb_data)) == TRUE)
+					break;
 			}
 		}
 	}
@@ -764,17 +818,46 @@ FILE *procmime_get_text_content(MimeInfo *mimeinfo)
 	if (conv_fail)
 		g_warning("procmime_get_text_content(): Code conversion failed.\n");
 
-	fclose(tmpfp);
-	rewind(outfp);
+	procmime_fclose(tmpfp);
 	claws_unlink(tmpfile);
 	g_free(tmpfile);
 
-	if (err == TRUE) {
-		fclose(outfp);
+	return scan_ret;
+}
+
+static gboolean scan_fputs_cb(const gchar *str, gpointer fp)
+{
+	if (SC_FPUTS(str, (FILE *)fp) == EOF)
+		return TRUE;
+	
+	return FALSE;
+}
+
+FILE *procmime_get_text_content(MimeInfo *mimeinfo)
+{
+	FILE *outfp;
+	gboolean err;
+
+	if ((outfp = my_tmpfile()) == NULL) {
+		perror("tmpfile");
 		return NULL;
 	}
+#ifdef HAVE_FGETS_UNLOCKED
+	flockfile(outfp);
+#endif
 
+	err = procmime_scan_text_content(mimeinfo, scan_fputs_cb, outfp);
+
+	rewind(outfp);
+	if (err == TRUE) {
+		procmime_fclose(outfp);
+		return NULL;
+	}
+#ifdef HAVE_FGETS_UNLOCKED
+	funlockfile(outfp);
+#endif
 	return outfp;
+
 }
 
 FILE *procmime_get_binary_content(MimeInfo *mimeinfo)
@@ -796,7 +879,7 @@ FILE *procmime_get_binary_content(MimeInfo *mimeinfo)
 		return NULL;
 	}
 
-	outfp = g_fopen(tmpfile, "rb");
+	outfp = procmime_fopen(tmpfile, "rb");
 	if (outfp == NULL) {
 		g_unlink(tmpfile);
 		g_free(tmpfile);
@@ -806,6 +889,9 @@ FILE *procmime_get_binary_content(MimeInfo *mimeinfo)
 	g_unlink(tmpfile);
 	g_free(tmpfile);
 
+#ifdef HAVE_FGETS_UNLOCKED
+	funlockfile(outfp);
+#endif
 	return outfp;
 }
 
@@ -850,6 +936,8 @@ scan_again:
 		goto scan_again;
 	}
 	procmime_mimeinfo_free_all(mimeinfo);
+
+	/* outfp already unlocked at this time */
 	return outfp;
 }
 
@@ -912,6 +1000,7 @@ FILE *procmime_get_first_encrypted_text_content(MsgInfo *msginfo)
 
 	procmime_mimeinfo_free_all(mimeinfo);
 
+	/* outfp already unlocked at this time */
 	return outfp;
 }
 
@@ -1061,12 +1150,11 @@ static GHashTable *procmime_get_mime_type_table(void)
 
 		exts = g_strsplit(mime_type->extension, " ", 16);
 		for (i = 0; exts[i] != NULL; i++) {
-			/* use previously dup'd key on overwriting */
-			if (g_hash_table_lookup(table, exts[i]))
-				key = exts[i];
-			else
+			/* Don't overwrite previously inserted extension */
+			if (!g_hash_table_lookup(table, exts[i])) {
 				key = g_strdup(exts[i]);
-			g_hash_table_insert(table, key, mime_type);
+				g_hash_table_insert(table, key, mime_type);
+			}
 		}
 		g_strfreev(exts);
 	}
@@ -1088,14 +1176,14 @@ GList *procmime_get_mime_type_list(void)
 		return mime_type_list;
 	
 #if defined(__NetBSD__) || defined(__OpenBSD__) || defined(__FreeBSD__)
-	if ((fp = g_fopen(DATAROOTDIR "/mime/globs", "rb")) == NULL) 
+	if ((fp = procmime_fopen(DATAROOTDIR "/mime/globs", "rb")) == NULL) 
 #else
-	if ((fp = g_fopen("/usr/share/mime/globs", "rb")) == NULL) 
+	if ((fp = procmime_fopen("/usr/share/mime/globs", "rb")) == NULL) 
 #endif
 	{
 		fp_is_glob_file = FALSE;
-		if ((fp = g_fopen("/etc/mime.types", "rb")) == NULL) {
-			if ((fp = g_fopen(SYSCONFDIR "/mime.types", "rb")) 
+		if ((fp = procmime_fopen("/etc/mime.types", "rb")) == NULL) {
+			if ((fp = procmime_fopen(SYSCONFDIR "/mime.types", "rb")) 
 				== NULL) {
 				FILE_OP_ERROR(SYSCONFDIR "/mime.types", 
 					"fopen");
@@ -1104,7 +1192,7 @@ GList *procmime_get_mime_type_list(void)
 		}
 	}
 
-	while (fgets(buf, sizeof(buf), fp) != NULL) {
+	while (SC_FGETS(buf, sizeof(buf), fp) != NULL) {
 		p = strchr(buf, '#');
 		if (p) *p = '\0';
 		g_strstrip(buf);
@@ -1143,7 +1231,7 @@ GList *procmime_get_mime_type_list(void)
 		list = g_list_append(list, mime_type);
 	}
 
-	fclose(fp);
+	procmime_fclose(fp);
 
 	if (!list)
 		g_warning("Can't read mime.types\n");
@@ -1180,12 +1268,12 @@ EncodingType procmime_get_encoding_for_text_file(const gchar *file, gboolean *ha
 	gfloat octet_percentage;
 	gboolean force_b64 = FALSE;
 
-	if ((fp = g_fopen(file, "rb")) == NULL) {
+	if ((fp = procmime_fopen(file, "rb")) == NULL) {
 		FILE_OP_ERROR(file, "fopen");
 		return ENC_UNKNOWN;
 	}
 
-	while ((len = fread(buf, sizeof(guchar), sizeof(buf), fp)) > 0) {
+	while ((len = SC_FREAD(buf, sizeof(guchar), sizeof(buf), fp)) > 0) {
 		guchar *p;
 		gint i;
 
@@ -1200,7 +1288,7 @@ EncodingType procmime_get_encoding_for_text_file(const gchar *file, gboolean *ha
 		total_len += len;
 	}
 
-	fclose(fp);
+	procmime_fclose(fp);
 	
 	if (total_len > 0)
 		octet_percentage = (gfloat)octet_chars / (gfloat)total_len;
@@ -1346,7 +1434,7 @@ static void procmime_parse_message_rfc822(MimeInfo *mimeinfo, gboolean short_sca
 
 	procmime_decode_content(mimeinfo);
 
-	fp = g_fopen(mimeinfo->data.filename, "rb");
+	fp = procmime_fopen(mimeinfo->data.filename, "rb");
 	if (fp == NULL) {
 		FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 		return;
@@ -1385,7 +1473,7 @@ static void procmime_parse_message_rfc822(MimeInfo *mimeinfo, gboolean short_sca
         }
   
 	content_start = ftell(fp);
-	fclose(fp);
+	procmime_fclose(fp);
 	
 	len = mimeinfo->length - (content_start - mimeinfo->offset);
 	if (len < 0)
@@ -1419,7 +1507,7 @@ static void procmime_parse_disposition_notification(MimeInfo *mimeinfo,
 	procmime_decode_content(mimeinfo);
 
 	debug_print("parse disposition notification\n");
-	fp = g_fopen(mimeinfo->data.filename, "rb");
+	fp = procmime_fopen(mimeinfo->data.filename, "rb");
 	if (fp == NULL) {
 		FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 		return;
@@ -1433,7 +1521,7 @@ static void procmime_parse_disposition_notification(MimeInfo *mimeinfo,
 		procheader_get_header_fields(fp, hentry);
 	}
     
-        fclose(fp);
+        procmime_fclose(fp);
 
     	if (!hentry[0].body || !hentry[1].body) {
 		debug_print("MsgId %s, Disp %s\n",
@@ -1534,7 +1622,6 @@ static void procmime_parse_multipart(MimeInfo *mimeinfo, gboolean short_scan)
 	gchar buf[BUFFSIZE];
 	FILE *fp;
 	int result = 0;
-	gboolean done = FALSE;
 	gboolean start_found = FALSE;
 	gboolean end_found = FALSE;
 
@@ -1545,14 +1632,14 @@ static void procmime_parse_multipart(MimeInfo *mimeinfo, gboolean short_scan)
 
 	procmime_decode_content(mimeinfo);
 
-	fp = g_fopen(mimeinfo->data.filename, "rb");
+	fp = procmime_fopen(mimeinfo->data.filename, "rb");
 	if (fp == NULL) {
 		FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 		return;
 	}
 
 	fseek(fp, mimeinfo->offset, SEEK_SET);
-	while ((p = fgets(buf, sizeof(buf), fp)) != NULL && result == 0) {
+	while ((p = SC_FGETS(buf, sizeof(buf), fp)) != NULL && result == 0) {
 		if (ftell(fp) - 1 > (mimeinfo->offset + mimeinfo->length))
 			break;
 
@@ -1570,10 +1657,9 @@ static void procmime_parse_multipart(MimeInfo *mimeinfo, gboolean short_scan)
 							hentry[6].body, hentry[7].body,
 							mimeinfo->data.filename, lastoffset,
 							len, short_scan);
-				if (result == 1 && short_scan) {
-					done = TRUE;
+				if (result == 1 && short_scan)
 					break;
-				}
+				
 			} 
 			
 			if (buf[2 + boundary_len]     == '-' &&
@@ -1609,7 +1695,7 @@ static void procmime_parse_multipart(MimeInfo *mimeinfo, gboolean short_scan)
 		g_free(hentry[i].body);
 		hentry[i].body = NULL;
 	}
-	fclose(fp);
+	procmime_fclose(fp);
 }
 
 static void parse_parameters(const gchar *parameters, GHashTable *table)
@@ -1701,15 +1787,15 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 			tmp[0] = '\0';
 
 			if ((tmp[1] == '0') && (tmp[2] == '\0') && 
-			    (g_slist_find_custom(concatlist, down_attr, g_strcmp0) == NULL))
+			    (g_slist_find_custom(concatlist, down_attr, (GCompareFunc)g_strcmp0) == NULL))
 				concatlist = g_slist_prepend(concatlist, g_strdup(tmpattr));
 
-			if (convert && (g_slist_find_custom(convlist, down_attr, g_strcmp0) == NULL))
+			if (convert && (g_slist_find_custom(convlist, tmpattr, (GCompareFunc)g_strcmp0) == NULL))
 				convlist = g_slist_prepend(convlist, g_strdup(tmpattr));
 
 			g_free(tmpattr);
 		} else if (convert) {
-			if (g_slist_find_custom(convlist, down_attr, g_strcmp0) == NULL)
+			if (g_slist_find_custom(convlist, down_attr, (GCompareFunc)g_strcmp0) == NULL)
 				convlist = g_slist_prepend(convlist, g_strdup(down_attr));
 		}
 
@@ -1740,8 +1826,7 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 		g_hash_table_insert(table, g_strdup(attribute), g_strdup(value->str));
 		g_string_free(value, TRUE);
 	}
-	slist_free_strings(concatlist);
-	g_slist_free(concatlist);
+	slist_free_strings_full(concatlist);
 
 	for (cur = convlist; cur != NULL; cur = g_slist_next(cur)) {
 		gchar *attribute, *key, *value;
@@ -1753,6 +1838,8 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 			continue;
 
 		charset = value;
+		if (charset == NULL)
+			continue;
 		lang = strchr(charset, '\'');
 		if (lang == NULL)
 			continue;
@@ -1772,8 +1859,7 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 
 		g_hash_table_insert(table, g_strdup(attribute), newvalue);
 	}
-	slist_free_strings(convlist);
-	g_slist_free(convlist);
+	slist_free_strings_full(convlist);
 
 	g_free(params);
 }	
@@ -1929,6 +2015,7 @@ static int procmime_parse_mimepart(MimeInfo *parent,
 	mimeinfo->length = length;
 
 	if (content_type != NULL) {
+		g_strchomp(content_type);
 		procmime_parse_content_type(content_type, mimeinfo);
 	} else {
 		mimeinfo->type = MIMETYPE_TEXT;
@@ -1943,6 +2030,7 @@ static int procmime_parse_mimepart(MimeInfo *parent,
 	}
 
 	if (content_encoding != NULL) {
+ 		g_strchomp(content_encoding);
 		procmime_parse_content_encoding(content_encoding, mimeinfo);
 	} else {
 		mimeinfo->encoding_type = ENC_UNKNOWN;
@@ -1963,9 +2051,10 @@ static int procmime_parse_mimepart(MimeInfo *parent,
 	else
 		mimeinfo->location = NULL;
 
-	if (content_disposition != NULL) 
+	if (content_disposition != NULL) {
+ 		g_strchomp(content_disposition);
 		procmime_parse_content_disposition(content_disposition, mimeinfo);
-	else
+	} else
 		mimeinfo->disposition = DISPOSITIONTYPE_UNKNOWN;
 
 	/* Call parser for mime type */
@@ -2093,10 +2182,10 @@ static MimeInfo *procmime_scan_queue_file_full(const gchar *filename, gboolean s
 	cm_return_val_if_fail(filename != NULL, NULL);
 
 	/* Open file */
-	if ((fp = g_fopen(filename, "rb")) == NULL)
+	if ((fp = procmime_fopen(filename, "rb")) == NULL)
 		return NULL;
 	/* Skip queue header */
-	while (fgets(buf, sizeof(buf), fp) != NULL) {
+	while (SC_FGETS(buf, sizeof(buf), fp) != NULL) {
 		/* new way */
 		if ((!strncmp(buf, "X-Claws-End-Special-Headers: 1",
 			strlen("X-Claws-End-Special-Headers:"))) ||
@@ -2115,7 +2204,7 @@ static MimeInfo *procmime_scan_queue_file_full(const gchar *filename, gboolean s
 		}
 	}
 	offset = ftell(fp);
-	fclose(fp);
+	procmime_fclose(fp);
 
 	mimeinfo = procmime_scan_file_with_offset(filename, offset, short_scan);
 
@@ -2366,18 +2455,18 @@ static gint procmime_write_message_rfc822(MimeInfo *mimeinfo, FILE *fp)
 	/* write header */
 	switch (mimeinfo->content) {
 	case MIMECONTENT_FILE:
-		if ((infp = g_fopen(mimeinfo->data.filename, "rb")) == NULL) {
+		if ((infp = procmime_fopen(mimeinfo->data.filename, "rb")) == NULL) {
 			FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 			return -1;
 		}
 		fseek(infp, mimeinfo->offset, SEEK_SET);
-		while (fgets(buf, sizeof(buf), infp) == buf) {
+		while (SC_FGETS(buf, sizeof(buf), infp) == buf) {
 			strcrchomp(buf);
 			if (buf[0] == '\n' && buf[1] == '\0')
 				break;
 			if (skip && (buf[0] == ' ' || buf[0] == '\t'))
 				continue;
-			if (g_ascii_strncasecmp(buf, "Mime-Version:", 13) == 0 ||
+			if (g_ascii_strncasecmp(buf, "MIME-Version:", 13) == 0 ||
 			    g_ascii_strncasecmp(buf, "Content-Type:", 13) == 0 ||
 			    g_ascii_strncasecmp(buf, "Content-Transfer-Encoding:", 26) == 0 ||
 			    g_ascii_strncasecmp(buf, "Content-Description:", 20) == 0 ||
@@ -2388,19 +2477,19 @@ static gint procmime_write_message_rfc822(MimeInfo *mimeinfo, FILE *fp)
 				continue;
 			}
 			len = strlen(buf);
-			if (fwrite(buf, sizeof(gchar), len, fp) < len) {
+			if (SC_FWRITE(buf, sizeof(gchar), len, fp) < len) {
 				g_warning("failed to dump %zd bytes from file", len);
-				fclose(infp);
+				procmime_fclose(infp);
 				return -1;
 			}
 			skip = FALSE;
 		}
-		fclose(infp);
+		procmime_fclose(infp);
 		break;
 
 	case MIMECONTENT_MEM:
 		len = strlen(mimeinfo->data.mem);
-		if (fwrite(mimeinfo->data.mem, sizeof(gchar), len, fp) < len) {
+		if (SC_FWRITE(mimeinfo->data.mem, sizeof(gchar), len, fp) < len) {
 			g_warning("failed to dump %zd bytes from mem", len);
 			return -1;
 		}
@@ -2415,7 +2504,7 @@ static gint procmime_write_message_rfc822(MimeInfo *mimeinfo, FILE *fp)
 		return -1;
 
 	child = (MimeInfo *) childnode->data;
-	if (fprintf(fp, "Mime-Version: 1.0\n") < 0) {
+	if (fprintf(fp, "MIME-Version: 1.0\n") < 0) {
 		g_warning("failed to write mime version");
 		return -1;
 	}
@@ -2439,22 +2528,22 @@ static gint procmime_write_multipart(MimeInfo *mimeinfo, FILE *fp)
 
 	switch (mimeinfo->content) {
 	case MIMECONTENT_FILE:
-		if ((infp = g_fopen(mimeinfo->data.filename, "rb")) == NULL) {
+		if ((infp = procmime_fopen(mimeinfo->data.filename, "rb")) == NULL) {
 			FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 			return -1;
 		}
 		fseek(infp, mimeinfo->offset, SEEK_SET);
-		while (fgets(buf, sizeof(buf), infp) == buf) {
+		while (SC_FGETS(buf, sizeof(buf), infp) == buf) {
 			if (IS_BOUNDARY(buf, boundary, strlen(boundary)))
 				break;
 			len = strlen(buf);
-			if (fwrite(buf, sizeof(gchar), len, fp) < len) {
+			if (SC_FWRITE(buf, sizeof(gchar), len, fp) < len) {
 				g_warning("failed to write %zd", len);
-				fclose(infp);
+				procmime_fclose(infp);
 				return -1;
 			}
 		}
-		fclose(infp);
+		procmime_fclose(infp);
 		break;
 
 	case MIMECONTENT_MEM:
@@ -2463,7 +2552,7 @@ static gint procmime_write_multipart(MimeInfo *mimeinfo, FILE *fp)
 		    (*(str2 - 1) == '-') && (*(str2 - 2) == '-'))
 			*(str2 - 2) = '\0';
 		len = strlen(str);
-		if (fwrite(str, sizeof(gchar), len, fp) < len) {
+		if (SC_FWRITE(str, sizeof(gchar), len, fp) < len) {
 			g_warning("failed to write %zd from mem", len);
 			g_free(str);
 			return -1;
@@ -2508,17 +2597,17 @@ gint procmime_write_mimeinfo(MimeInfo *mimeinfo, FILE *fp)
 	if (G_NODE_IS_LEAF(mimeinfo->node)) {
 		switch (mimeinfo->content) {
 		case MIMECONTENT_FILE:
-			if ((infp = g_fopen(mimeinfo->data.filename, "rb")) == NULL) {
+			if ((infp = procmime_fopen(mimeinfo->data.filename, "rb")) == NULL) {
 				FILE_OP_ERROR(mimeinfo->data.filename, "fopen");
 				return -1;
 			}
 			copy_file_part_to_fp(infp, mimeinfo->offset, mimeinfo->length, fp);
-			fclose(infp);
+			procmime_fclose(infp);
 			return 0;
 
 		case MIMECONTENT_MEM:
 			len = strlen(mimeinfo->data.mem);
-			if (fwrite(mimeinfo->data.mem, sizeof(gchar), len, fp) < len)
+			if (SC_FWRITE(mimeinfo->data.mem, sizeof(gchar), len, fp) < len)
 				return -1;
 			return 0;
 
