@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5"
+#define YYBISON_VERSION "2.7.12-4996"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,14 +58,11 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 0
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 20 "quote_fmt_parse.y"
 
 
@@ -617,14 +614,16 @@ static gchar *quote_fmt_complete_address(const gchar *addr)
 }
 
 
+/* Line 371 of yacc.c  */
+#line 619 "quote_fmt_parse.c"
 
-/* Line 268 of yacc.c  */
-#line 623 "quote_fmt_parse.c"
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+# ifndef YY_NULL
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULL nullptr
+#  else
+#   define YY_NULL 0
+#  endif
+# endif
 
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
@@ -634,11 +633,17 @@ static gchar *quote_fmt_complete_address(const gchar *addr)
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_QUOTE_FMT_PARSE_H_INCLUDED
+# define YY_YY_QUOTE_FMT_PARSE_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -818,33 +823,46 @@ static gchar *quote_fmt_complete_address(const gchar *addr)
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 293 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 571 "quote_fmt_parse.y"
 
 	char chr;
 	char str[256];
 
 
-
-/* Line 293 of yacc.c  */
-#line 836 "quote_fmt_parse.c"
+/* Line 387 of yacc.c  */
+#line 838 "quote_fmt_parse.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+extern YYSTYPE yylval;
+
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int yyparse (void *YYPARSE_PARAM);
+#else
+int yyparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int yyparse (void);
+#else
+int yyparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_QUOTE_FMT_PARSE_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 343 of yacc.c  */
-#line 848 "quote_fmt_parse.c"
+/* Line 390 of yacc.c  */
+#line 866 "quote_fmt_parse.c"
 
 #ifdef short
 # undef short
@@ -897,24 +915,33 @@ typedef short int yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
+# endif
+#endif
+
+#ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+# if (! defined __GNUC__ || __GNUC__ < 2 \
+      || (__GNUC__ == 2 && __GNUC_MINOR__ < 5))
+#  define __attribute__(Spec) /* empty */
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
+
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -950,6 +977,7 @@ YYID (yyi)
 #    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 #     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
+      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
 #     ifndef EXIT_SUCCESS
 #      define EXIT_SUCCESS 0
 #     endif
@@ -1041,20 +1069,20 @@ union yyalloc
 #endif
 
 #if defined YYCOPY_NEEDED && YYCOPY_NEEDED
-/* Copy COUNT objects from FROM to TO.  The source and destination do
+/* Copy COUNT objects from SRC to DST.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
 #  if defined __GNUC__ && 1 < __GNUC__
-#   define YYCOPY(To, From, Count) \
-      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
+#   define YYCOPY(Dst, Src, Count) \
+      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
 #  else
-#   define YYCOPY(To, From, Count)		\
-      do					\
-	{					\
-	  YYSIZE_T yyi;				\
-	  for (yyi = 0; yyi < (Count); yyi++)	\
-	    (To)[yyi] = (From)[yyi];		\
-	}					\
+#   define YYCOPY(Dst, Src, Count)              \
+      do                                        \
+        {                                       \
+          YYSIZE_T yyi;                         \
+          for (yyi = 0; yyi < (Count); yyi++)   \
+            (Dst)[yyi] = (Src)[yyi];            \
+        }                                       \
       while (YYID (0))
 #  endif
 # endif
@@ -1208,7 +1236,7 @@ static const yytype_uint16 yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -1251,7 +1279,7 @@ static const char *const yytname[] =
   "$@12", "$@13", "$@14", "$@15", "$@16", "$@17", "$@18", "query_not",
   "$@19", "$@20", "$@21", "$@22", "$@23", "$@24", "$@25", "$@26", "$@27",
   "$@28", "$@29", "$@30", "$@31", "$@32", "$@33", "$@34", "$@35", "$@36",
-  "insert", "$@37", "$@38", "$@39", "attach", "$@40", 0
+  "insert", "$@37", "$@38", "$@39", "attach", "$@40", YY_NULL
 };
 #endif
 
@@ -1434,10 +1462,10 @@ static const yytype_uint16 yytable[] =
      257,   259,   260,   261,     0,     0,   134
 };
 
-#define yypact_value_is_default(yystate) \
-  ((yystate) == (-50))
+#define yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-50)))
 
-#define yytable_value_is_error(yytable_value) \
+#define yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const yytype_int16 yycheck[] =
@@ -1530,62 +1558,35 @@ static const yytype_uint8 yystos[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)					\
-do								\
-  if (yychar == YYEMPTY && yylen == 1)				\
-    {								\
-      yychar = (Token);						\
-      yylval = (Value);						\
-      YYPOPSTACK (1);						\
-      goto yybackup;						\
-    }								\
-  else								\
-    {								\
+#define YYBACKUP(Token, Value)                                  \
+do                                                              \
+  if (yychar == YYEMPTY)                                        \
+    {                                                           \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
+      goto yybackup;                                            \
+    }                                                           \
+  else                                                          \
+    {                                                           \
       yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
-#ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (YYID (0))
-#endif
-
-
 /* This macro is provided for backward compatibility. */
-
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX yylex (YYLEX_PARAM)
 #else
@@ -1635,6 +1636,8 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
     YYSTYPE const * const yyvaluep;
 #endif
 {
+  FILE *yyo = yyoutput;
+  YYUSE (yyo);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -1643,11 +1646,7 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
 # else
   YYUSE (yyoutput);
 # endif
-  switch (yytype)
-    {
-      default:
-	break;
-    }
+  YYUSE (yytype);
 }
 
 
@@ -1886,12 +1885,11 @@ static int
 yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yytype_int16 *yyssp, int yytoken)
 {
-  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytoken]);
+  YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
-  YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
-  const char *yyformat = 0;
+  const char *yyformat = YY_NULL;
   /* Arguments of yyformat. */
   char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
   /* Number of reported tokens (one for the "unexpected", one per
@@ -1951,11 +1949,13 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (0, yytname[yyx]);
-                if (! (yysize <= yysize1
-                       && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                yysize = yysize1;
+                {
+                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
+                  if (! (yysize <= yysize1
+                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  yysize = yysize1;
+                }
               }
         }
     }
@@ -1975,10 +1975,12 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 # undef YYCASE_
     }
 
-  yysize1 = yysize + yystrlen (yyformat);
-  if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  yysize = yysize1;
+  {
+    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
+    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    yysize = yysize1;
+  }
 
   if (*yymsg_alloc < yysize)
     {
@@ -2034,36 +2036,26 @@ yydestruct (yymsg, yytype, yyvaluep)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
 
-  switch (yytype)
-    {
-
-      default:
-	break;
-    }
+  YYUSE (yytype);
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int yychar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE yylval;
+YYSTYPE yylval YY_INITIAL_VALUE(yyval_default);
 
 /* Number of syntax errors so far.  */
 int yynerrs;
@@ -2103,7 +2095,7 @@ yyparse ()
        `yyss': related to states.
        `yyvs': related to semantic values.
 
-       Refer to the stacks thru separate pointers, to allow yyoverflow
+       Refer to the stacks through separate pointers, to allow yyoverflow
        to reallocate them elsewhere.  */
 
     /* The state stack.  */
@@ -2121,7 +2113,7 @@ yyparse ()
   int yyn;
   int yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
+  int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE yyval;
@@ -2139,9 +2131,8 @@ yyparse ()
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
-  yytoken = 0;
-  yyss = yyssa;
-  yyvs = yyvsa;
+  yyssp = yyss = yyssa;
+  yyvsp = yyvs = yyvsa;
   yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -2150,14 +2141,6 @@ yyparse ()
   yyerrstatus = 0;
   yynerrs = 0;
   yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  yyssp = yyss;
-  yyvsp = yyvs;
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -2298,7 +2281,9 @@ yybackup:
   yychar = YYEMPTY;
 
   yystate = yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto yynewstate;
 
@@ -2335,8 +2320,7 @@ yyreduce:
   switch (yyn)
     {
         case 14:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 650 "quote_fmt_parse.y"
     {
 		INSERT_CHARACTER((yyvsp[(1) - (1)].chr));
@@ -2344,8 +2328,7 @@ yyreduce:
     break;
 
   case 16:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 660 "quote_fmt_parse.y"
     {
 		(yyval.str)[0] = (yyvsp[(1) - (1)].chr);
@@ -2354,8 +2337,7 @@ yyreduce:
     break;
 
   case 17:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 665 "quote_fmt_parse.y"
     {
 		size_t len;
@@ -2371,8 +2353,7 @@ yyreduce:
     break;
 
   case 18:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 679 "quote_fmt_parse.y"
     {
 		if (msginfo->newsgroups)
@@ -2381,8 +2362,7 @@ yyreduce:
     break;
 
   case 19:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 684 "quote_fmt_parse.y"
     {
 		quote_fmt_show_date(msginfo, (yyvsp[(3) - (4)].str));
@@ -2390,8 +2370,7 @@ yyreduce:
     break;
 
   case 20:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 688 "quote_fmt_parse.y"
     {
 		if (msginfo->date)
@@ -2400,8 +2379,7 @@ yyreduce:
     break;
 
   case 21:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 693 "quote_fmt_parse.y"
     {
 		if (msginfo->from)
@@ -2410,8 +2388,7 @@ yyreduce:
     break;
 
   case 22:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 698 "quote_fmt_parse.y"
     {
 		if (msginfo->from) {
@@ -2424,8 +2401,7 @@ yyreduce:
     break;
 
   case 23:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 707 "quote_fmt_parse.y"
     {
 		if (msginfo->fromname)
@@ -2434,8 +2410,7 @@ yyreduce:
     break;
 
   case 24:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 712 "quote_fmt_parse.y"
     {
 		quote_fmt_show_first_name(msginfo);
@@ -2443,8 +2418,7 @@ yyreduce:
     break;
 
   case 25:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 716 "quote_fmt_parse.y"
     {
 		quote_fmt_show_last_name(msginfo);
@@ -2452,8 +2426,7 @@ yyreduce:
     break;
 
   case 26:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 720 "quote_fmt_parse.y"
     {
 		quote_fmt_show_sender_initial(msginfo);
@@ -2461,8 +2434,7 @@ yyreduce:
     break;
 
   case 27:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 724 "quote_fmt_parse.y"
     {
 		if (msginfo->subject)
@@ -2471,8 +2443,7 @@ yyreduce:
     break;
 
   case 28:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 729 "quote_fmt_parse.y"
     {
 		if (msginfo->to)
@@ -2481,8 +2452,7 @@ yyreduce:
     break;
 
   case 29:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 734 "quote_fmt_parse.y"
     {
 		if (msginfo->msgid)
@@ -2491,8 +2461,7 @@ yyreduce:
     break;
 
   case 30:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 739 "quote_fmt_parse.y"
     {
 		INSERT("%");
@@ -2500,8 +2469,7 @@ yyreduce:
     break;
 
   case 31:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 743 "quote_fmt_parse.y"
     {
 		if (msginfo->cc)
@@ -2510,8 +2478,7 @@ yyreduce:
     break;
 
   case 32:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 748 "quote_fmt_parse.y"
     {
 		GSList *item;
@@ -2524,8 +2491,7 @@ yyreduce:
     break;
 
   case 33:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 757 "quote_fmt_parse.y"
     {
 		quote_fmt_show_msg(msginfo, body, FALSE, TRUE, quote_str);
@@ -2533,8 +2499,7 @@ yyreduce:
     break;
 
   case 34:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 761 "quote_fmt_parse.y"
     {
 		quote_fmt_show_msg(msginfo, body, TRUE, TRUE, quote_str);
@@ -2542,8 +2507,7 @@ yyreduce:
     break;
 
   case 35:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 765 "quote_fmt_parse.y"
     {
 		quote_fmt_show_msg(msginfo, body, FALSE, FALSE, quote_str);
@@ -2551,8 +2515,7 @@ yyreduce:
     break;
 
   case 36:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 769 "quote_fmt_parse.y"
     {
 		quote_fmt_show_msg(msginfo, body, TRUE, FALSE, quote_str);
@@ -2560,8 +2523,7 @@ yyreduce:
     break;
 
   case 37:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 773 "quote_fmt_parse.y"
     {
 		if (account && account->name)
@@ -2570,8 +2532,7 @@ yyreduce:
     break;
 
   case 38:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 778 "quote_fmt_parse.y"
     {
 		if (account && account->address)
@@ -2580,8 +2541,7 @@ yyreduce:
     break;
 
   case 39:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 783 "quote_fmt_parse.y"
     {
 		if (account && account->account_name)
@@ -2590,8 +2550,7 @@ yyreduce:
     break;
 
   case 40:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 788 "quote_fmt_parse.y"
     {
 		if (account && account->organization)
@@ -2600,8 +2559,7 @@ yyreduce:
     break;
 
   case 41:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 793 "quote_fmt_parse.y"
     {
 		gchar *str = account_get_signature_str(account);
@@ -2611,8 +2569,7 @@ yyreduce:
     break;
 
   case 42:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 799 "quote_fmt_parse.y"
     {
 		if (account && account->sig_path)
@@ -2621,8 +2578,7 @@ yyreduce:
     break;
 
   case 43:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 804 "quote_fmt_parse.y"
     {
 #ifdef USE_ENCHANT
@@ -2636,8 +2592,7 @@ yyreduce:
     break;
 
   case 44:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 814 "quote_fmt_parse.y"
     {
 #ifdef USE_ENCHANT
@@ -2647,8 +2602,7 @@ yyreduce:
     break;
 
   case 45:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 820 "quote_fmt_parse.y"
     {
 		gchar *tags = procmsg_msginfo_get_tags_str(msginfo);
@@ -2660,8 +2614,7 @@ yyreduce:
     break;
 
   case 46:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 828 "quote_fmt_parse.y"
     {
 		INSERT("\\");
@@ -2669,8 +2622,7 @@ yyreduce:
     break;
 
   case 47:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 832 "quote_fmt_parse.y"
     {
 		INSERT("\t");
@@ -2678,8 +2630,7 @@ yyreduce:
     break;
 
   case 48:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 836 "quote_fmt_parse.y"
     {
 		INSERT("\n");
@@ -2687,8 +2638,7 @@ yyreduce:
     break;
 
   case 49:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 840 "quote_fmt_parse.y"
     {
 		INSERT("?");
@@ -2696,8 +2646,7 @@ yyreduce:
     break;
 
   case 50:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 844 "quote_fmt_parse.y"
     {
 		INSERT("!");
@@ -2705,8 +2654,7 @@ yyreduce:
     break;
 
   case 51:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 848 "quote_fmt_parse.y"
     {
 		INSERT("|");
@@ -2714,8 +2662,7 @@ yyreduce:
     break;
 
   case 52:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 852 "quote_fmt_parse.y"
     {
 		INSERT("{");
@@ -2723,8 +2670,7 @@ yyreduce:
     break;
 
   case 53:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 856 "quote_fmt_parse.y"
     {
 		INSERT("}");
@@ -2732,8 +2678,7 @@ yyreduce:
     break;
 
   case 54:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 860 "quote_fmt_parse.y"
     {
 		if (current->buffer)
@@ -2744,8 +2689,7 @@ yyreduce:
     break;
 
   case 55:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 867 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->cc);
@@ -2757,8 +2701,7 @@ yyreduce:
     break;
 
   case 56:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 875 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->from);
@@ -2770,8 +2713,7 @@ yyreduce:
     break;
 
   case 57:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 883 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->to);
@@ -2783,8 +2725,7 @@ yyreduce:
     break;
 
   case 58:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 893 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->date != NULL);
@@ -2792,8 +2733,7 @@ yyreduce:
     break;
 
   case 59:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 897 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2801,8 +2741,7 @@ yyreduce:
     break;
 
   case 60:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 901 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->from != NULL);
@@ -2810,8 +2749,7 @@ yyreduce:
     break;
 
   case 61:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 905 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2819,8 +2757,7 @@ yyreduce:
     break;
 
   case 62:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 909 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->fromname != NULL);
@@ -2828,8 +2765,7 @@ yyreduce:
     break;
 
   case 63:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 913 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2837,8 +2773,7 @@ yyreduce:
     break;
 
   case 64:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 917 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->subject != NULL);
@@ -2846,8 +2781,7 @@ yyreduce:
     break;
 
   case 65:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 921 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2855,8 +2789,7 @@ yyreduce:
     break;
 
   case 66:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 925 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->to != NULL);
@@ -2864,8 +2797,7 @@ yyreduce:
     break;
 
   case 67:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 929 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2873,8 +2805,7 @@ yyreduce:
     break;
 
   case 68:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 933 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->newsgroups != NULL);
@@ -2882,8 +2813,7 @@ yyreduce:
     break;
 
   case 69:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 937 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2891,8 +2821,7 @@ yyreduce:
     break;
 
   case 70:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 941 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->msgid != NULL);
@@ -2900,8 +2829,7 @@ yyreduce:
     break;
 
   case 71:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 945 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2909,8 +2837,7 @@ yyreduce:
     break;
 
   case 72:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 949 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->cc != NULL);
@@ -2918,8 +2845,7 @@ yyreduce:
     break;
 
   case 73:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 953 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2927,8 +2853,7 @@ yyreduce:
     break;
 
   case 74:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 957 "quote_fmt_parse.y"
     {
 		gboolean found;
@@ -2943,8 +2868,7 @@ yyreduce:
     break;
 
   case 75:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 968 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2952,8 +2876,7 @@ yyreduce:
     break;
 
   case 76:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 972 "quote_fmt_parse.y"
     {
 		add_visibility(account != NULL && account->name != NULL);
@@ -2961,8 +2884,7 @@ yyreduce:
     break;
 
   case 77:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 976 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2970,8 +2892,7 @@ yyreduce:
     break;
 
   case 78:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 980 "quote_fmt_parse.y"
     {
 		add_visibility(account != NULL && account->organization != NULL);
@@ -2979,8 +2900,7 @@ yyreduce:
     break;
 
   case 79:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 984 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -2988,8 +2908,7 @@ yyreduce:
     break;
 
   case 80:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 988 "quote_fmt_parse.y"
     {
 		gchar *str = account_get_signature_str(account);
@@ -2999,8 +2918,7 @@ yyreduce:
     break;
 
   case 81:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 994 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3008,8 +2926,7 @@ yyreduce:
     break;
 
   case 82:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 998 "quote_fmt_parse.y"
     {
 		add_visibility(account != NULL && account->sig_path != NULL
@@ -3018,8 +2935,7 @@ yyreduce:
     break;
 
   case 83:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1003 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3027,8 +2943,7 @@ yyreduce:
     break;
 
   case 84:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1007 "quote_fmt_parse.y"
     {
 #ifdef USE_ENCHANT
@@ -3041,8 +2956,7 @@ yyreduce:
     break;
 
   case 85:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1016 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3050,8 +2964,7 @@ yyreduce:
     break;
 
   case 86:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1020 "quote_fmt_parse.y"
     {
 #ifdef USE_ENCHANT
@@ -3063,8 +2976,7 @@ yyreduce:
     break;
 
   case 87:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1028 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3072,8 +2984,7 @@ yyreduce:
     break;
 
   case 88:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1032 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->cc);
@@ -3083,8 +2994,7 @@ yyreduce:
     break;
 
   case 89:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1038 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3092,8 +3002,7 @@ yyreduce:
     break;
 
   case 90:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1042 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->from);
@@ -3103,8 +3012,7 @@ yyreduce:
     break;
 
   case 91:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1048 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3112,8 +3020,7 @@ yyreduce:
     break;
 
   case 92:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1052 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->to);
@@ -3123,8 +3030,7 @@ yyreduce:
     break;
 
   case 93:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1058 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3132,8 +3038,7 @@ yyreduce:
     break;
 
   case 94:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1064 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->date == NULL);
@@ -3141,8 +3046,7 @@ yyreduce:
     break;
 
   case 95:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1068 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3150,8 +3054,7 @@ yyreduce:
     break;
 
   case 96:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1072 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->from == NULL);
@@ -3159,8 +3062,7 @@ yyreduce:
     break;
 
   case 97:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1076 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3168,8 +3070,7 @@ yyreduce:
     break;
 
   case 98:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1080 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->fromname == NULL);
@@ -3177,8 +3078,7 @@ yyreduce:
     break;
 
   case 99:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1084 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3186,8 +3086,7 @@ yyreduce:
     break;
 
   case 100:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1088 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->subject == NULL);
@@ -3195,8 +3094,7 @@ yyreduce:
     break;
 
   case 101:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1092 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3204,8 +3102,7 @@ yyreduce:
     break;
 
   case 102:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1096 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->to == NULL);
@@ -3213,8 +3110,7 @@ yyreduce:
     break;
 
   case 103:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1100 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3222,8 +3118,7 @@ yyreduce:
     break;
 
   case 104:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1104 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->newsgroups == NULL);
@@ -3231,8 +3126,7 @@ yyreduce:
     break;
 
   case 105:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1108 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3240,8 +3134,7 @@ yyreduce:
     break;
 
   case 106:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1112 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->msgid == NULL);
@@ -3249,8 +3142,7 @@ yyreduce:
     break;
 
   case 107:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1116 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3258,8 +3150,7 @@ yyreduce:
     break;
 
   case 108:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1120 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->cc == NULL);
@@ -3267,8 +3158,7 @@ yyreduce:
     break;
 
   case 109:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1124 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3276,8 +3166,7 @@ yyreduce:
     break;
 
   case 110:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1128 "quote_fmt_parse.y"
     {
 		gboolean found;
@@ -3292,8 +3181,7 @@ yyreduce:
     break;
 
   case 111:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1139 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3301,8 +3189,7 @@ yyreduce:
     break;
 
   case 112:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1143 "quote_fmt_parse.y"
     {
 		add_visibility(account == NULL || account->name == NULL);
@@ -3310,8 +3197,7 @@ yyreduce:
     break;
 
   case 113:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1147 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3319,8 +3205,7 @@ yyreduce:
     break;
 
   case 114:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1151 "quote_fmt_parse.y"
     {
 		add_visibility(account == NULL || account->organization == NULL);
@@ -3328,8 +3213,7 @@ yyreduce:
     break;
 
   case 115:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1155 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3337,8 +3221,7 @@ yyreduce:
     break;
 
   case 116:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1159 "quote_fmt_parse.y"
     {
 		gchar *str = account_get_signature_str(account);
@@ -3348,8 +3231,7 @@ yyreduce:
     break;
 
   case 117:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1165 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3357,8 +3239,7 @@ yyreduce:
     break;
 
   case 118:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1169 "quote_fmt_parse.y"
     {
 		add_visibility(account == NULL || account->sig_path == NULL
@@ -3367,8 +3248,7 @@ yyreduce:
     break;
 
   case 119:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1174 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3376,8 +3256,7 @@ yyreduce:
     break;
 
   case 120:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1178 "quote_fmt_parse.y"
     {
 #ifdef USE_ENCHANT
@@ -3390,8 +3269,7 @@ yyreduce:
     break;
 
   case 121:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1187 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3399,8 +3277,7 @@ yyreduce:
     break;
 
   case 122:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1191 "quote_fmt_parse.y"
     {
 #ifdef USE_ENCHANT
@@ -3412,8 +3289,7 @@ yyreduce:
     break;
 
   case 123:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1199 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3421,8 +3297,7 @@ yyreduce:
     break;
 
   case 124:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1203 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->cc);
@@ -3432,8 +3307,7 @@ yyreduce:
     break;
 
   case 125:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1209 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3441,8 +3315,7 @@ yyreduce:
     break;
 
   case 126:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1213 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->from);
@@ -3452,8 +3325,7 @@ yyreduce:
     break;
 
   case 127:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1219 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3461,8 +3333,7 @@ yyreduce:
     break;
 
   case 128:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1223 "quote_fmt_parse.y"
     {
 		gchar *tmp = quote_fmt_complete_address(msginfo->to);
@@ -3472,8 +3343,7 @@ yyreduce:
     break;
 
   case 129:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1229 "quote_fmt_parse.y"
     {
 		remove_visibility();
@@ -3481,8 +3351,7 @@ yyreduce:
     break;
 
   case 130:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1235 "quote_fmt_parse.y"
     {
 		current = &sub_expr;
@@ -3491,8 +3360,7 @@ yyreduce:
     break;
 
   case 131:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1240 "quote_fmt_parse.y"
     {
 		current = &main_expr;
@@ -3503,8 +3371,7 @@ yyreduce:
     break;
 
   case 132:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1247 "quote_fmt_parse.y"
     {
 		current = &sub_expr;
@@ -3513,8 +3380,7 @@ yyreduce:
     break;
 
   case 133:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1252 "quote_fmt_parse.y"
     {
 		current = &main_expr;
@@ -3525,8 +3391,7 @@ yyreduce:
     break;
 
   case 134:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1259 "quote_fmt_parse.y"
     {
 		current = &sub_expr;
@@ -3535,8 +3400,7 @@ yyreduce:
     break;
 
   case 135:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1264 "quote_fmt_parse.y"
     {
 		current = &main_expr;
@@ -3547,8 +3411,7 @@ yyreduce:
     break;
 
   case 136:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1273 "quote_fmt_parse.y"
     {
 		current = &sub_expr;
@@ -3557,8 +3420,7 @@ yyreduce:
     break;
 
   case 137:
-
-/* Line 1806 of yacc.c  */
+/* Line 1787 of yacc.c  */
 #line 1278 "quote_fmt_parse.y"
     {
 		current = &main_expr;
@@ -3569,9 +3431,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1806 of yacc.c  */
-#line 3575 "quote_fmt_parse.c"
+/* Line 1787 of yacc.c  */
+#line 3436 "quote_fmt_parse.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -3734,7 +3595,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
@@ -3758,7 +3621,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#if !defined(yyoverflow) || YYERROR_VERBOSE
+#if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -3800,4 +3663,3 @@ yyreturn:
 }
 
 
-
