@@ -19,6 +19,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include "defs.h"
@@ -63,6 +64,8 @@ struct _SendProgressDialog
 	gboolean cancelled;
 };
 
+static SendProgressDialog *send_dialog = NULL;
+
 static gint send_recv_message		(Session		*session,
 					 const gchar		*msg,
 					 gpointer		 data);
@@ -85,6 +88,17 @@ static void send_cancel_button_cb	(GtkWidget	*widget,
 static void send_put_error		(Session	*session);
 
 
+void send_cancel(void)
+{
+	if (send_dialog)
+		send_cancel_button_cb(NULL, send_dialog);
+}
+
+gboolean send_is_active(void)
+{
+	return (send_dialog != NULL);
+}
+
 gint send_message(const gchar *file, PrefsAccount *ac_prefs, GSList *to_list)
 {
 	FILE *fp;
@@ -199,7 +213,6 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 	Session *session;
 	SMTPSession *smtp_session;
 	gushort port = 0;
-	SendProgressDialog *dialog;
 	gchar buf[BUFFSIZE];
 	gint ret = 0;
 	gboolean was_inited = FALSE;
@@ -242,51 +255,15 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 			smtp_session->hostname = NULL;
 		}
 
-		if (ac_prefs->use_smtp_auth) {
-			smtp_session->forced_auth_type = ac_prefs->smtp_auth_type;
-			if (ac_prefs->smtp_userid && strlen(ac_prefs->smtp_userid)) {
-				smtp_session->user = g_strdup(ac_prefs->smtp_userid);
-				if (ac_prefs->smtp_passwd)
-					smtp_session->pass =
-						g_strdup(ac_prefs->smtp_passwd);
-				else {
-					smtp_session->pass =
-						input_dialog_query_password_keep
-							(ac_prefs->smtp_server,
-							 smtp_session->user,
-							 &(ac_prefs->session_smtp_passwd));
-					if (!smtp_session->pass) {
-						session_destroy(session);
-						return -1;
-					}
-				}
-			} else {
-				smtp_session->user = g_strdup(ac_prefs->userid);
-				if (ac_prefs->passwd)
-					smtp_session->pass = g_strdup(ac_prefs->passwd);
-				else {
-					smtp_session->pass =
-						input_dialog_query_password_keep
-							(ac_prefs->smtp_server,
-							 smtp_session->user,
-							 &(ac_prefs->session_smtp_passwd));
-					if (!smtp_session->pass) {
-						session_destroy(session);
-						return -1;
-					}
-				}
-			}
-		} else {
-			smtp_session->user = NULL;
-			smtp_session->pass = NULL;
-		}
-
 #ifdef USE_GNUTLS
 		port = ac_prefs->set_smtpport ? ac_prefs->smtpport :
 			ac_prefs->ssl_smtp == SSL_TUNNEL ? SSMTP_PORT : SMTP_PORT;
 		session->ssl_type = ac_prefs->ssl_smtp;
 		if (ac_prefs->ssl_smtp != SSL_NONE)
 			session->nonblocking = ac_prefs->use_nonblocking_ssl;
+		if (ac_prefs->set_gnutls_priority && ac_prefs->gnutls_priority &&
+		    strlen(ac_prefs->gnutls_priority))
+			session->gnutls_priority = g_strdup(ac_prefs->gnutls_priority);
 #else
 		if (ac_prefs->ssl_smtp != SSL_NONE) {
 			if (alertpanel_full(_("Insecure connection"),
@@ -306,11 +283,58 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 		port = ac_prefs->set_smtpport ? ac_prefs->smtpport : SMTP_PORT;
 #endif
 
-		dialog = send_progress_dialog_create();
-		dialog->session = session;
-		smtp_session->dialog = dialog;
+		if (ac_prefs->use_smtp_auth) {
+			smtp_session->forced_auth_type = ac_prefs->smtp_auth_type;
+			if (ac_prefs->smtp_userid && strlen(ac_prefs->smtp_userid)) {
+				smtp_session->user = g_strdup(ac_prefs->smtp_userid);
+				if (password_get(smtp_session->user,
+							ac_prefs->smtp_server, "smtp", port,
+							&(smtp_session->pass))) {
+					/* NOP */;
+				} else if (ac_prefs->smtp_passwd)
+					smtp_session->pass =
+						g_strdup(ac_prefs->smtp_passwd);
+				else {
+					smtp_session->pass =
+						input_dialog_query_password_keep
+							(ac_prefs->smtp_server,
+							 smtp_session->user,
+							 &(ac_prefs->session_smtp_passwd));
+					if (!smtp_session->pass) {
+						session_destroy(session);
+						return -1;
+					}
+				}
+			} else {
+				smtp_session->user = g_strdup(ac_prefs->userid);
+				if (password_get(smtp_session->user,
+							ac_prefs->smtp_server, "smtp", port,
+							&(smtp_session->pass))) {
+					/* NOP */;
+				} else if (ac_prefs->passwd)
+					smtp_session->pass = g_strdup(ac_prefs->passwd);
+				else {
+					smtp_session->pass =
+						input_dialog_query_password_keep
+							(ac_prefs->smtp_server,
+							 smtp_session->user,
+							 &(ac_prefs->session_smtp_passwd));
+					if (!smtp_session->pass) {
+						session_destroy(session);
+						return -1;
+					}
+				}
+			}
+		} else {
+			smtp_session->user = NULL;
+			smtp_session->pass = NULL;
+		}
 
-		progress_dialog_list_set(dialog->dialog, 0, NULL, 
+		send_dialog = send_progress_dialog_create();
+		send_dialog->session = session;
+		smtp_session->dialog = send_dialog;
+
+		progress_dialog_list_set(send_dialog->dialog, 0, NULL, 
 					 ac_prefs->smtp_server, 
 					 _("Connecting"));
 
@@ -319,21 +343,21 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 		    && (time(NULL) - ac_prefs->last_pop_login_time) > (60 * ac_prefs->pop_before_smtp_timeout)) {
 			g_snprintf(buf, sizeof(buf), _("Doing POP before SMTP..."));
 			log_message(LOG_PROTOCOL, "%s\n", buf);
-			progress_dialog_set_label(dialog->dialog, buf);
-			progress_dialog_list_set_status(dialog->dialog, 0, _("POP before SMTP"));
+			progress_dialog_set_label(send_dialog->dialog, buf);
+			progress_dialog_list_set_status(send_dialog->dialog, 0, _("POP before SMTP"));
 			GTK_EVENTS_FLUSH();
 			inc_pop_before_smtp(ac_prefs);
 		}
 
-		g_snprintf(buf, sizeof(buf), _("Account '%s': Connecting to SMTP server: %s ..."),
-				ac_prefs->account_name, ac_prefs->smtp_server);
-		progress_dialog_set_label(dialog->dialog, buf);
+		g_snprintf(buf, sizeof(buf), _("Account '%s': Connecting to SMTP server: %s:%d..."),
+				ac_prefs->account_name, ac_prefs->smtp_server, port);
+		progress_dialog_set_label(send_dialog->dialog, buf);
 		log_message(LOG_PROTOCOL, "%s\n", buf);
 
-		session_set_recv_message_notify(session, send_recv_message, dialog);
+		session_set_recv_message_notify(session, send_recv_message, send_dialog);
 		session_set_send_data_progressive_notify
-			(session, send_send_data_progressive, dialog);
-		session_set_send_data_notify(session, send_send_data_finished, dialog);
+			(session, send_send_data_progressive, send_dialog);
+		session_set_send_data_notify(session, send_send_data_finished, send_dialog);
 
 	} else {
 		/* everything is ready to start at MAIL FROM:, just
@@ -343,7 +367,7 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 		ac_prefs->session = NULL;
 		smtp_session = SMTP_SESSION(session);
 		smtp_session->state = SMTP_HELO;
-		dialog = (SendProgressDialog *)smtp_session->dialog;
+		send_dialog = (SendProgressDialog *)smtp_session->dialog;
 		was_inited = TRUE;
 	}
 
@@ -359,7 +383,7 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 	/* connect if necessary */
 	if (!was_inited && session_connect(session, ac_prefs->smtp_server, port) < 0) {
 		session_destroy(session);
-		send_progress_dialog_destroy(dialog);
+		send_progress_dialog_destroy(send_dialog);
 		ac_prefs->session = NULL;
 		return -1;
 	}
@@ -371,7 +395,7 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 		smtp_from(smtp_session);
 	}
 
-	while (session_is_running(session) && dialog->cancelled == FALSE
+	while (session_is_running(session) && send_dialog->cancelled == FALSE
 		&& SMTP_SESSION(session)->state != SMTP_MAIL_SENT_OK)
 		gtk_main_iteration();
 
@@ -395,13 +419,13 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 		   SMTP_SESSION(session)->state == SMTP_ERROR ||
 		   SMTP_SESSION(session)->error_val != SM_OK)
 		ret = -1;
-	else if (dialog->cancelled == TRUE)
+	else if (send_dialog->cancelled == TRUE)
 		ret = -1;
 
 	if (ret == -1) {
-		manage_window_focus_in(dialog->dialog->window, NULL, NULL);
+		manage_window_focus_in(send_dialog->dialog->window, NULL, NULL);
 		send_put_error(session);
-		manage_window_focus_out(dialog->dialog->window, NULL, NULL);
+		manage_window_focus_out(send_dialog->dialog->window, NULL, NULL);
 	}
 
 	/* if we should close the connection, let's do it.
@@ -411,11 +435,11 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 	if (!keep_session || ret != 0) {
 		if (session_is_connected(session))
 			smtp_quit(smtp_session);
-		while (session_is_connected(session) && !dialog->cancelled)
+		while (session_is_connected(session) && !send_dialog->cancelled)
 			gtk_main_iteration();
 		session_destroy(session);
 		ac_prefs->session = NULL;
-		send_progress_dialog_destroy(dialog);
+		send_progress_dialog_destroy(send_dialog);
 	} else {
 		g_free(smtp_session->from);
 		g_free(smtp_session->send_data);
@@ -598,6 +622,7 @@ static void send_progress_dialog_destroy(SendProgressDialog *dialog)
 		progress_dialog_destroy(dialog->dialog);
 	}
 	g_free(dialog);
+	send_dialog = NULL;
 }
 
 static void send_showlog_button_cb(GtkWidget *widget, gpointer data)
