@@ -27,7 +27,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-typedef struct _SummaryView		SummaryView;
+#include "viewtypes.h"
 typedef struct _SummaryColumnState	SummaryColumnState;
 
 #define MAIL_MANUAL_FILTERING_HOOKLIST "mail_manual_filtering_hooklist"
@@ -66,9 +66,6 @@ typedef enum
 } TargetInfo;
 
 #include "mainwindow.h"
-#include "folderview.h"
-#include "headerview.h"
-#include "messageview.h"
 #include "compose.h"
 #include "folder.h"
 #include "gtksctree.h"
@@ -169,6 +166,10 @@ private:
 	gint folder_update_callback_id;
 
 	GtkTargetList *target_list; /* DnD */
+
+	// folders with matches for recursive quicksearch queries
+	GSList *recursive_matched_folders;
+	FolderItem *search_root_folder;
 	
 #if !GTK_CHECK_VERSION(2,12,0)
 	GtkTooltips *tooltips;
@@ -327,4 +328,5 @@ void summary_set_menu_sensitive	(SummaryView		*summaryview);
 void summary_relayout(SummaryView *summaryview);
 void summary_update_unread(SummaryView *summaryview, FolderItem *removed_item);
 gboolean summary_is_list(SummaryView *summaryview);
+gboolean summaryview_search_root_progress(gpointer data, guint at, guint matched, guint total);
 #endif /* __SUMMARY_H__ */
